import { useAsyncEntity } from '@backstage/plugin-catalog-react';
import { useCortexApi, useInitiativesCustomName } from '../../utils/hooks.esm.js';
import { stringifyAnyEntityRef } from '../../utils/types.esm.js';
import { Progress, WarningPanel, EmptyState, InfoCard } from '@backstage/core-components';
import React__default from 'react';
import { isUndefined } from 'lodash';
import { GroupComponentActionItemsRow } from './GroupComponentActionItemsRow.esm.js';
import { Grid } from '@material-ui/core';
import { groupByString, mapValues } from '../../utils/collections.esm.js';
import { parseEntityRef } from '@backstage/catalog-model';
import { defaultComponentRefContext } from '../../utils/ComponentUtils.esm.js';

const CortexGroupActionItemsWidget = () => {
  const {
    entity,
    loading: entityLoading,
    error: entityError
  } = useAsyncEntity();
  const {
    value: initiativeActionItems,
    loading: actionItemsLoading,
    error: actionItemsError
  } = useCortexApi(
    async (cortexApi) => {
      return entity !== void 0 ? await cortexApi.getInitiativeActionItemsForTeam(
        stringifyAnyEntityRef(entity)
      ) : void 0;
    },
    [entity]
  );
  const { plural: initiativesName } = useInitiativesCustomName();
  if (entityLoading || actionItemsLoading) {
    return /* @__PURE__ */ React__default.createElement(Progress, null);
  }
  if (isUndefined(entity) || entityError) {
    return /* @__PURE__ */ React__default.createElement(WarningPanel, { severity: "error", title: "Could not load entity." }, entityError == null ? void 0 : entityError.message);
  }
  if (actionItemsError || isUndefined(initiativeActionItems)) {
    return /* @__PURE__ */ React__default.createElement(WarningPanel, { severity: "error", title: "Could not load group action items." }, actionItemsError == null ? void 0 : actionItemsError.message);
  }
  if (initiativeActionItems.length === 0) {
    return /* @__PURE__ */ React__default.createElement(
      EmptyState,
      {
        missing: "info",
        title: "No group action items to display",
        description: `The group does not have any action items for the ${initiativesName} it is part of.`
      }
    );
  }
  const componentRefToInitiativeActionItems = groupByString(
    initiativeActionItems,
    (initiativeActionItem) => initiativeActionItem.componentRef
  );
  const componentRefToRuleToInitiative = mapValues(
    componentRefToInitiativeActionItems,
    (items) => groupByString(items, (item) => item.rule.expression)
  );
  return /* @__PURE__ */ React__default.createElement(InfoCard, { title: "Group Action Items" }, /* @__PURE__ */ React__default.createElement(Grid, { container: true, direction: "column" }, Object.keys(componentRefToRuleToInitiative).map((componentRef) => /* @__PURE__ */ React__default.createElement(
    GroupComponentActionItemsRow,
    {
      key: `${componentRef}-key`,
      componentRef: parseEntityRef(
        componentRef,
        defaultComponentRefContext
      ),
      ruleToInitiativeActionItem: componentRefToRuleToInitiative[componentRef]
    }
  ))));
};

export { CortexGroupActionItemsWidget };
//# sourceMappingURL=CortexGroupActionItemsWidget.esm.js.map
