import { Typography } from '@material-ui/core';
import React__default, { Children, isValidElement, Fragment } from 'react';
import { attachComponentData, useApi, configApiRef } from '@backstage/core-plugin-api';
import { Page, Header, RoutedTabs } from '@backstage/core-components';

const Route = () => null;
attachComponentData(Route, "core.gatherMountPoints", true);
function createSubRoutesFromChildren(childrenProps) {
  const routeType = (/* @__PURE__ */ React__default.createElement(Route, { path: "", title: "" }, /* @__PURE__ */ React__default.createElement("div", null))).type;
  return Children.toArray(childrenProps).flatMap((child) => {
    if (!isValidElement(child)) {
      return [];
    }
    if (child.type === Fragment) {
      return createSubRoutesFromChildren(child.props.children);
    }
    if (child.type !== routeType) {
      throw new Error("Child of CortexLayout must be a CortexLayout.Route");
    }
    const { path, title, children, tabProps } = child.props;
    return [{ path, title, children, tabProps }];
  });
}
const CortexLayout = ({
  title,
  subtitle,
  children,
  hideContent
}) => {
  var _a, _b;
  const routes = createSubRoutesFromChildren(children);
  const config = useApi(configApiRef);
  const headerConfig = config.getOptionalConfig("cortex.header");
  const customTitle = headerConfig == null ? void 0 : headerConfig.getOptionalString("title");
  const customTitleComponent = customTitle && /* @__PURE__ */ React__default.createElement(React__default.Fragment, null, customTitle, /* @__PURE__ */ React__default.createElement(Typography, { variant: "subtitle1" }, "Powered by Cortex"));
  return /* @__PURE__ */ React__default.createElement(Page, { themeId: "home" }, /* @__PURE__ */ React__default.createElement(
    Header,
    {
      title: (_a = title != null ? title : customTitleComponent) != null ? _a : "Cortex",
      pageTitleOverride: "Cortex",
      subtitle: (_b = subtitle != null ? subtitle : headerConfig == null ? void 0 : headerConfig.getOptionalString("subtitle")) != null ? _b : "Understand and improve your services."
    }
  ), hideContent ? null : /* @__PURE__ */ React__default.createElement(RoutedTabs, { routes }));
};
CortexLayout.Route = Route;

export { CortexLayout };
//# sourceMappingURL=CortexLayout.esm.js.map
