import React__default from 'react';
import { isNil, capitalize } from 'lodash';
import { CortexLayout } from '../CortexLayout/CortexLayout.esm.js';
import { ScorecardsPage } from '../../extensions.esm.js';
import { SettingsPage } from '../SettingsPage/SettingsPage.esm.js';
import { InitiativesPage } from '../Initiatives/InitiativesPage/InitiativesPage.esm.js';
import { ReportsPage } from '../ReportsPage/ReportsPage.esm.js';
import { useAsync } from 'react-use';
import { Progress } from '@backstage/core-components';
import { useApi, configApiRef } from '@backstage/core-plugin-api';
import { cortexApiRef } from '../../api/CortexClient.esm.js';
import { Permission } from '../../api/types.esm.js';
import { extensionApiRef } from '../../api/ExtensionApi.esm.js';
import { HelpPage } from '../HelpPage/HelpPage.esm.js';
import { shouldShowExpirationBanner, isBeforeShutdownDate } from '../Entitlements/ExpirationUtils.esm.js';
import { ExpirationBanner } from '../Entitlements/ExpirationBanner.esm.js';
import { useInitiativesCustomName } from '../../utils/hooks.esm.js';

const CortexPage = () => {
  var _a;
  const cortexApi = useApi(cortexApiRef);
  const extensionApi = useApi(extensionApiRef);
  const config = useApi(configApiRef);
  const {
    value: permissions,
    loading: loadingPermissions,
    error: permissionsError
  } = useAsync(async () => {
    return await cortexApi.getUserPermissions();
  }, []);
  const { value: helpPage, loading: loadingHelpPage } = useAsync(async () => {
    var _a2, _b, _c;
    return (_c = (_b = await ((_a2 = extensionApi.getUiExtensions) == null ? void 0 : _a2.call(extensionApi))) != null ? _b : void 0) == null ? void 0 : _c.helpPage;
  }, []);
  const hideSettings = (_a = config.getOptionalBoolean("cortex.hideSettings")) != null ? _a : false;
  const canEditSettings = permissions && (permissions == null ? void 0 : permissions.permissions.includes(Permission.EDIT_SETTINGS));
  const {
    value: expiration,
    loading: loadingExpiration
  } = useAsync(async () => {
    return await cortexApi.getExpiration();
  }, []);
  const { plural: initiativesName } = useInitiativesCustomName();
  if (loadingPermissions || loadingHelpPage || loadingExpiration || isNil(expiration)) {
    return /* @__PURE__ */ React__default.createElement(Progress, null);
  }
  return /* @__PURE__ */ React__default.createElement(React__default.Fragment, null, shouldShowExpirationBanner(expiration) && /* @__PURE__ */ React__default.createElement(ExpirationBanner, { ...expiration }), /* @__PURE__ */ React__default.createElement(CortexLayout, { hideContent: !isBeforeShutdownDate(expiration) }, /* @__PURE__ */ React__default.createElement(CortexLayout.Route, { path: "scorecards", title: "Scorecards" }, /* @__PURE__ */ React__default.createElement(ScorecardsPage, null)), /* @__PURE__ */ React__default.createElement(CortexLayout.Route, { path: "reports", title: "Reports" }, /* @__PURE__ */ React__default.createElement(ReportsPage, null)), /* @__PURE__ */ React__default.createElement(CortexLayout.Route, { path: "initiatives", title: capitalize(initiativesName) }, /* @__PURE__ */ React__default.createElement(InitiativesPage, null)), !hideSettings && (!isNil(permissionsError) || canEditSettings) && /* @__PURE__ */ React__default.createElement(CortexLayout.Route, { path: "settings", title: "Settings" }, /* @__PURE__ */ React__default.createElement(SettingsPage, null)), !isNil(helpPage) && /* @__PURE__ */ React__default.createElement(CortexLayout.Route, { path: "help", title: "Help" }, /* @__PURE__ */ React__default.createElement(HelpPage, { helpPage }))));
};

export { CortexPage };
//# sourceMappingURL=CortexPage.esm.js.map
