import React__default, { useMemo } from 'react';
import { useCortexApi } from '../../utils/hooks.esm.js';
import { stringifyAnyEntityRef } from '../../utils/types.esm.js';
import { useAsyncEntity } from '@backstage/plugin-catalog-react';
import { EntityScorecardsCard } from '../EntityPage/EntityScorecardsCard.esm.js';
import { Progress, WarningPanel, EmptyState } from '@backstage/core-components';
import { useLocation, useNavigate } from 'react-router-dom';
import { hasText } from '../../utils/SearchUtils.esm.js';

const isScoreFiltered = (score, filters) => {
  var _a, _b, _c, _d, _e, _f, _g;
  const filteredById = (filters == null ? void 0 : filters.ids) && ((_a = filters == null ? void 0 : filters.ids) == null ? void 0 : _a.length) !== 0 ? (_b = filters == null ? void 0 : filters.ids) == null ? void 0 : _b.includes(score.scorecard.id) : false;
  const filteredByName = (filters == null ? void 0 : filters.names) && ((_c = filters == null ? void 0 : filters.names) == null ? void 0 : _c.length) !== 0 ? (_e = (_d = filters == null ? void 0 : filters.names) == null ? void 0 : _d.map((name) => name.toLowerCase())) == null ? void 0 : _e.reduce(
    (includes, query) => includes || hasText(score, "scorecard.name", query),
    false
  ) : false;
  const filteredByScore = (filters == null ? void 0 : filters.scores) && ((_f = filters == null ? void 0 : filters.scores) == null ? void 0 : _f.length) !== 0 ? (_g = filters == null ? void 0 : filters.scores) == null ? void 0 : _g.includes(score.score.scorePercentage) : false;
  return filteredById || filteredByName || filteredByScore;
};
const CortexScorecardWidget = ({
  includeFilters,
  excludeFilters
}) => {
  const {
    entity,
    loading: entityLoading,
    error: entityError
  } = useAsyncEntity();
  const location = useLocation();
  const navigate = useNavigate();
  const {
    value: scores,
    loading: scoresLoading,
    error: scoresError
  } = useCortexApi(
    async (cortexApi) => {
      return entity !== void 0 ? await cortexApi.getServiceScores(stringifyAnyEntityRef(entity)) : void 0;
    },
    [entity]
  );
  const scoresToDisplay = useMemo(
    () => scores == null ? void 0 : scores.filter((score) => {
      if (includeFilters === void 0 && excludeFilters === void 0) {
        return true;
      }
      return includeFilters !== void 0 && isScoreFiltered(score, includeFilters) || excludeFilters !== void 0 && !isScoreFiltered(score, excludeFilters);
    }),
    [scores, includeFilters, excludeFilters]
  );
  if (entityLoading || scoresLoading) {
    return /* @__PURE__ */ React__default.createElement(Progress, null);
  }
  if (entity === void 0 || entityError) {
    return /* @__PURE__ */ React__default.createElement(WarningPanel, { severity: "error", title: "Could not load entity." }, entityError == null ? void 0 : entityError.message);
  }
  if (scoresError || scoresToDisplay === void 0) {
    return /* @__PURE__ */ React__default.createElement(WarningPanel, { severity: "error", title: "Could not load Scorecards." }, scoresError == null ? void 0 : scoresError.message);
  }
  if (scoresToDisplay.length === 0) {
    return /* @__PURE__ */ React__default.createElement(
      EmptyState,
      {
        missing: "info",
        title: "No scorecards to display",
        description: "You haven't added any scorecards yet."
      }
    );
  }
  return /* @__PURE__ */ React__default.createElement(
    EntityScorecardsCard,
    {
      title: "Cortex Scorecards",
      scores: scoresToDisplay,
      onSelect: (scorecardId) => {
        const target = location.pathname.endsWith("/") ? "cortex" : "/cortex";
        navigate(`${location.pathname}${target}?scorecardId=${scorecardId}`);
      }
    }
  );
};

export { CortexScorecardWidget };
//# sourceMappingURL=CortexScorecardWidget.esm.js.map
