import React__default from 'react';
import { WarningPanel } from '@backstage/core-components';
import { isNil } from 'lodash';
import { getExpirationMessage } from './ExpirationUtils.esm.js';
import { daysUntil } from '../../utils/dates.esm.js';

const ExpirationBanner = ({ contractType, expirationDate, shutdownDate }) => {
  const daysUntilExpiration = daysUntil(expirationDate);
  if (isNil(daysUntilExpiration)) {
    return null;
  }
  const daysUntilShutdown = daysUntil(shutdownDate);
  const isTrial = contractType === "TRIAL";
  const isExpired = daysUntilExpiration < 0;
  return /* @__PURE__ */ React__default.createElement(
    WarningPanel,
    {
      severity: isExpired ? "error" : "warning",
      title: getExpirationMessage(isTrial, daysUntilExpiration, -daysUntilExpiration, daysUntilShutdown)
    }
  );
};

export { ExpirationBanner };
//# sourceMappingURL=ExpirationBanner.esm.js.map
