import { ContractType } from '../../api/types.esm.js';
import { isNil } from 'lodash';
import { maybePluralize } from '../../utils/strings.esm.js';
import { daysUntil } from '../../utils/dates.esm.js';

const shouldShowExpirationBanner = (expiration) => {
  if (!isNil(expiration) && expiration.contractType === ContractType.Trial) {
    return true;
  }
  const daysUntilExpiration = expiration && daysUntil(expiration.expirationDate);
  return !isNil(daysUntilExpiration) && daysUntilExpiration < 14;
};
const isBeforeShutdownDate = (expiration) => {
  const daysUntilShutdown = expiration && daysUntil(expiration.shutdownDate);
  return !daysUntilShutdown || daysUntilShutdown > 0;
};
const getExpirationMessage = (isTrial, daysUntilExpiration, daysPastExpiration, daysUntilShutdown) => {
  return isTrial ? getTrialExpirationMessage(daysUntilExpiration) : getProdExpirationMessage(daysUntilExpiration, daysPastExpiration, daysUntilShutdown);
};
const getProdExpirationMessage = (daysUntilExpiration, daysPastExpiration, daysUntilShutdown) => {
  const shutdownDates = !isNil(daysUntilShutdown) && daysUntilShutdown > 0 ? `in ${maybePluralize(daysUntilShutdown, "day")}` : "today";
  const shutdownMessage = !isNil(daysUntilShutdown) ? `. Your workspace will automatically shut down ${shutdownDates}` : "";
  const expirationState = daysUntilExpiration > 0 ? `is expiring in ${maybePluralize(daysUntilExpiration, "day")}` : daysUntilExpiration === 0 ? `expires today${shutdownMessage}` : `expired ${daysPastExpiration} days ago${shutdownMessage}`;
  return `Your access ${expirationState}. Please reach out to your account manager for support.`;
};
const getTrialExpirationMessage = (daysUntilExpiration) => {
  return daysUntilExpiration > 0 ? `Your Cortex trial expires in ${maybePluralize(daysUntilExpiration, "day")}.` : daysUntilExpiration === 0 ? "Your Cortex trial expires today - Please contact your account manager to continue using Cortex!" : "Your Cortex trial has expired - Please contact your account manager to continue using Cortex!";
};

export { getExpirationMessage, isBeforeShutdownDate, shouldShowExpirationBanner };
//# sourceMappingURL=ExpirationUtils.esm.js.map
