import React__default, { useState, useEffect, useMemo } from 'react';
import { Progress, WarningPanel, EmptyState, Content, ContentHeader } from '@backstage/core-components';
import { Grid } from '@material-ui/core';
import { EntityScorecardsCard } from './EntityScorecardsCard.esm.js';
import { useAsyncEntity } from '@backstage/plugin-catalog-react';
import { stringifyAnyEntityRef } from '../../utils/types.esm.js';
import { useCortexApi } from '../../utils/hooks.esm.js';
import { EntityScorecardDetails } from './EntityScorecardDetails/EntityScorecardDetails.esm.js';
import { ScorecardServiceRefLink } from '../ScorecardServiceRefLink/ScorecardServiceRefLink.esm.js';
import { useLocation } from 'react-router-dom';

const EntityPage = () => {
  var _a;
  const {
    entity,
    loading: entityLoading,
    error: entityError
  } = useAsyncEntity();
  const [selectedScorecardId, setSelectedScorecardId] = useState();
  const location = useLocation();
  const queryParams = new URLSearchParams(location.search);
  const queryScorecardId = Number((_a = queryParams.get("scorecardId")) != null ? _a : void 0);
  const initialScorecardId = Number.isNaN(queryScorecardId) ? void 0 : queryScorecardId;
  const {
    value: scores,
    loading: scoresLoading,
    error: scoresError
  } = useCortexApi(
    async (cortexApi) => {
      return entity !== void 0 ? await cortexApi.getServiceScores(stringifyAnyEntityRef(entity)) : void 0;
    },
    [entity]
  );
  useEffect(() => {
    var _a2, _b;
    const scorecardId = initialScorecardId != null ? initialScorecardId : (_b = (_a2 = scores == null ? void 0 : scores[0]) == null ? void 0 : _a2.scorecard) == null ? void 0 : _b.id;
    if (scorecardId !== void 0) {
      setSelectedScorecardId(scorecardId);
    }
  }, [initialScorecardId, scores, setSelectedScorecardId]);
  const selectedScore = useMemo(() => {
    return scores == null ? void 0 : scores.find((score) => score.scorecard.id === selectedScorecardId);
  }, [scores, selectedScorecardId]);
  if (entityLoading || scoresLoading) {
    return /* @__PURE__ */ React__default.createElement(Progress, null);
  }
  if (scoresError || scores === void 0) {
    return /* @__PURE__ */ React__default.createElement(WarningPanel, { severity: "error", title: "Could not load Scorecards." }, scoresError == null ? void 0 : scoresError.message);
  }
  if (entity === void 0 || entityError) {
    return /* @__PURE__ */ React__default.createElement(WarningPanel, { severity: "error", title: "Could not load entity." }, entityError == null ? void 0 : entityError.message);
  }
  if (scores.length === 0) {
    return /* @__PURE__ */ React__default.createElement(
      EmptyState,
      {
        missing: "info",
        title: "No Scorecards to display",
        description: "You haven't added any Scorecards yet."
      }
    );
  }
  if (selectedScorecardId === void 0) {
    return /* @__PURE__ */ React__default.createElement(EmptyState, { missing: "data", title: "Select a Scorecard" });
  }
  if (selectedScore === void 0) {
    return /* @__PURE__ */ React__default.createElement(
      WarningPanel,
      {
        severity: "error",
        title: "No Scorecard has not been evaluated yet."
      }
    );
  }
  return /* @__PURE__ */ React__default.createElement(Content, null, /* @__PURE__ */ React__default.createElement(ContentHeader, { title: "Scorecards" }, /* @__PURE__ */ React__default.createElement(
    ScorecardServiceRefLink,
    {
      scorecardId: selectedScore.scorecard.id,
      componentRef: stringifyAnyEntityRef(entity)
    },
    /* @__PURE__ */ React__default.createElement("b", null, "View all details")
  )), /* @__PURE__ */ React__default.createElement(Grid, { container: true, direction: "row", spacing: 2 }, /* @__PURE__ */ React__default.createElement(Grid, { item: true, lg: 4 }, /* @__PURE__ */ React__default.createElement(
    EntityScorecardsCard,
    {
      scores,
      onSelect: setSelectedScorecardId,
      selectedScorecardId
    }
  )), /* @__PURE__ */ React__default.createElement(Grid, { item: true, lg: 8 }, /* @__PURE__ */ React__default.createElement(
    EntityScorecardDetails,
    {
      entityRef: entity,
      scorecardId: selectedScorecardId,
      score: selectedScore
    }
  ))));
};

export { EntityPage };
//# sourceMappingURL=EntityPage.esm.js.map
