import React__default, { useState, useMemo } from 'react';
import { Progress, InfoCard, HeaderTabs } from '@backstage/core-components';
import { ScorecardResultDetails } from '../../Scorecards/ScorecardDetailsPage/ScorecardsTableCard/ScorecardResultDetails.esm.js';
import { isRuleOutcomeFailing, isRuleOutcomePassing, isNotApplicableRuleOutcome, isNotEvaluatedRuleOutcome, filterPassingRuleOutcomes, filterFailingRuleOutcomes, filterNotApplicableRuleOutcomes, filterNotEvaluatedRuleOutcomes } from '../../../utils/ScorecardRules.esm.js';

const EntityScorecardRules = ({ score }) => {
  const [selectedIndex, setSelectedIndex] = useState(0);
  const selectedRuleOutcomes = useMemo(() => {
    var _a, _b;
    return (_b = (_a = score == null ? void 0 : score.evaluation) == null ? void 0 : _a.rules) == null ? void 0 : _b.filter(
      (rule) => selectedIndex === 0 ? isRuleOutcomeFailing(rule) : selectedIndex === 1 ? isRuleOutcomePassing(rule) : selectedIndex === 2 ? isNotApplicableRuleOutcome(rule) : isNotEvaluatedRuleOutcome(rule)
    );
  }, [selectedIndex, score]);
  if (score === void 0 || selectedRuleOutcomes === void 0) {
    return /* @__PURE__ */ React__default.createElement(Progress, null);
  }
  const numPassing = filterPassingRuleOutcomes(score.evaluation.rules).length;
  const numFailing = filterFailingRuleOutcomes(score.evaluation.rules).length;
  const numNotApplicable = filterNotApplicableRuleOutcomes(
    score.evaluation.rules
  ).length;
  const numNotEvaluated = filterNotEvaluatedRuleOutcomes(
    score.evaluation.rules
  ).length;
  return /* @__PURE__ */ React__default.createElement(InfoCard, { title: "All Rules" }, /* @__PURE__ */ React__default.createElement(
    HeaderTabs,
    {
      tabs: [
        { id: "failing", label: `Failing (${numFailing})` },
        { id: "passing", label: `Passing (${numPassing})` },
        { id: "not_applicable", label: `Exempt (${numNotApplicable})` },
        {
          id: "not_evaluated",
          label: `Not Yet Evaluated (${numNotEvaluated})`
        }
      ],
      onChange: setSelectedIndex
    }
  ), /* @__PURE__ */ React__default.createElement(ScorecardResultDetails, { ruleOutcomes: selectedRuleOutcomes }));
};

export { EntityScorecardRules };
//# sourceMappingURL=EntityScorecardRules.esm.js.map
