import React__default from 'react';
import { keyBy } from 'lodash';
import { makeStyles, Box, Typography, MenuItem, FormGroup, FormControlLabel, Checkbox, TextField } from '@material-ui/core';
import Select from '@material-ui/core/Select';
import { Autocomplete } from '@material-ui/lab';
import { fallbackPalette } from '../../styles/styles.esm.js';
import { mapValues } from '../../utils/collections.esm.js';
import { useFilter } from './useFilter.esm.js';

const useStyles = makeStyles((theme) => {
  var _a, _b, _c, _d, _e, _f;
  return {
    name: {
      color: (_c = (_b = (_a = theme.palette) == null ? void 0 : _a.text) == null ? void 0 : _b.secondary) != null ? _c : fallbackPalette.text.secondary,
      fontSize: "14px",
      fontWeight: "bold",
      letterSpacing: 0.5,
      overflow: "hidden",
      whiteSpace: "nowrap"
    },
    select: {
      color: (_f = (_e = (_d = theme.palette) == null ? void 0 : _d.text) == null ? void 0 : _e.secondary) != null ? _f : fallbackPalette.text.secondary,
      fontSize: "14px"
    },
    rulesList: {
      padding: 0
    }
  };
});
const Filters = ({
  displayName,
  filters,
  name,
  oneOfDisabled
}) => {
  var _a;
  const { checkedFilters, setCheckedFilters, oneOf, setOneOf } = useFilter();
  const classes = useStyles();
  const currentOneOf = (_a = oneOf[name]) != null ? _a : true;
  const toggleAllFilters = (allCheckedFilters) => {
    const newFilters = mapValues(
      keyBy(allCheckedFilters, (filter) => `${name}${filter.id}`),
      () => true
    );
    setCheckedFilters(newFilters);
  };
  const toggleFilter = (filter) => {
    setCheckedFilters((prevFilters) => {
      var _a2;
      const filterName = `${name}${filter}`;
      const newFilters = {
        ...prevFilters,
        [filterName]: !((_a2 = prevFilters[filterName]) != null ? _a2 : false)
      };
      return newFilters;
    });
  };
  const toggleOneOf = () => {
    setOneOf((prevOneOf) => {
      var _a2;
      const prevValue = (_a2 = prevOneOf[name]) != null ? _a2 : true;
      return {
        ...prevOneOf,
        [name]: !prevValue
      };
    });
  };
  return /* @__PURE__ */ React__default.createElement(Box, { display: "flex", flexDirection: "column" }, /* @__PURE__ */ React__default.createElement(Box, { display: "flex", flexDirection: "row", justifyContent: "space-between" }, /* @__PURE__ */ React__default.createElement(Typography, { variant: "subtitle2", className: classes.name }, displayName != null ? displayName : name, ":"), !oneOfDisabled && /* @__PURE__ */ React__default.createElement(
    Select,
    {
      value: currentOneOf ? "One Of" : "All Of",
      onChange: () => toggleOneOf(),
      className: classes.select,
      "aria-label": `Select and/or for ${name.toLowerCase()}`
    },
    /* @__PURE__ */ React__default.createElement(MenuItem, { value: "One Of" }, "One Of"),
    /* @__PURE__ */ React__default.createElement(MenuItem, { value: "All Of" }, "All Of")
  )), Object.keys(filters).length <= 10 ? /* @__PURE__ */ React__default.createElement(FormGroup, { className: classes.rulesList }, Object.keys(filters).map((id) => {
    var _a2;
    return /* @__PURE__ */ React__default.createElement(
      FormControlLabel,
      {
        key: `Filter-${name}-${id}`,
        control: /* @__PURE__ */ React__default.createElement(
          Checkbox,
          {
            checked: (_a2 = checkedFilters[`${name}${id}`]) != null ? _a2 : false,
            onChange: () => toggleFilter(id),
            color: "primary",
            inputProps: {
              "aria-label": `Filter ${name.toLowerCase()} by ${filters[id].display}`
            }
          }
        ),
        label: /* @__PURE__ */ React__default.createElement(Typography, { variant: "subtitle2" }, filters[id].display)
      }
    );
  })) : /* @__PURE__ */ React__default.createElement(
    Autocomplete,
    {
      defaultValue: Object.values(filters).filter(
        (filter) => checkedFilters[`${name}${filter.id}`]
      ),
      "aria-label": `Filter ${name.toLowerCase()}`,
      options: Object.values(filters),
      getOptionLabel: (filter) => filter.display,
      multiple: true,
      onChange: (_event, values) => {
        toggleAllFilters(values);
      },
      renderInput: (params) => /* @__PURE__ */ React__default.createElement(TextField, { ...params, variant: "standard" })
    }
  ));
};

export { Filters };
//# sourceMappingURL=Filters.esm.js.map
