import { makeStyles, useTheme } from '@material-ui/core';
import { Circle } from 'rc-progress';
import React__default from 'react';
import { fallbackPalette } from '../../styles/styles.esm.js';

const useStyles = makeStyles((theme) => {
  var _a, _b, _c;
  return {
    root: {
      position: "relative",
      lineHeight: 0,
      width: "80px"
    },
    overlay: {
      position: "absolute",
      top: "50%",
      left: "50%",
      transform: "translate(-50%, -60%)",
      fontWeight: "bold",
      fontSize: "0.75rem",
      color: (_c = (_b = (_a = theme.palette) == null ? void 0 : _a.text) == null ? void 0 : _b.secondary) != null ? _c : fallbackPalette.text.secondary
    },
    circle: {
      width: "80%",
      transform: "translate(10%, 0)"
    },
    colorUnknown: {}
  };
});
const defaultProps = {
  fractional: true,
  inverse: false,
  unit: "%",
  max: 100
};
function getProgressColor(palette, value, inverse, max) {
  var _a, _b, _c, _d, _e, _f;
  if (isNaN(value)) {
    return "#DDDDDD";
  }
  const actualMax = max ? max : defaultProps.max;
  const actualValue = inverse ? actualMax - value : value;
  if (actualValue < actualMax / 3) {
    return (_b = (_a = palette.status) == null ? void 0 : _a.error) != null ? _b : fallbackPalette.status.error;
  } else if (actualValue < actualMax * (2 / 3)) {
    return (_d = (_c = palette.status) == null ? void 0 : _c.warning) != null ? _d : fallbackPalette.status.warning;
  }
  return (_f = (_e = palette.status) == null ? void 0 : _e.ok) != null ? _f : fallbackPalette.status.ok;
}
const Gauge = (props) => {
  var _a, _b;
  const classes = useStyles(props);
  const theme = useTheme();
  const { value, fractional, inverse, unit, max, textOverride } = {
    ...defaultProps,
    ...props
  };
  const asPercentage = fractional ? Math.round(value * max) : value;
  const asActual = max !== 100 ? Math.round(value) : asPercentage;
  return /* @__PURE__ */ React__default.createElement("div", { className: classes.root }, /* @__PURE__ */ React__default.createElement(
    Circle,
    {
      strokeLinecap: "butt",
      percent: asPercentage,
      strokeWidth: (_a = props.strokeWidth) != null ? _a : 12,
      trailWidth: (_b = props.trailWidth) != null ? _b : 12,
      strokeColor: getProgressColor(theme.palette, asActual, inverse, max),
      className: classes.circle
    }
  ), /* @__PURE__ */ React__default.createElement("div", { className: classes.overlay }, textOverride != null ? textOverride : isNaN(value) ? "N/A" : `${asActual}${unit}`));
};

export { Gauge, getProgressColor };
//# sourceMappingURL=Gauge.esm.js.map
