import React__default, { useMemo } from 'react';
import { Content, ContentHeader, ItemCardGrid } from '@backstage/core-components';
import moment from 'moment';
import { HomepageOncallCard } from './HomepageOncallCard.esm.js';
import { HomepageInsights } from './HomepageInsights.esm.js';
import { useApi, identityApiRef } from '@backstage/core-plugin-api';
import { useAsync } from 'react-use';

const Homepage = () => {
  const identityApi = useApi(identityApiRef);
  const currTime = useMemo(() => moment(), []);
  const name = useAsync(async () => {
    const profileInfo = await identityApi.getProfileInfo();
    return profileInfo.displayName;
  });
  const helloMessage = useMemo(() => {
    const nameSuffix = name.loading ? "" : `, ${name.value}`;
    const currHour = currTime.hour();
    if (currHour < 12) {
      return `\u2600\uFE0F Good morning${nameSuffix}`;
    } else if (currHour < 18) {
      return `\u2600\uFE0F Good afternoon${nameSuffix}`;
    } else {
      return `\u{1F305} Good evening${nameSuffix}`;
    }
  }, [currTime, name]);
  return /* @__PURE__ */ React__default.createElement(Content, null, /* @__PURE__ */ React__default.createElement(ContentHeader, { title: helloMessage }), /* @__PURE__ */ React__default.createElement(ItemCardGrid, null, /* @__PURE__ */ React__default.createElement(HomepageOncallCard, null), /* @__PURE__ */ React__default.createElement(HomepageInsights, null)));
};

export { Homepage };
//# sourceMappingURL=Homepage.esm.js.map
