import React__default from 'react';
import { UserInsightType } from '../../api/userInsightTypes.esm.js';
import { Link } from '@backstage/core-components';
import { maybePluralize } from '../../utils/strings.esm.js';
import moment from 'moment';
import { isNil, capitalize } from 'lodash';
import { useRouteRef } from '@backstage/core-plugin-api';
import { initiativeRouteRef } from '../../routes.esm.js';
import { EntityRefLink } from '@backstage/plugin-catalog-react';
import { ScorecardRefLink } from '../ScorecardRefLink/ScorecardRefLink.esm.js';
import { useHomepageInsightsLinkStyles } from '../../styles/styles.esm.js';
import InsightCard from './InsightCard.esm.js';
import { useInitiativesCustomName } from '../../utils/hooks.esm.js';

const HomepageInsightCard = ({
  insight,
  scorecards,
  initiatives,
  entities
}) => {
  var _a, _b, _c, _d, _e, _f;
  const initiativeRef = useRouteRef(initiativeRouteRef);
  const linkClasses = useHomepageInsightsLinkStyles();
  const { singular: initiativeName } = useInitiativesCustomName();
  switch (insight.type) {
    case UserInsightType.ACTION_ITEM: {
      const actionItemInsight = insight;
      const entity = entities == null ? void 0 : entities.find(
        (currEntity) => currEntity.id === actionItemInsight.entityId
      );
      const initiative = initiatives == null ? void 0 : initiatives.find(
        (currInitiative) => currInitiative.id === actionItemInsight.initiativeId.toString()
      );
      const entityRef = {
        kind: ((_a = entity == null ? void 0 : entity.definition) == null ? void 0 : _a.kind) || "Component",
        namespace: ((_b = entity == null ? void 0 : entity.definition) == null ? void 0 : _b.namespace) || "default",
        name: ((_c = entity == null ? void 0 : entity.definition) == null ? void 0 : _c.name) || (entity == null ? void 0 : entity.codeTag)
      };
      return /* @__PURE__ */ React__default.createElement(InsightCard, null, "You have", " ", maybePluralize(actionItemInsight.ruleIds.length, "action item"), " due by ", moment.utc(actionItemInsight.targetDate).format("MMM Do"), !isNil(entity) && /* @__PURE__ */ React__default.createElement(React__default.Fragment, null, " ", "for", " ", /* @__PURE__ */ React__default.createElement(EntityRefLink, { entityRef, className: linkClasses.root }, entity.name)), " ", !isNil(initiative) && /* @__PURE__ */ React__default.createElement(React__default.Fragment, null, " ", "for the", " ", /* @__PURE__ */ React__default.createElement(
        Link,
        {
          to: initiativeRef({
            id: initiative.id.toString()
          }),
          className: linkClasses.root
        },
        initiative.name
      ), " ", capitalize(initiativeName)));
    }
    case UserInsightType.FAILING_RULE: {
      const failingRuleInsight = insight;
      const entity = entities == null ? void 0 : entities.find(
        (currEntity) => currEntity.id === failingRuleInsight.entityId
      );
      const scorecard = scorecards.find(
        (scorecard2) => scorecard2.id === failingRuleInsight.scorecardId
      );
      const contentSuffix = failingRuleInsight.nextLadderLevel ? ` to reach ${failingRuleInsight.nextLadderLevel}` : "";
      const entityRef = {
        kind: ((_d = entity == null ? void 0 : entity.definition) == null ? void 0 : _d.kind) || "Component",
        namespace: ((_e = entity == null ? void 0 : entity.definition) == null ? void 0 : _e.namespace) || "default",
        name: ((_f = entity == null ? void 0 : entity.definition) == null ? void 0 : _f.name) || (entity == null ? void 0 : entity.codeTag)
      };
      return /* @__PURE__ */ React__default.createElement(InsightCard, null, maybePluralize(failingRuleInsight.ruleIds.length, "rule"), " left", !isNil(entity) && /* @__PURE__ */ React__default.createElement(React__default.Fragment, null, " ", "for", " ", /* @__PURE__ */ React__default.createElement(EntityRefLink, { entityRef, className: linkClasses.root }, entity.name)), contentSuffix, !isNil(scorecard) && /* @__PURE__ */ React__default.createElement(React__default.Fragment, null, " ", "in", " ", /* @__PURE__ */ React__default.createElement(
        ScorecardRefLink,
        {
          scorecardId: scorecard.id,
          className: linkClasses.root
        },
        scorecard.name
      )));
    }
    case UserInsightType.NO_ENTITIES_OWNED: {
      return /* @__PURE__ */ React__default.createElement(InsightCard, null, "Looks like you own no entities. Try creating one or add yourself as an owner to an existing one.");
    }
    case UserInsightType.NO_FAILING_RULES: {
      return /* @__PURE__ */ React__default.createElement(InsightCard, null, "Great work! You don't have any more Scorecard rules left; all your services are crushing it! \u{1F389}");
    }
    case UserInsightType.NO_SCORECARDS: {
      return /* @__PURE__ */ React__default.createElement(InsightCard, null, "Looks like you have no scorecards - create one!");
    }
    default: {
      return /* @__PURE__ */ React__default.createElement(React__default.Fragment, null);
    }
  }
};

export { HomepageInsightCard };
//# sourceMappingURL=HomepageInsightCard.esm.js.map
