import React__default, { useMemo } from 'react';
import { Progress, WarningPanel } from '@backstage/core-components';
import { useApi } from '@backstage/core-plugin-api';
import { cortexApiRef } from '../../api/CortexClient.esm.js';
import { useAsync } from 'react-use';
import { UserInsightType } from '../../api/userInsightTypes.esm.js';
import moment from 'moment';
import { HomepageInsightCard } from './HomepageInsightCard.esm.js';

const MAX_NUM_INSIGHTS_TO_SHOW = 3;
function isSameOrAfterToday(input) {
  return input.isSameOrAfter(moment(), "date");
}
const HomepageInsights = () => {
  const cortexApi = useApi(cortexApiRef);
  const {
    value: scorecards,
    loading: loadingScorecards,
    error: errorScorecards
  } = useAsync(async () => {
    return await cortexApi.getScorecards();
  }, []);
  const {
    value: initiatives,
    loading: loadingInitiatives,
    error: errorInitiatives
  } = useAsync(async () => {
    return await cortexApi.getInitiatives();
  }, []);
  const {
    value: insights,
    loading: loadingInsights,
    error: errorInsights
  } = useAsync(async () => {
    return await cortexApi.getInsightsByEmail();
  }, []);
  const {
    value: entities,
    loading: loadingEntities,
    error: errorEntities
  } = useAsync(async () => {
    return await cortexApi.getCatalogEntities();
  }, []);
  const insightsToDisplay = useMemo(() => {
    var _a, _b;
    const filteredInsights = (_b = (_a = insights == null ? void 0 : insights.insights) == null ? void 0 : _a.filter((insight) => {
      if (insight.type === UserInsightType.ACTION_ITEM) {
        const targetDate = insight == null ? void 0 : insight.targetDate;
        return isSameOrAfterToday(moment(targetDate));
      }
      return true;
    })) != null ? _b : [];
    return filteredInsights.slice(0, MAX_NUM_INSIGHTS_TO_SHOW);
  }, [insights]);
  if (loadingScorecards || loadingInitiatives || loadingInsights || loadingEntities) {
    return /* @__PURE__ */ React__default.createElement(Progress, null);
  }
  if (errorScorecards || errorInitiatives || errorInsights || errorEntities) {
    return /* @__PURE__ */ React__default.createElement(WarningPanel, { severity: "error", title: "Could not load home page." }, errorScorecards && errorScorecards.message, " ", errorInitiatives && errorInitiatives.message, " ", errorInsights && errorInsights.message, " ", errorEntities && errorEntities.message);
  }
  return /* @__PURE__ */ React__default.createElement(React__default.Fragment, null, insightsToDisplay.map((insight, idx) => {
    return /* @__PURE__ */ React__default.createElement(
      HomepageInsightCard,
      {
        key: `InsightCard-${idx}`,
        insight,
        scorecards: scorecards || [],
        initiatives: initiatives || [],
        entities: (entities == null ? void 0 : entities.entities) || []
      }
    );
  }));
};

export { HomepageInsights, isSameOrAfterToday };
//# sourceMappingURL=HomepageInsights.esm.js.map
