import React__default from 'react';
import { useApi } from '@backstage/core-plugin-api';
import { cortexApiRef } from '../../api/CortexClient.esm.js';
import { useAsync } from 'react-use';
import { Progress, WarningPanel, EmptyState, InfoCard } from '@backstage/core-components';
import { isNil } from 'lodash';
import moment from 'moment';
import { Typography } from '@material-ui/core';
import { getOncallSchedulesDisplayName, getDisplayTimeUntilNextOncall } from './HomepageUtils.esm.js';
import { useHomepageOncallStyles } from '../../styles/styles.esm.js';

const HomepageOncallCard = () => {
  const classes = useHomepageOncallStyles();
  const cortexApi = useApi(cortexApiRef);
  const {
    value: oncall,
    loading,
    error
  } = useAsync(async () => {
    return await cortexApi.getUserOncallByEmail();
  }, []);
  if (loading) {
    return /* @__PURE__ */ React__default.createElement(Progress, null);
  }
  if (error) {
    return /* @__PURE__ */ React__default.createElement(WarningPanel, { severity: "error", title: "Could not load insights." }, error.message);
  }
  if (!(oncall == null ? void 0 : oncall.oncalls.length)) {
    return /* @__PURE__ */ React__default.createElement(
      EmptyState,
      {
        missing: "info",
        title: "No on-call to display",
        description: "You have no on-call provider set up."
      }
    );
  }
  const now = moment.now();
  const currentOncalls = oncall == null ? void 0 : oncall.oncalls.filter(
    (oncall2) => isNil(oncall2.startDate) || moment(oncall2.startDate).isBefore(now)
  );
  const firstOncall = oncall == null ? void 0 : oncall.oncalls[0];
  if (!(firstOncall == null ? void 0 : firstOncall.startDate) || moment(firstOncall.startDate).isBefore(now)) {
    return /* @__PURE__ */ React__default.createElement(InfoCard, { title: "On-Call", className: classes.root }, /* @__PURE__ */ React__default.createElement(Typography, null, "You're currently on call for", " ", getOncallSchedulesDisplayName(currentOncalls)));
  }
  const nextOncallTime = moment(firstOncall.startDate);
  const allNextOncalls = oncall == null ? void 0 : oncall.oncalls.filter(
    (oncall2) => moment(oncall2.startDate).isSameOrBefore(nextOncallTime)
  );
  return /* @__PURE__ */ React__default.createElement(InfoCard, { title: "On-Call" }, /* @__PURE__ */ React__default.createElement(Typography, null, "You're on call for ", getOncallSchedulesDisplayName(allNextOncalls), " in", " ", getDisplayTimeUntilNextOncall(nextOncallTime.toISOString())));
};

export { HomepageOncallCard };
//# sourceMappingURL=HomepageOncallCard.esm.js.map
