import React__default from 'react';
import { useNavigate, useLocation } from 'react-router';
import { stringifyUrl } from 'query-string';
import { Dialog } from '@material-ui/core';
import { FilterProvider } from '../../../FilterCard/useFilter.esm.js';
import { useFiltersFromQueryParams, getPredicateFilterFromFilters, toQueryParams } from './InitiativeFilterDialogUtils.esm.js';
import { InitiativeFilterForm } from '../InitiativeFilterForm/InitiativeFilterForm.esm.js';

const InitiativeFilterDialog = ({
  filtersDefinition,
  handleClose,
  setFilter,
  isOpen
}) => {
  const navigate = useNavigate();
  const location = useLocation();
  const { filters, oneOf } = useFiltersFromQueryParams(location.search);
  const handleSaveFilters = ({
    checkedFilters,
    oneOf: oneOf2
  }) => {
    const predicateFilter = getPredicateFilterFromFilters(
      checkedFilters,
      oneOf2,
      filtersDefinition
    );
    const queryParams = toQueryParams(checkedFilters, oneOf2, filtersDefinition);
    setFilter(predicateFilter);
    navigate(
      stringifyUrl({
        url: location.pathname,
        query: queryParams
      }),
      { replace: true }
    );
    handleClose();
  };
  return /* @__PURE__ */ React__default.createElement(Dialog, { open: isOpen, onClose: handleClose }, /* @__PURE__ */ React__default.createElement(FilterProvider, { initialCheckedFilters: filters, initialOneOf: oneOf }, /* @__PURE__ */ React__default.createElement(
    InitiativeFilterForm,
    {
      filtersDefinition,
      onSave: handleSaveFilters
    }
  )));
};

export { InitiativeFilterDialog };
//# sourceMappingURL=InitiativeFilterDialog.esm.js.map
