import React__default, { useState, useMemo } from 'react';
import { useLocation } from 'react-router';
import { useAsync } from 'react-use';
import { mapValues, keyBy, isNil, isEmpty } from 'lodash';
import { Progress, WarningPanel, Content } from '@backstage/core-components';
import { useRouteRefParams, useApi } from '@backstage/core-plugin-api';
import { Grid, Box, Tabs, Tab, Button } from '@material-ui/core';
import { cortexApiRef } from '../../../api/CortexClient.esm.js';
import { initiativeRouteRef } from '../../../routes.esm.js';
import { InitiativeStatsCard } from './InitiativeStatsCard/InitiativeStatsCard.esm.js';
import { useEntitiesByTag } from '../../../utils/hooks.esm.js';
import { InitiativeMetadataCard } from './InitiativeMetadataCard/InitiativeMetadataCard.esm.js';
import { InitiativeFailingTab } from './InitiativeFailingTab/InitiativeFailingTab.esm.js';
import { InitiativePassingTab } from './InitiativePassingTab/InitiativePassingTab.esm.js';
import { InitiativeLevelsTab } from './InitiativeLevelsTab/InitiativeLevelsTab.esm.js';
import { InitiativeRulesTab } from './InitiativeRulesTab/InitiativeRulesTab.esm.js';
import { InitiativeFilterDialog } from './InitativeFilterDialog/InitiativeFilterDialog.esm.js';
import { useFiltersFromQueryParams, getPredicateFilterFromFilters, getFilterDefinitions } from './InitativeFilterDialog/InitiativeFilterDialogUtils.esm.js';
import { ruleName } from '../../../api/types.esm.js';

const InitiativeDetailsPage = ({
  actionItems,
  entitiesByTag,
  initiative,
  userEntities
}) => {
  var _a;
  const [activeTab, setActiveTab] = useState("Failing" /* Failing */);
  const [isFilterDialogOpen, setIsFilterDialogOpen] = useState(false);
  const location = useLocation();
  const { filters, oneOf } = useFiltersFromQueryParams(location.search);
  const ownerOptions = useMemo(() => {
    var _a2;
    const actionItemEntityRefs = actionItems == null ? void 0 : actionItems.map((actionItem) => {
      return actionItem.componentRef;
    });
    const actionItemEntities = actionItemEntityRefs == null ? void 0 : actionItemEntityRefs.map(
      (entityRef) => {
        return entitiesByTag[entityRef];
      }
    );
    return (_a2 = actionItemEntities == null ? void 0 : actionItemEntities.flatMap((entity) => {
      return entity == null ? void 0 : entity.serviceOwnerEmails.map((emailOwner) => emailOwner.email);
    })) != null ? _a2 : [];
  }, [actionItems, entitiesByTag]);
  const ownerOptionsMap = useMemo(() => {
    return ownerOptions.reduce((acc, email) => {
      acc[email] = {
        display: email,
        value: email,
        id: email
      };
      return acc;
    }, {});
  }, [ownerOptions]);
  const ruleFilterDefinitions = useMemo(() => {
    return mapValues(
      keyBy(initiative == null ? void 0 : initiative.rules, (rule) => `${rule.ruleId}`),
      (rule) => {
        return {
          display: ruleName(rule),
          value: rule.expression,
          id: rule.ruleId.toString()
        };
      }
    );
  }, [initiative == null ? void 0 : initiative.rules]);
  const filterDefinitions = getFilterDefinitions({
    actionItems: actionItems != null ? actionItems : [],
    ownerOptionsMap,
    entitiesByTag,
    ruleFilterDefinitions,
    userEntities
  });
  const [filter, setFilter] = useState(() => {
    return getPredicateFilterFromFilters(filters, oneOf, filterDefinitions);
  });
  const filteredComponentRefs = useMemo(() => {
    var _a2, _b, _c;
    return (_c = (_b = (_a2 = initiative == null ? void 0 : initiative.scores) == null ? void 0 : _a2.map((score) => score.entityTag)) == null ? void 0 : _b.filter(filter)) != null ? _c : [];
  }, [initiative, filter]);
  const filteredActionItems = useMemo(() => {
    if (isNil(actionItems)) {
      return actionItems;
    }
    return actionItems.filter(
      (actionItem) => filteredComponentRefs.some(
        (componentRef) => actionItem.componentRef === componentRef
      )
    );
  }, [actionItems, filteredComponentRefs]);
  const handleTabChange = (_event, newValue) => {
    setActiveTab(newValue);
  };
  const handleFilterDialogClose = () => {
    setIsFilterDialogOpen(false);
  };
  const renderTab = (tabName) => {
    switch (tabName) {
      case "Failing" /* Failing */:
        return /* @__PURE__ */ React__default.createElement(
          InitiativeFailingTab,
          {
            actionItems: filteredActionItems,
            entitiesByTag,
            numRules: initiative.rules.length,
            scorecardId: initiative.scorecard.id
          }
        );
      case "Passing" /* Passing */:
        return /* @__PURE__ */ React__default.createElement(
          InitiativePassingTab,
          {
            actionItems,
            componentRefs: filteredComponentRefs,
            entitiesByTag,
            numRules: initiative.rules.length,
            scorecardId: initiative.scorecard.id
          }
        );
      case "Levels" /* Levels */:
        return /* @__PURE__ */ React__default.createElement(
          InitiativeLevelsTab,
          {
            levels: initiative.levels,
            rules: initiative.rules
          }
        );
      case "Rules" /* Rules */:
        return /* @__PURE__ */ React__default.createElement(InitiativeRulesTab, { rules: initiative.rules });
    }
  };
  return /* @__PURE__ */ React__default.createElement(Content, null, /* @__PURE__ */ React__default.createElement(Grid, { container: true, direction: "row", spacing: 1 }, /* @__PURE__ */ React__default.createElement(Grid, { item: true, lg: 5, xs: 12 }, /* @__PURE__ */ React__default.createElement(InitiativeMetadataCard, { initiative })), /* @__PURE__ */ React__default.createElement(Grid, { item: true, lg: 7, xs: 12 }, /* @__PURE__ */ React__default.createElement(Box, { display: "flex", flexDirection: "column" }, /* @__PURE__ */ React__default.createElement(
    InitiativeStatsCard,
    {
      scores: (_a = initiative == null ? void 0 : initiative.scores) != null ? _a : [],
      actionItems: filteredActionItems,
      filter
    }
  )))), /* @__PURE__ */ React__default.createElement(Box, { display: "flex", justifyContent: "space-between", alignItems: "center" }, /* @__PURE__ */ React__default.createElement(
    Tabs,
    {
      value: activeTab,
      indicatorColor: "primary",
      textColor: "primary",
      onChange: handleTabChange
    },
    /* @__PURE__ */ React__default.createElement(
      Tab,
      {
        label: "Failing" /* Failing */,
        value: "Failing" /* Failing */
      }
    ),
    /* @__PURE__ */ React__default.createElement(
      Tab,
      {
        label: "Passing" /* Passing */,
        value: "Passing" /* Passing */
      }
    ),
    !isEmpty(initiative == null ? void 0 : initiative.levels) ? /* @__PURE__ */ React__default.createElement(
      Tab,
      {
        label: "Levels" /* Levels */,
        value: "Levels" /* Levels */
      }
    ) : /* @__PURE__ */ React__default.createElement(
      Tab,
      {
        label: "Rules" /* Rules */,
        value: "Rules" /* Rules */
      }
    )
  ), activeTab === "Failing" /* Failing */ && /* @__PURE__ */ React__default.createElement(
    Button,
    {
      onClick: () => setIsFilterDialogOpen(true),
      variant: "outlined",
      "aria-label": "Filter"
    },
    "Filter"
  )), /* @__PURE__ */ React__default.createElement(Box, { my: 1 }, renderTab(activeTab)), /* @__PURE__ */ React__default.createElement(
    InitiativeFilterDialog,
    {
      filtersDefinition: filterDefinitions,
      handleClose: handleFilterDialogClose,
      isOpen: isFilterDialogOpen,
      setFilter: (filter2) => setFilter(() => filter2)
    }
  ));
};
const InitiativeDetailsPageWrapper = () => {
  var _a;
  const { id: initiativeId } = useRouteRefParams(initiativeRouteRef);
  const cortexApi = useApi(cortexApiRef);
  const { value, loading, error } = useAsync(async () => {
    return await Promise.all([
      cortexApi.getInitiative(+initiativeId),
      cortexApi.getInitiativeActionItems(+initiativeId),
      cortexApi.getUserEntities()
    ]);
  }, []);
  const [initiative, actionItems, userEntityIds] = value != null ? value : [
    void 0,
    void 0,
    void 0
  ];
  const { entitiesByTag, loading: loadingEntities } = useEntitiesByTag();
  const userEntities = Object.values(entitiesByTag).filter((entity) => userEntityIds == null ? void 0 : userEntityIds.entityIds.includes(entity.id)).map((entity) => entity.codeTag);
  return loading || loadingEntities ? /* @__PURE__ */ React__default.createElement(Progress, null) : error || initiative === void 0 ? /* @__PURE__ */ React__default.createElement(WarningPanel, { severity: "error", title: `Could not load Initiative.` }, (_a = error == null ? void 0 : error.message) != null ? _a : "") : /* @__PURE__ */ React__default.createElement(
    InitiativeDetailsPage,
    {
      actionItems: actionItems != null ? actionItems : [],
      entitiesByTag,
      initiative,
      userEntities: userEntities != null ? userEntities : []
    }
  );
};

export { InitiativeDetailsPage, InitiativeDetailsPageWrapper as default };
//# sourceMappingURL=InitiativeDetailsPage.esm.js.map
