import React__default from 'react';
import { InitiativeScheduleTimeUnit } from '../../../../api/types.esm.js';
import { Link, MarkdownContent } from '@backstage/core-components';
import { makeStyles, Box, Typography } from '@material-ui/core';
import { useRouteRef } from '@backstage/core-plugin-api';
import { scorecardRouteRef } from '../../../../routes.esm.js';
import { CortexInfoCard } from '../../../Common/CortexInfoCard.esm.js';
import { CaptionTypography } from '../../../Common/StatsItem.esm.js';
import InitiativeMetadataFilter from './InitiativeMetadataFilter.esm.js';
import { getTargetDateMessage } from './InitiativeMetadataCardUtils.esm.js';
import { useHideCortexLinks, useCortexFrontendUrl } from '../../../../utils/hooks.esm.js';
import { cortexInitiativePageUrl } from '../../../../utils/URLUtils.esm.js';
import { isNil } from 'lodash';
import { maybePluralize } from '../../../../utils/strings.esm.js';

const timeUnitToDisplayName = {
  [InitiativeScheduleTimeUnit.Day]: "Day",
  [InitiativeScheduleTimeUnit.Week]: "Week",
  [InitiativeScheduleTimeUnit.Month]: "Month"
};
const useScorecardMetadataCardStyles = makeStyles((theme) => ({
  markdownBox: {
    "& p": {
      marginTop: theme.spacing(1),
      marginBottom: theme.spacing(1)
    },
    "& p:first-child": {
      marginTop: 0
    },
    "& p:last-child": {
      marginBottom: 0
    }
  }
}));
const getNotificationDisplayText = (initiative) => {
  const notificationSchedule = initiative.notificationSchedule;
  const isDisabled = isNil(notificationSchedule) || (notificationSchedule == null ? void 0 : notificationSchedule.isDisabled);
  if (isDisabled) {
    return "Custom notifications are disabled for this Initiative";
  }
  return `Notifications are configured to be sent every 
  ${maybePluralize(
    notificationSchedule.timeInterval,
    timeUnitToDisplayName[notificationSchedule.timeUnit].toLowerCase()
  )}`;
};
const InitiativeMetadataCard = ({
  initiative
}) => {
  const classes = useScorecardMetadataCardStyles();
  const scorecardRef = useRouteRef(scorecardRouteRef);
  const hideLink = useHideCortexLinks();
  const cortexBaseUrl = useCortexFrontendUrl();
  return /* @__PURE__ */ React__default.createElement(
    CortexInfoCard,
    {
      title: /* @__PURE__ */ React__default.createElement(Box, { display: "flex", flexDirection: "column" }, /* @__PURE__ */ React__default.createElement(Typography, { variant: "h6" }, initiative.name))
    },
    /* @__PURE__ */ React__default.createElement(Box, { display: "flex", flexDirection: "column", gridGap: 8 }, /* @__PURE__ */ React__default.createElement(Typography, { variant: "body2" }, getTargetDateMessage(initiative)), /* @__PURE__ */ React__default.createElement(Link, { to: scorecardRef({ id: `${initiative.scorecard.id}` }) }, /* @__PURE__ */ React__default.createElement(Typography, { variant: "body2" }, initiative.scorecard.name)), initiative.description && /* @__PURE__ */ React__default.createElement(Box, { className: classes.markdownBox }, /* @__PURE__ */ React__default.createElement(CaptionTypography, { variant: "caption" }, "Description"), /* @__PURE__ */ React__default.createElement(MarkdownContent, { content: initiative.description })), /* @__PURE__ */ React__default.createElement(Box, { className: classes.markdownBox }, /* @__PURE__ */ React__default.createElement(CaptionTypography, { variant: "caption" }, "Notification Schedule"), /* @__PURE__ */ React__default.createElement(MarkdownContent, { content: getNotificationDisplayText(initiative) }), !hideLink && /* @__PURE__ */ React__default.createElement(Box, null, /* @__PURE__ */ React__default.createElement(
      Link,
      {
        to: cortexInitiativePageUrl({
          initiativeId: initiative.id,
          cortexUrl: cortexBaseUrl
        }),
        target: "_blank"
      },
      /* @__PURE__ */ React__default.createElement("b", null, "Edit notification settings")
    ))), /* @__PURE__ */ React__default.createElement(Box, { mb: 2 }, /* @__PURE__ */ React__default.createElement(CaptionTypography, { variant: "caption" }, "Filter"), /* @__PURE__ */ React__default.createElement(InitiativeMetadataFilter, { initiative })))
  );
};

export { InitiativeMetadataCard };
//# sourceMappingURL=InitiativeMetadataCard.esm.js.map
