import React__default, { useMemo } from 'react';
import { InfoCard, EmptyState, Table } from '@backstage/core-components';
import { Typography, Box, ThemeProvider } from '@material-ui/core';
import { defaultComponentRefContext, entityComponentRef } from '../../../../utils/ComponentUtils.esm.js';
import { humanizeAnyEntityRef } from '../../../../utils/types.esm.js';
import { LinearProgressWithLabel } from '../../../Common/LinearProgressWithLabel.esm.js';
import { useInitiativePassingTabStyle, passingTabTheme } from './InitiativePassingTabConfig.esm.js';
import { ServiceNameColumn } from './ServiceNameColumn.esm.js';
import useLinearProgressWithLabelStyles from '../../../Common/useLinearProgressWithLabelStyles.esm.js';

const InitiativePassingTab = ({
  actionItems,
  componentRefs,
  defaultPageSize = 15,
  entitiesByTag,
  numRules = 2,
  scorecardId
}) => {
  const classes = useInitiativePassingTabStyle();
  const linearProgressWithLabelClasses = useLinearProgressWithLabelStyles();
  const passingComponents = useMemo(
    () => componentRefs.filter(
      (componentRef) => actionItems.every(
        (actionItem) => actionItem.componentRef !== componentRef
      )
    ),
    [actionItems, componentRefs]
  );
  const data = useMemo(() => {
    return passingComponents.map((componentRef) => {
      const tag = humanizeAnyEntityRef(
        componentRef,
        defaultComponentRefContext
      );
      const { name, description } = entitiesByTag[componentRef];
      return {
        componentRef,
        description,
        name,
        tag
      };
    }).sort((left, right) => left.tag.localeCompare(right.tag));
  }, [entitiesByTag, passingComponents]);
  const showPagination = useMemo(
    () => componentRefs.length > defaultPageSize,
    [componentRefs, defaultPageSize]
  );
  const columns = useMemo(
    () => [
      {
        field: "all",
        title: "Service name",
        width: "60%",
        render: (data2) => {
          return /* @__PURE__ */ React__default.createElement(
            ServiceNameColumn,
            {
              ...data2,
              componentRef: entityComponentRef(
                entitiesByTag,
                data2.componentRef
              ),
              scorecardId
            }
          );
        },
        customSort: (data1, data2) => {
          return data2.name.localeCompare(data1.name);
        },
        customFilterAndSearch: (filter, rowData) => {
          var _a, _b, _c, _d;
          return (_d = (_c = (_a = rowData.name) == null ? void 0 : _a.includes(filter)) != null ? _c : (_b = rowData.tag) == null ? void 0 : _b.includes(filter)) != null ? _d : false;
        },
        sorting: true
      },
      {
        sorting: true,
        field: "componentRef",
        title: "Tag",
        width: "25%",
        customSort: (data1, data2) => {
          return data2.tag.localeCompare(data1.tag);
        },
        customFilterAndSearch: (filter, rowData) => {
          var _a;
          return (_a = rowData.componentRef.toLocaleLowerCase().includes(filter.toLocaleLowerCase())) != null ? _a : false;
        },
        render: ({ componentRef }) => /* @__PURE__ */ React__default.createElement(Typography, { variant: "subtitle2", className: classes.tag }, componentRef)
      },
      {
        field: "score",
        sorting: false,
        title: "Score",
        width: "15%",
        render: () => {
          return /* @__PURE__ */ React__default.createElement(Box, { sx: { width: 120 } }, /* @__PURE__ */ React__default.createElement(
            LinearProgressWithLabel,
            {
              classes: linearProgressWithLabelClasses,
              value: 100,
              label: `${numRules} / ${numRules}`
            }
          ));
        }
      }
    ],
    [
      classes.tag,
      entitiesByTag,
      linearProgressWithLabelClasses,
      numRules,
      scorecardId
    ]
  );
  if (data.length === 0) {
    return /* @__PURE__ */ React__default.createElement(InfoCard, { title: "Passing" }, /* @__PURE__ */ React__default.createElement(EmptyState, { missing: "data", title: "No passing services." }));
  }
  return /* @__PURE__ */ React__default.createElement(Box, { marginBottom: 3 }, /* @__PURE__ */ React__default.createElement(ThemeProvider, { theme: passingTabTheme }, /* @__PURE__ */ React__default.createElement(
    Table,
    {
      columns,
      data,
      options: {
        pageSize: defaultPageSize,
        pageSizeOptions: [
          defaultPageSize,
          defaultPageSize * 2,
          defaultPageSize * 4
        ],
        paging: showPagination
      },
      title: "Passing"
    }
  )));
};

export { InitiativePassingTab };
//# sourceMappingURL=InitiativePassingTab.esm.js.map
