import React__default from 'react';
import { cortexApiRef } from '../../../api/CortexClient.esm.js';
import { useAsync } from 'react-use';
import { Progress, WarningPanel, EmptyState } from '@backstage/core-components';
import { useApi } from '@backstage/core-plugin-api';
import { Routes, Route } from 'react-router-dom';
import InitiativeDetailsPageWrapper from '../InitiativeDetailsPage/InitiativeDetailsPage.esm.js';
import { InitiativesList } from './InitiativesList.esm.js';
import { useInitiativesCustomName } from '../../../utils/hooks.esm.js';

const InitiativesPage = () => {
  const cortexApi = useApi(cortexApiRef);
  const {
    value: scorecards,
    loading,
    error
  } = useAsync(async () => {
    return await cortexApi.getScorecards();
  }, []);
  const { plural: initiativesName } = useInitiativesCustomName();
  if (loading) {
    return /* @__PURE__ */ React__default.createElement(Progress, null);
  }
  if (error) {
    return /* @__PURE__ */ React__default.createElement(
      WarningPanel,
      {
        severity: "error",
        title: `Could not load ${initiativesName}.`
      },
      error.message
    );
  }
  if (!(scorecards == null ? void 0 : scorecards.length)) {
    return /* @__PURE__ */ React__default.createElement(
      EmptyState,
      {
        missing: "info",
        title: `No ${initiativesName} to display`,
        description: "You haven't added any scorecards yet."
      }
    );
  }
  return /* @__PURE__ */ React__default.createElement(Routes, null, /* @__PURE__ */ React__default.createElement(Route, { path: "/:id", element: /* @__PURE__ */ React__default.createElement(InitiativeDetailsPageWrapper, null) }), /* @__PURE__ */ React__default.createElement(Route, { path: "/", element: /* @__PURE__ */ React__default.createElement(InitiativesList, null) }));
};

export { InitiativesPage };
//# sourceMappingURL=InitiativesPage.esm.js.map
