import React__default, { useMemo } from 'react';
import { Progress, WarningPanel } from '@backstage/core-components';
import { useCortexApi, useEntitiesByTag } from '../../../utils/hooks.esm.js';
import { GroupByOption } from '../../../api/types.esm.js';
import { AllScorecardsHeatmapTable } from './Tables/AllScorecardHeatmapTable.esm.js';

const AllScorecardsHeatmap = ({
  groupBy
}) => {
  const {
    value: serviceScores,
    loading,
    error
  } = useCortexApi((api) => api.getServiceScorecardScores(groupBy), [groupBy]);
  const scorecards = useMemo(() => {
    var _a;
    const out = {};
    (_a = serviceScores == null ? void 0 : serviceScores.flatMap((score) => score.scores)) == null ? void 0 : _a.forEach((score) => {
      out[score.scorecardId] = score.scorecardName;
    });
    return out;
  }, [serviceScores]);
  const scorecardIds = useMemo(() => {
    return Object.keys(scorecards).sort(
      (a, b) => scorecards[a].localeCompare(scorecards[b])
    );
  }, [scorecards]);
  const { entitiesByTag, loading: loadingEntities } = useEntitiesByTag();
  if (loading || loadingEntities) {
    return /* @__PURE__ */ React__default.createElement(Progress, null);
  }
  if (error || serviceScores === void 0) {
    return /* @__PURE__ */ React__default.createElement(WarningPanel, { severity: "error", title: "Could not load Scorecards." }, error == null ? void 0 : error.message);
  }
  if (groupBy === GroupByOption.LEVEL) {
    return /* @__PURE__ */ React__default.createElement(WarningPanel, { severity: "error", title: "Functionality not supported." }, "Group by for levels is not supported yet.");
  }
  const scorecardNames = scorecardIds.map(
    (scorecardId) => scorecards[scorecardId]
  );
  return /* @__PURE__ */ React__default.createElement(
    AllScorecardsHeatmapTable,
    {
      entitiesByTag,
      groupBy,
      scorecardNames,
      serviceScores
    }
  );
};

export { AllScorecardsHeatmap };
//# sourceMappingURL=AllScorecardsHeatmap.esm.js.map
