import React__default, { useMemo } from 'react';
import { round, mean } from 'lodash';
import { Table, TableBody, TableRow, TableCell } from '@material-ui/core';
import { EntityRefLink } from '@backstage/plugin-catalog-react';
import { parseEntityRef } from '@backstage/catalog-model';
import { HeatmapTableHeader } from './HeatmapTableHeader.esm.js';
import { HeatmapCell } from '../HeatmapCell.esm.js';
import { getFormattedScorecardScores } from '../HeatmapUtils.esm.js';
import { entityComponentRef, defaultComponentRefContext } from '../../../../utils/ComponentUtils.esm.js';
import { filterNotUndefined } from '../../../../utils/collections.esm.js';
import { GroupByOption } from '../../../../api/types.esm.js';
import { useColorCellStyles } from './colorClasses.esm.js';

const AllScorecardsHeatmapTable = ({
  entitiesByTag,
  groupBy,
  scorecardNames,
  serviceScores
}) => {
  const colorClasses = useColorCellStyles();
  const data = useMemo(
    () => getFormattedScorecardScores(scorecardNames, serviceScores),
    [scorecardNames, serviceScores]
  );
  const isGroupedByService = groupBy === GroupByOption.ENTITY;
  const numberOfServicesOrEmpty = !isGroupedByService ? ["Number of Services"] : [];
  const headers = [
    { label: "Entity" },
    ...numberOfServicesOrEmpty.map((label) => ({ label })),
    { label: "Average Score" },
    ...scorecardNames.map((label) => ({ label }))
  ];
  return /* @__PURE__ */ React__default.createElement(Table, null, /* @__PURE__ */ React__default.createElement(HeatmapTableHeader, { headers }), /* @__PURE__ */ React__default.createElement(TableBody, null, data.map((groupScore) => {
    var _a;
    const averageScore = round(
      mean(
        filterNotUndefined(
          groupScore.scores.map((score) => score == null ? void 0 : score.scorePercentage)
        )
      ),
      2
    );
    return /* @__PURE__ */ React__default.createElement(TableRow, { key: `TableRow-${groupScore.identifier}` }, /* @__PURE__ */ React__default.createElement(TableCell, null, !isGroupedByService ? /* @__PURE__ */ React__default.createElement(React__default.Fragment, null, groupScore.identifier) : /* @__PURE__ */ React__default.createElement(
      EntityRefLink,
      {
        entityRef: parseEntityRef(
          entityComponentRef(
            entitiesByTag,
            groupScore.identifier
          ),
          defaultComponentRefContext
        ),
        title: (_a = entitiesByTag[groupScore.identifier]) == null ? void 0 : _a.name
      }
    )), !isGroupedByService && /* @__PURE__ */ React__default.createElement(TableCell, { style: { textAlign: "center" } }, groupScore.numberOfServices), /* @__PURE__ */ React__default.createElement(
      HeatmapCell,
      {
        score: isNaN(averageScore) ? void 0 : averageScore,
        text: isNaN(averageScore) ? "N/A" : void 0,
        colorClasses
      }
    ), groupScore.scores.map((score, idx) => /* @__PURE__ */ React__default.createElement(React__default.Fragment, { key: `ReportsTableRuleRow-${idx}` }, /* @__PURE__ */ React__default.createElement(
      HeatmapCell,
      {
        score: score == null ? void 0 : score.scorePercentage,
        text: score !== void 0 ? void 0 : "N/A",
        colorClasses
      }
    ))));
  })));
};

export { AllScorecardsHeatmapTable };
//# sourceMappingURL=AllScorecardHeatmapTable.esm.js.map
