import React__default from 'react';
import TableHead from '@material-ui/core/TableHead/TableHead';
import TableRow from '@material-ui/core/TableRow/TableRow';
import { makeStyles, TableCell, IconButton } from '@material-ui/core';
import { ArrowDropUp, ArrowDropDown } from '@material-ui/icons';

const useHeatmapStyles = makeStyles({
  root: {
    textAlign: "center"
  }
});
const Sorter = ({
  sortBy,
  sortKey,
  setSortBy
}) => {
  const isSelected = (sortBy == null ? void 0 : sortBy.column) === sortKey;
  const isDescending = isSelected && (sortBy == null ? void 0 : sortBy.desc);
  return /* @__PURE__ */ React__default.createElement(
    "div",
    {
      style: {
        display: "flex",
        flexDirection: "column"
      }
    },
    /* @__PURE__ */ React__default.createElement(
      IconButton,
      {
        onClick: () => {
          setSortBy({
            column: sortKey,
            desc: true
          });
        }
      },
      /* @__PURE__ */ React__default.createElement(
        ArrowDropUp,
        {
          color: !isDescending && isSelected ? "primary" : "action"
        }
      )
    ),
    /* @__PURE__ */ React__default.createElement(
      IconButton,
      {
        onClick: () => {
          setSortBy({
            column: sortKey,
            desc: false
          });
        }
      },
      /* @__PURE__ */ React__default.createElement(
        ArrowDropDown,
        {
          color: isDescending && isSelected ? "primary" : "action"
        }
      )
    )
  );
};
const MIN_COL_WIDTH = "150px";
const firstColumn = { width: `15%`, minWidth: MIN_COL_WIDTH };
const secondaryColumns = { width: `10%`, minWidth: MIN_COL_WIDTH };
const HeatmapTableHeader = ({
  headers,
  sortBy,
  setSortBy
}) => {
  const classes = useHeatmapStyles();
  const cellWidth = 85 / headers.length;
  return /* @__PURE__ */ React__default.createElement(TableHead, null, /* @__PURE__ */ React__default.createElement(TableRow, null, headers.map(({ sortKey, label }, idx) => {
    const style = idx === 0 ? firstColumn : [1, 2].includes(idx) ? secondaryColumns : { width: `${cellWidth}%`, minWidth: MIN_COL_WIDTH };
    return /* @__PURE__ */ React__default.createElement(
      TableCell,
      {
        key: `HeatmapTableHeader-${idx}`,
        className: classes.root,
        style,
        onClick: () => {
          if (sortKey && setSortBy) {
            setSortBy((prev) => {
              if ((prev == null ? void 0 : prev.column) === sortKey) {
                return { column: sortKey, desc: !prev.desc };
              }
              return { column: sortKey, desc: false };
            });
          }
        }
      },
      /* @__PURE__ */ React__default.createElement(
        "div",
        {
          style: {
            display: "flex",
            alignItems: "center"
          }
        },
        /* @__PURE__ */ React__default.createElement("span", null, label),
        sortKey && setSortBy && /* @__PURE__ */ React__default.createElement(
          Sorter,
          {
            sortBy,
            sortKey,
            setSortBy
          }
        )
      )
    );
  })));
};

export { HeatmapTableHeader };
//# sourceMappingURL=HeatmapTableHeader.esm.js.map
