import React__default, { useState, useCallback, useEffect } from 'react';
import { makeStyles, Dialog, DialogTitle, Typography, IconButton, DialogContent, Box, DialogActions, Button } from '@material-ui/core';
import CloseIcon from '@material-ui/icons/Close';
import { size } from 'lodash';
import { ModalSelect } from './HeatmapFiltersSelect.esm.js';

const useStyles = makeStyles((theme) => ({
  title: {
    display: "flex",
    flexDirection: "row",
    justifyContent: "space-between",
    alignItems: "center"
  },
  button: {
    position: "absolute",
    right: theme.spacing(1),
    top: theme.spacing(1),
    color: theme.palette.grey[500]
  }
}));
const HeatmapFiltersModal = ({
  filters,
  filtersConfig,
  isOpen,
  setFilters,
  setIsOpen
}) => {
  const classes = useStyles();
  const [updatedFilters, setUpdatedFilters] = useState(filters);
  const filterChangeHandler = useCallback(
    (type, value) => {
      setUpdatedFilters({
        ...updatedFilters,
        [type]: value
      });
    },
    [updatedFilters]
  );
  const filterClearHandler = useCallback(
    (type) => {
      setUpdatedFilters({
        ...updatedFilters,
        [type]: []
      });
    },
    [updatedFilters]
  );
  const applyFiltersHandler = useCallback(() => {
    setFilters(updatedFilters);
    setIsOpen(false);
  }, [setFilters, setIsOpen, updatedFilters]);
  const closeDialogHandler = useCallback(() => {
    setIsOpen(false);
  }, [setIsOpen]);
  useEffect(() => {
    setUpdatedFilters(filters);
  }, [filters, isOpen]);
  return /* @__PURE__ */ React__default.createElement(Dialog, { open: isOpen, onClose: closeDialogHandler, fullWidth: true }, /* @__PURE__ */ React__default.createElement(DialogTitle, { disableTypography: true, className: classes.title }, /* @__PURE__ */ React__default.createElement(Typography, { variant: "h6" }, "Filter Bird's Eye Report"), /* @__PURE__ */ React__default.createElement(
    IconButton,
    {
      "aria-label": "close",
      className: classes.button,
      onClick: closeDialogHandler
    },
    /* @__PURE__ */ React__default.createElement(CloseIcon, null)
  )), /* @__PURE__ */ React__default.createElement(DialogContent, null, /* @__PURE__ */ React__default.createElement(Box, { display: "flex", flexDirection: "column", gridRowGap: 16 }, filtersConfig.map((config) => {
    if (size(config.options) === 0) {
      return null;
    }
    if (config.key === "selectedLevels" && size(config.options) === 1 && config.options[0] === "No Level") {
      return null;
    }
    return /* @__PURE__ */ React__default.createElement(
      ModalSelect,
      {
        key: config.key,
        configKey: config.key,
        name: config.label,
        onChange: filterChangeHandler,
        onReset: filterClearHandler,
        value: updatedFilters[config.key],
        options: config.options
      }
    );
  }))), /* @__PURE__ */ React__default.createElement(DialogActions, null, /* @__PURE__ */ React__default.createElement(
    Button,
    {
      onClick: applyFiltersHandler,
      color: "primary",
      "aria-label": "Apply filters"
    },
    "Apply filters"
  )));
};

export { HeatmapFiltersModal, useStyles };
//# sourceMappingURL=HeatmapFiltersModal.esm.js.map
