import { MenuItem, Box, FormControl, InputLabel, Select, Input, Button } from '@material-ui/core';
import { Clear } from '@material-ui/icons';
import React__default, { useState, useMemo } from 'react';

const ModalSelect = ({
  configKey,
  name,
  value,
  onChange,
  onReset,
  options
}) => {
  const [isOpened, setOpened] = useState(false);
  const mappedOptions = useMemo(() => {
    return options.map((option) => /* @__PURE__ */ React__default.createElement(MenuItem, { key: `ScorecardOption-domain-${option}`, value: option }, option));
  }, [options]);
  const changeHandler = (event) => {
    onChange(configKey, event.target.value);
    setOpened(false);
  };
  const resetHandler = () => {
    onReset(configKey);
  };
  const openMenuHandler = () => {
    setOpened(true);
  };
  const closeMenuHandler = () => {
    setOpened(false);
  };
  return /* @__PURE__ */ React__default.createElement(Box, { display: "flex", flexDirection: "row" }, /* @__PURE__ */ React__default.createElement(FormControl, { variant: "standard", fullWidth: true }, /* @__PURE__ */ React__default.createElement(InputLabel, null, name), /* @__PURE__ */ React__default.createElement(
    Select,
    {
      input: /* @__PURE__ */ React__default.createElement(Input, null),
      multiple: true,
      onClose: closeMenuHandler,
      onOpen: openMenuHandler,
      open: isOpened,
      value,
      onChange: changeHandler
    },
    mappedOptions
  )), value.length > 0 && /* @__PURE__ */ React__default.createElement(
    Button,
    {
      onClick: resetHandler,
      variant: "text",
      "aria-label": `Clear ${name.toLocaleLowerCase()} filter`,
      title: `Clear ${name.toLocaleLowerCase()} filter`
    },
    /* @__PURE__ */ React__default.createElement(Clear, null)
  ));
};

export { ModalSelect };
//# sourceMappingURL=HeatmapFiltersSelect.esm.js.map
