import React__default, { useState, useCallback, useEffect } from 'react';
import { ContentHeader, Progress, EmptyState } from '@backstage/core-components';
import { Grid } from '@material-ui/core';
import { ScorecardSelector } from '../ScorecardSelector.esm.js';
import { useCortexApi, useCortexApiMemoized, useEntitiesByTag } from '../../../utils/hooks.esm.js';
import { CopyButton } from '../../Common/CopyButton.esm.js';
import { useLocation, useNavigate, useSearchParams } from 'react-router-dom';
import { isFunction, isNil, isEmpty } from 'lodash';
import { stringifyUrl } from 'query-string';
import { defaultInitial } from '@cortexapps/birdseye';
import { HeatmapTable } from './HeatmapTable.esm.js';
import { buildUrl } from '../../../utils/URLUtils.esm.js';
import { useApi, alertApiRef } from '@backstage/core-plugin-api';
import { filtersToParams } from './HeatmapUtils.esm.js';

const HeatmapPage = () => {
  var _a, _b, _c, _d, _e, _f, _g, _h, _i, _j, _k, _l, _m, _n;
  const location = useLocation();
  const navigate = useNavigate();
  const [searchParams] = useSearchParams();
  const alertApi = useApi(alertApiRef);
  const [filters, setFilters] = useState({
    ...defaultInitial,
    scorecardId: (_a = searchParams.get("scorecardId")) != null ? _a : void 0,
    dataFilters: {
      ...defaultInitial.dataFilters,
      selectedEntities: (_b = searchParams.getAll("entity")) != null ? _b : [],
      selectedGroups: (_c = searchParams.getAll("group")) != null ? _c : [],
      selectedTeams: (_d = searchParams.getAll("team")) != null ? _d : [],
      selectedDomains: (_e = searchParams.getAll("domain")) != null ? _e : [],
      selectedLevels: (_f = searchParams.getAll("level")) != null ? _f : [],
      selectedOwners: (_g = searchParams.getAll("owner")) != null ? _g : []
    },
    path: searchParams.getAll("path").map((item) => {
      const [type, label] = JSON.parse(item);
      return { type, label };
    }),
    useHierarchy: searchParams.has("showHierarchy"),
    hideTeamsWithoutServices: !searchParams.has("hideWithoutChildren"),
    headerType: (_h = searchParams.get("headerType")) != null ? _h : void 0
  });
  const getShareableLink = useCallback(() => {
    return buildUrl(filtersToParams(filters), location.pathname);
  }, [filters, location]);
  const onGetShareableLinkSuccess = useCallback(
    () => alertApi.post({ message: "Share link copied!", display: "transient" }),
    [alertApi]
  );
  const setFiltersAndNavigate = useCallback(
    (value) => {
      setFilters((prev) => {
        const newFilters = isFunction(value) ? value(prev) : value;
        navigate(
          stringifyUrl({
            url: location.pathname,
            query: filtersToParams(newFilters)
          }),
          { replace: true }
        );
        return newFilters;
      });
    },
    [location.pathname, navigate]
  );
  const scorecardsResult = useCortexApi((api) => api.getScorecards());
  const { loading: isLoadingScorecards } = scorecardsResult;
  const { value: scores, loading: isLoadingScores } = useCortexApi(
    async (api) => filters.scorecardId ? api.getScorecardScores(Number.parseInt(filters.scorecardId)) : void 0,
    [filters.scorecardId]
  );
  const { value: ladders, loading: isLoadingLadder } = useCortexApi(
    async (api) => filters.scorecardId ? api.getScorecardLadders(Number.parseInt(filters.scorecardId)) : void 0,
    [filters.scorecardId]
  );
  const { value: catalog, loading: isLoadingCatalog } = useCortexApi(
    (api) => api.getCatalogEntities()
  );
  const { value: domains, loading: isLoadingDomains } = useCortexApi(
    (api) => api.getAllDomains()
  );
  const { value: teams, loading: isLoadingTeams } = useCortexApi(
    (api) => api.getAllTeams()
  );
  const { value: teamsByEntityId, loading: isLoadingTeamsByEntityId } = useCortexApiMemoized(
    async (api) => !isNil(scores) && !isEmpty(scores) ? await api.getTeamsByEntityIds(scores.map((score) => score.serviceId)) : void 0,
    [scores]
  );
  const { value: domainHierarchies, loading: isLoadingDomainHierarchies } = useCortexApi((api) => api.getDomainHierarchies());
  const { value: teamHierarchies, loading: isLoadingTeamHierarchies } = useCortexApi((api) => api.getTeamHierarchies());
  const { value: domainAncestors, loading: isLoadingDomainAncestors } = useCortexApi((api) => api.getEntityDomainAncestors());
  const { entitiesByTag, loading: loadingEntitiesByTag } = useEntitiesByTag();
  const isLoading = isLoadingScorecards || isLoadingScores || isLoadingCatalog || isLoadingLadder || isLoadingDomainHierarchies || isLoadingTeamHierarchies || isLoadingDomainAncestors || isLoadingDomains || isLoadingTeams || isLoadingTeamsByEntityId || loadingEntitiesByTag;
  const onScorecardSelectChange = useCallback(
    (scorecardId) => {
      setFiltersAndNavigate({
        ...defaultInitial,
        scorecardId: scorecardId == null ? void 0 : scorecardId.toString()
      });
    },
    [setFiltersAndNavigate]
  );
  useEffect(() => {
    setFiltersAndNavigate(filters);
  }, [filters, setFiltersAndNavigate]);
  const scorecard = (_i = scorecardsResult.value) == null ? void 0 : _i.find(
    (result) => result.id.toString() === filters.scorecardId
  );
  return /* @__PURE__ */ React__default.createElement(React__default.Fragment, null, /* @__PURE__ */ React__default.createElement(ContentHeader, { title: "Bird's Eye" }, /* @__PURE__ */ React__default.createElement(
    CopyButton,
    {
      textToCopy: getShareableLink,
      "aria-label": "Share link",
      onSuccess: onGetShareableLinkSuccess
    },
    "Share link"
  )), /* @__PURE__ */ React__default.createElement(Grid, { container: true, direction: "column" }, /* @__PURE__ */ React__default.createElement(Grid, { item: true, lg: 12 }, /* @__PURE__ */ React__default.createElement(
    ScorecardSelector,
    {
      selectedScorecardId: filters.scorecardId ? Number.parseInt(filters.scorecardId) : void 0,
      onSelect: onScorecardSelectChange,
      scorecardsResult
    }
  )), /* @__PURE__ */ React__default.createElement(Grid, { item: true, lg: 12 }, isLoading ? /* @__PURE__ */ React__default.createElement(Progress, null) : scorecard ? /* @__PURE__ */ React__default.createElement(
    HeatmapTable,
    {
      allDomains: (_j = domains == null ? void 0 : domains.domains) != null ? _j : [],
      allTeams: (_k = teams == null ? void 0 : teams.teams) != null ? _k : [],
      catalog: (_l = catalog == null ? void 0 : catalog.entities) != null ? _l : [],
      domainAncestryMap: (_m = domainAncestors == null ? void 0 : domainAncestors.entitiesToAncestors) != null ? _m : {},
      domainHierarchy: domainHierarchies,
      entitiesByTag,
      filters,
      ladder: ladders == null ? void 0 : ladders[0],
      scorecard,
      scores: scores != null ? scores : [],
      setFilters,
      teamHierarchy: teamHierarchies,
      teamsByEntity: (_n = teamsByEntityId == null ? void 0 : teamsByEntityId.teamsByEntityId) != null ? _n : {}
    }
  ) : /* @__PURE__ */ React__default.createElement(EmptyState, { title: "Select a Scorecard", missing: "data" }))));
};

export { HeatmapPage };
//# sourceMappingURL=HeatmapPage.esm.js.map
