import React__default, { useState, useCallback, useMemo } from 'react';
import { HeaderType } from '@cortexapps/birdseye';
import { mapValues, sum, map, size } from 'lodash';
import { Grid, FormControl, InputLabel, Select, MenuItem, FormControlLabel, Checkbox, Typography, Button } from '@material-ui/core';
import { HeatmapFiltersModal } from './HeatmapFiltersModal.esm.js';
import { Clear } from '@material-ui/icons';

const HeatmapSettings = ({
  filters,
  filtersConfig,
  groupBy,
  groupByOptions,
  setDataFilters,
  setGroupBy,
  setHideTeamsWithoutEntities,
  setReportType,
  setUseHierarchy,
  shouldShowReportType,
  showHierarchy
}) => {
  const [isFilterModalOpened, setFilterModalOpened] = useState(false);
  const groupChangeHandler = useCallback(
    (event) => {
      const newGroup = groupByOptions.find(
        (option) => option === event.target.value
      );
      if (!newGroup) {
        return;
      }
      setGroupBy(newGroup);
    },
    [groupByOptions, setGroupBy]
  );
  const reportTypeChangeHandler = useCallback(
    (event) => {
      if (event.target.value !== HeaderType.Ladder && event.target.value !== HeaderType.Rules) {
        return;
      }
      setReportType(event.target.value);
    },
    [setReportType]
  );
  const clearFiltersHandler = useCallback(() => {
    const emptyFilter = mapValues(filters.dataFilters, () => []);
    setDataFilters(emptyFilter);
  }, [filters.dataFilters, setDataFilters]);
  const filtersCount = useMemo(
    () => sum(map(filters.dataFilters, size)),
    [filters.dataFilters]
  );
  return /* @__PURE__ */ React__default.createElement(Grid, { container: true, direction: "row", justifyContent: "space-between" }, /* @__PURE__ */ React__default.createElement(Grid, { item: true }, /* @__PURE__ */ React__default.createElement(Grid, { container: true, direction: "row" }, /* @__PURE__ */ React__default.createElement(Grid, { item: true }, /* @__PURE__ */ React__default.createElement(FormControl, null, /* @__PURE__ */ React__default.createElement(InputLabel, { style: { minWidth: "100px" } }, "Group By"), /* @__PURE__ */ React__default.createElement(Select, { value: groupBy, onChange: groupChangeHandler }, groupByOptions.map((value) => /* @__PURE__ */ React__default.createElement(MenuItem, { key: `GroupByOption-${value}`, value }, value))))), shouldShowReportType && /* @__PURE__ */ React__default.createElement(Grid, { item: true }, /* @__PURE__ */ React__default.createElement(FormControl, null, /* @__PURE__ */ React__default.createElement(InputLabel, { style: { minWidth: "100px" } }, "Driven By"), /* @__PURE__ */ React__default.createElement(
    Select,
    {
      value: filters.headerType,
      onChange: reportTypeChangeHandler
    },
    /* @__PURE__ */ React__default.createElement(
      MenuItem,
      {
        key: "DrivenByOption-Rules",
        value: HeaderType.Rules
      },
      "Rules"
    ),
    /* @__PURE__ */ React__default.createElement(
      MenuItem,
      {
        key: "DrivenByOption-Levels",
        value: HeaderType.Ladder
      },
      "Levels"
    )
  ))), showHierarchy && /* @__PURE__ */ React__default.createElement(Grid, { item: true }, /* @__PURE__ */ React__default.createElement(
    FormControlLabel,
    {
      "aria-label": "Show hierarchy",
      control: /* @__PURE__ */ React__default.createElement(
        Checkbox,
        {
          checked: filters.useHierarchy,
          onChange: () => {
            setUseHierarchy(!filters.useHierarchy);
          }
        }
      ),
      label: /* @__PURE__ */ React__default.createElement(Typography, { variant: "subtitle2" }, "Show hierarchy")
    }
  )), showHierarchy && /* @__PURE__ */ React__default.createElement(Grid, { item: true }, /* @__PURE__ */ React__default.createElement(
    FormControlLabel,
    {
      "aria-label": "Hide teams without entities",
      control: /* @__PURE__ */ React__default.createElement(
        Checkbox,
        {
          checked: filters.hideTeamsWithoutServices,
          onChange: () => {
            setHideTeamsWithoutEntities(
              !filters.hideTeamsWithoutServices
            );
          }
        }
      ),
      label: /* @__PURE__ */ React__default.createElement(Typography, { variant: "subtitle2" }, "Hide teams without entities")
    }
  )))), /* @__PURE__ */ React__default.createElement(Grid, { item: true }, /* @__PURE__ */ React__default.createElement(
    Button,
    {
      onClick: () => setFilterModalOpened(true),
      variant: "outlined",
      "aria-label": "Filter"
    },
    "Filters",
    filtersCount > 0 && /* @__PURE__ */ React__default.createElement(React__default.Fragment, null, " (", filtersCount, ")")
  ), filtersCount > 0 && /* @__PURE__ */ React__default.createElement(
    Button,
    {
      onClick: clearFiltersHandler,
      variant: "text",
      "aria-label": "Clear filters",
      title: "Clear filters"
    },
    /* @__PURE__ */ React__default.createElement(Clear, null)
  )), /* @__PURE__ */ React__default.createElement(
    HeatmapFiltersModal,
    {
      isOpen: isFilterModalOpened,
      filters: filters.dataFilters,
      filtersConfig,
      setFilters: setDataFilters,
      setIsOpen: setFilterModalOpened
    }
  ));
};

export { HeatmapSettings };
//# sourceMappingURL=HeatmapSettings.esm.js.map
