import React__default from 'react';
import { DomainOwnerInheritance, FilterType as FilterType$1 } from '@cortexapps/birdseye';
import { OwnerInheritance, FilterType } from '../../../api/types.esm.js';
import { Link } from '@backstage/core-components';
import { makeStyles } from '@material-ui/core';

const filtersToParams = (filters) => ({
  scorecardId: filters.scorecardId,
  entity: filters.dataFilters.selectedEntities,
  group: filters.dataFilters.selectedGroups,
  team: filters.dataFilters.selectedTeams,
  domain: filters.dataFilters.selectedDomains,
  level: filters.dataFilters.selectedLevels,
  owner: filters.dataFilters.selectedOwners,
  showHierarchy: filters.useHierarchy ? "true" : void 0,
  hideWithoutChildren: filters.hideTeamsWithoutServices ? void 0 : "false",
  headerType: filters.headerType,
  path: filters.path.map(({ type, label }) => JSON.stringify([type, label]))
});
const convertToBirdsEyeFilterType = (filterType) => {
  switch (filterType) {
    case FilterType.SERVICE_FILTER:
      return FilterType$1.SERVICE_FILTER;
    case FilterType.DOMAIN_FILTER:
      return FilterType$1.DOMAIN_FILTER;
    case FilterType.RESOURCE_FILTER:
      return FilterType$1.RESOURCE_FILTER;
    case FilterType.TEAM_FILTER:
      return FilterType$1.TEAM_FILTER;
  }
};
const convertToBirdsEyeOwnerInheritance = (inheritance) => {
  switch (inheritance) {
    case OwnerInheritance.Append:
      return DomainOwnerInheritance.Append;
    case OwnerInheritance.Fallback:
      return DomainOwnerInheritance.Fallback;
    case OwnerInheritance.None:
      return DomainOwnerInheritance.None;
  }
};
const convertToBirdsEyeFilter = (filter) => {
  return !filter ? void 0 : (filter == null ? void 0 : filter.type) === FilterType.COMPOUND_FILTER ? {
    ...filter,
    type: "COMPOUND_FILTER",
    cqlFilter: filter.cqlFilter ? {
      ...filter.cqlFilter,
      type: FilterType$1.CQL_FILTER
    } : void 0
  } : (filter == null ? void 0 : filter.type) === FilterType.CQL_FILTER ? {
    ...filter,
    type: FilterType$1.CQL_FILTER
  } : {
    ...filter,
    type: convertToBirdsEyeFilterType(filter.type)
  };
};
const convertToBirdsEyeRule = (rule) => {
  var _a;
  return {
    ...rule,
    cqlVersion: rule.cqlVersion,
    dateCreated: (_a = rule.dateCreated) != null ? _a : "",
    filter: convertToBirdsEyeFilter(rule.filter),
    id: rule.id.toString()
  };
};
const convertToBirdsEyeScorecard = (scorecard, ladder) => {
  const rules = scorecard.rules.map(
    convertToBirdsEyeRule
  );
  return {
    ...scorecard,
    filter: convertToBirdsEyeFilter(scorecard.filter),
    id: scorecard.id.toString(),
    rules,
    ladder
  };
};
const convertToBirdsEyeRuleOutcome = (rules) => {
  return rules.map(
    (rule) => ({
      ...rule,
      rule: convertToBirdsEyeRule(rule.rule)
    })
  );
};
const convertToBirdsEyeScores = (scores, catalog) => {
  return scores.map((score) => {
    var _a, _b;
    const entity = catalog.find((item) => item.id === score.serviceId);
    return {
      score: {
        score: score.score,
        scorePercentage: score.scorePercentage,
        totalPossibleScore: score.totalPossibleScore
      },
      entity: {
        cid: score.cid,
        entityGroups: {
          all: score.tags,
          defined: score.tags
        },
        entityOwners: score.entityOwners.map((owner) => {
          var _a2, _b2;
          return {
            ...owner,
            id: (_b2 = (_a2 = owner.id) == null ? void 0 : _a2.toString()) != null ? _b2 : "",
            inheritance: convertToBirdsEyeOwnerInheritance(owner.inheritance)
          };
        }),
        id: score.serviceId.toString(),
        name: (_a = entity == null ? void 0 : entity.name) != null ? _a : "",
        ownerGroups: score.teams,
        tag: score.componentRef,
        type: (_b = entity == null ? void 0 : entity.type) != null ? _b : "",
        description: score.description,
        icon: entity == null ? void 0 : entity.icon
      },
      evaluation: {
        rules: convertToBirdsEyeRuleOutcome(score.rules),
        ladderLevels: score.ladderLevels,
        lastUpdated: score.lastUpdated
      }
    };
  });
};
const convertToBirdsEyeDomainNodeMetadata = (item) => {
  var _a;
  return {
    ...item,
    node: {
      ...item.node,
      description: (_a = item.node.description) != null ? _a : void 0,
      id: item.node.id.toString()
    },
    orderedChildren: item.orderedChildren.map(
      convertToBirdsEyeDomainNodeMetadata
    )
  };
};
const convertToBirdsEyeDomainHierarchy = (hierarchies) => {
  var _a;
  return {
    ...hierarchies,
    orderedTree: (_a = hierarchies == null ? void 0 : hierarchies.orderedTree.map(convertToBirdsEyeDomainNodeMetadata)) != null ? _a : []
  };
};
const convertToBirdsEyeTeamNodeMetadata = (item) => {
  var _a;
  return {
    ...item,
    node: {
      ...item.node,
      description: (_a = item.node.description) != null ? _a : void 0,
      id: item.node.id.toString()
    },
    orderedChildren: item.orderedChildren.map(
      convertToBirdsEyeTeamNodeMetadata
    )
  };
};
const convertToBirdsEyeTeamHierarchy = (hierarchies) => {
  var _a;
  return {
    ...hierarchies,
    orderedParents: (_a = hierarchies == null ? void 0 : hierarchies.orderedParents.map(convertToBirdsEyeTeamNodeMetadata)) != null ? _a : []
  };
};
const getScoreColorClassName = (points) => {
  if (points > 0.9) {
    return "success1";
  } else if (points > 0.8) {
    return "success2";
  } else if (points > 0.7) {
    return "success3";
  } else if (points > 0.6) {
    return "warning1";
  } else if (points > 0.5) {
    return "warning2";
  } else if (points > 0.4) {
    return "warning3";
  } else if (points > 0.3) {
    return "danger1";
  } else if (points > 0.2) {
    return "danger2";
  }
  return "danger3";
};
const getCellColorBackground = (value) => {
  if (value === null || value === void 0) {
    return "danger3";
  }
  if (value > 0.9) {
    return "success1";
  } else if (value > 0.49) {
    return "warning2";
  } else {
    return "danger3";
  }
};
const BirdsEyeAnchorAdapter = (props) => {
  var _a;
  return /* @__PURE__ */ React__default.createElement(Link, { to: (_a = props.href) != null ? _a : "" }, props.children);
};
const useTableStyles = makeStyles((theme) => ({
  breadcrumb: {
    "& button:not(button[disabled])": {
      color: theme.palette.text.primary,
      cursor: "pointer"
    },
    "& button[disabled]": {
      color: theme.palette.text.disabled
    }
  },
  table: {
    "& table thead,tbody": {
      backgroundColor: theme.palette.background.default
    },
    "& table tr th": {
      backgroundColor: `${theme.palette.background.paper} !important`
    },
    "& table tr td.cortex-entity-count-cell": {
      backgroundColor: theme.palette.background.default,
      border: `1px solid ${theme.palette.background.default}`
    },
    "& table tr td.cortex-level-cell": {
      backgroundColor: theme.palette.background.default,
      border: `1px solid ${theme.palette.background.default}`
    },
    "& table tr td:first-child": {
      backgroundColor: theme.palette.background.paper,
      borderRightColor: theme.palette.background.default
    },
    "& a:link": {
      color: theme.palette.primary.main
    },
    "& a:hover": {
      textDecoration: "underline"
    }
  }
}));

export { BirdsEyeAnchorAdapter, convertToBirdsEyeDomainHierarchy, convertToBirdsEyeDomainNodeMetadata, convertToBirdsEyeFilter, convertToBirdsEyeFilterType, convertToBirdsEyeOwnerInheritance, convertToBirdsEyeRule, convertToBirdsEyeRuleOutcome, convertToBirdsEyeScorecard, convertToBirdsEyeScores, convertToBirdsEyeTeamHierarchy, convertToBirdsEyeTeamNodeMetadata, filtersToParams, getCellColorBackground, getScoreColorClassName, useTableStyles };
//# sourceMappingURL=HeatmapUtils.esm.js.map
