import React__default, { useMemo, useEffect } from 'react';
import { getLookbackRange } from '../../../utils/lookback.esm.js';
import { useCortexApi, useCortexFrontendUrl, useHideCortexLinks } from '../../../utils/hooks.esm.js';
import { Progress, WarningPanel, EmptyState } from '@backstage/core-components';
import { Typography, Button } from '@material-ui/core';
import { Timeseries } from '../../Timeseries/Timeseries.esm.js';
import Box from '@material-ui/core/Box';
import moment from 'moment';
import { mapByString } from '../../../utils/collections.esm.js';
import { GroupByOption } from '../../../api/types.esm.js';
import { cortexScorecardPageUrl } from '../../../utils/URLUtils.esm.js';

const AggregatedScorecardProgress = ({
  scorecardId,
  lookback,
  groupBy,
  filters,
  setFilterOptions,
  ruleExpression
}) => {
  var _a;
  const {
    value: historicalScores,
    loading,
    error
  } = useCortexApi(
    async (cortexApi) => {
      const [startDate, endDate] = getLookbackRange(lookback);
      return cortexApi.getAverageHistoricalScores(scorecardId, groupBy, {
        startDate,
        endDate,
        ruleExpression
      });
    },
    [scorecardId, lookback, groupBy, ruleExpression]
  );
  const unfilteredData = useMemo(() => {
    var _a2;
    return (_a2 = historicalScores == null ? void 0 : historicalScores.map((aggregatedResult) => {
      return {
        id: aggregatedResult.identifier,
        data: aggregatedResult.scores.map((score) => {
          return {
            x: new Date(score.dateCreated),
            y: (score.scorePercentage * 100).toFixed(2)
          };
        })
      };
    })) != null ? _a2 : [];
  }, [historicalScores]);
  const data = useMemo(() => {
    var _a2;
    return mapByString(
      (_a2 = unfilteredData == null ? void 0 : unfilteredData.filter(
        (d) => filters === void 0 || filters.length === 0 || filters.includes(d.id)
      )) != null ? _a2 : [],
      (serie) => serie.id
    );
  }, [unfilteredData, filters]);
  useEffect(() => {
    setFilterOptions(unfilteredData.map((d) => d.id));
  }, [setFilterOptions, unfilteredData]);
  const cortexBaseUrl = useCortexFrontendUrl();
  const hideLink = useHideCortexLinks();
  if (loading) {
    return /* @__PURE__ */ React__default.createElement(Progress, null);
  }
  if (error || data === void 0 || historicalScores === void 0) {
    return /* @__PURE__ */ React__default.createElement(WarningPanel, { severity: "error", title: "Could not load Scorecard scores." }, (_a = error == null ? void 0 : error.message) != null ? _a : "");
  }
  if (Object.values(data).length === 0) {
    const actionButton = hideLink ? void 0 : /* @__PURE__ */ React__default.createElement(
      Button,
      {
        variant: "contained",
        color: "primary",
        href: cortexScorecardPageUrl({
          scorecardId,
          cortexUrl: cortexBaseUrl
        })
      },
      "Go to Cortex"
    );
    return /* @__PURE__ */ React__default.createElement(
      EmptyState,
      {
        missing: "data",
        title: "Scorecard has not been evaluated yet.",
        description: "Wait until next Scorecard evaluation, or manually trigger from within Cortex.",
        action: actionButton
      }
    );
  }
  return /* @__PURE__ */ React__default.createElement(
    Timeseries,
    {
      data: Object.values(data),
      tooltip: (point) => {
        return /* @__PURE__ */ React__default.createElement(
          Box,
          {
            bgcolor: "background.paper",
            border: 1,
            borderRadius: "borderRadius",
            borderColor: "divider"
          },
          groupBy !== GroupByOption.ENTITY && /* @__PURE__ */ React__default.createElement(Typography, null, point.point.serieId),
          /* @__PURE__ */ React__default.createElement(Typography, null, /* @__PURE__ */ React__default.createElement(React__default.Fragment, null, moment.utc(point.point.data.x).fromNow(), ": \xA0", point.point.data.y, "%"))
        );
      }
    }
  );
};

export { AggregatedScorecardProgress };
//# sourceMappingURL=AggregatedScorecardProgress.esm.js.map
