import React__default, { useState, useCallback } from 'react';
import { WarningPanel, Content, ContentHeader, EmptyState } from '@backstage/core-components';
import { Grid, FormControl, InputLabel, Select, MenuItem } from '@material-ui/core';
import { ScorecardSelector } from '../ScorecardSelector.esm.js';
import { useDropdown, useCortexApi } from '../../../utils/hooks.esm.js';
import { Lookback } from '../../../utils/lookback.esm.js';
import { AggregatedScorecardProgress } from './AggregatedScorecardProgress.esm.js';
import { GroupByOption, ruleName } from '../../../api/types.esm.js';
import { SerieFilter } from './SerieFilter.esm.js';
import { GroupByDropdown } from '../Common/GroupByDropdown.esm.js';
import { LookbackDropdown } from '../Common/LookbackDropdown.esm.js';
import { useLocation, useNavigate, useSearchParams } from 'react-router-dom';
import { stringifyUrl } from 'query-string';

const defaultRule = {
  value: "DEFAULT_RULE_AVERAGE",
  label: "Average"
};
const ProgressPage = () => {
  var _a;
  const location = useLocation();
  const navigate = useNavigate();
  const [searchParams] = useSearchParams();
  const queryScorecardId = Number((_a = searchParams.get("scorecardId")) != null ? _a : void 0);
  const initialScorecardId = Number.isNaN(queryScorecardId) ? void 0 : queryScorecardId;
  const [selectedScorecardId, setSelectedScorecardId] = useState(initialScorecardId);
  const setSelectedScorecardIdAndNavigate = useCallback(
    (selectedScorecardId2) => {
      setSelectedScorecardId(selectedScorecardId2);
      const targetUrl = stringifyUrl({
        url: location.pathname,
        query: {
          scorecardId: selectedScorecardId2
        }
      });
      navigate(targetUrl, { replace: true });
    },
    [setSelectedScorecardId, location.pathname, navigate]
  );
  const [lookback, setLookback] = useDropdown(Lookback.MONTHS_1);
  const [groupBy, setGroupBy] = useState(GroupByOption.ENTITY);
  const [selectedRule, setSelectedRule] = useDropdown(
    defaultRule.value
  );
  const [filterOptions, setFilterOptions] = useState();
  const [filters, setFilters] = useState();
  const resetFilterOptions = useCallback(
    (o) => {
      setFilterOptions(o.length > 1 ? o : void 0);
      setFilters(void 0);
    },
    [setFilterOptions, setFilters]
  );
  const { value: scorecard, error } = useCortexApi(
    async (api) => selectedScorecardId ? await api.getScorecard(selectedScorecardId) : void 0,
    [selectedScorecardId]
  );
  const scorecardsResult = useCortexApi((api) => api.getScorecards());
  if (groupBy === GroupByOption.LEVEL || groupBy === GroupByOption.DOMAIN) {
    return /* @__PURE__ */ React__default.createElement(WarningPanel, { severity: "error", title: "Functionality not supported." }, "Group by for levels is not supported yet.");
  }
  if (error) {
    return /* @__PURE__ */ React__default.createElement(WarningPanel, { severity: "error", title: "Could not load Scorecard." }, error.message);
  }
  return /* @__PURE__ */ React__default.createElement(Content, null, /* @__PURE__ */ React__default.createElement(ContentHeader, { title: "Progress" }), /* @__PURE__ */ React__default.createElement(Grid, { container: true, direction: "column" }, /* @__PURE__ */ React__default.createElement(Grid, { item: true, lg: 12 }, /* @__PURE__ */ React__default.createElement(Grid, { container: true, direction: "row" }, /* @__PURE__ */ React__default.createElement(Grid, { item: true, lg: 8 }, /* @__PURE__ */ React__default.createElement(
    ScorecardSelector,
    {
      onSelect: setSelectedScorecardIdAndNavigate,
      selectedScorecardId,
      scorecardsResult,
      hideReset: true
    }
  )), /* @__PURE__ */ React__default.createElement(Grid, { item: true, lg: 4 }, /* @__PURE__ */ React__default.createElement(LookbackDropdown, { lookback, setLookback }))), /* @__PURE__ */ React__default.createElement(Grid, { container: true, style: { marginTop: "20px" } }, /* @__PURE__ */ React__default.createElement(Grid, { item: true, lg: 2 }, /* @__PURE__ */ React__default.createElement(GroupByDropdown, { groupBy, setGroupBy })), scorecard && /* @__PURE__ */ React__default.createElement(Grid, { item: true, lg: 10 }, /* @__PURE__ */ React__default.createElement(FormControl, null, /* @__PURE__ */ React__default.createElement(InputLabel, { style: { minWidth: "200px" } }, "Group By Rule"), /* @__PURE__ */ React__default.createElement(Select, { value: selectedRule, onChange: setSelectedRule }, /* @__PURE__ */ React__default.createElement(MenuItem, { value: defaultRule.value }, defaultRule.label), scorecard.rules.map((rule) => /* @__PURE__ */ React__default.createElement(MenuItem, { key: `Rule-${rule.id}`, value: rule.expression }, ruleName(rule)))))), filterOptions && /* @__PURE__ */ React__default.createElement(Grid, { item: true, lg: 12 }, /* @__PURE__ */ React__default.createElement(SerieFilter, { options: filterOptions, onSelect: setFilters })))), /* @__PURE__ */ React__default.createElement(Grid, { item: true, lg: 12 }, selectedScorecardId === void 0 ? /* @__PURE__ */ React__default.createElement(EmptyState, { title: "Select a Scorecard", missing: "data" }) : /* @__PURE__ */ React__default.createElement(
    AggregatedScorecardProgress,
    {
      scorecardId: selectedScorecardId,
      lookback,
      groupBy,
      setFilterOptions: resetFilterOptions,
      filters,
      ruleExpression: selectedRule === defaultRule.value ? void 0 : selectedRule
    }
  ))));
};

export { ProgressPage };
//# sourceMappingURL=ProgressPage.esm.js.map
