import React__default, { useMemo } from 'react';
import { Card, FormControl, InputLabel, Select, MenuItem } from '@material-ui/core';
import { Progress, WarningPanel } from '@backstage/core-components';

const ScorecardSelector = ({
  selectedScorecardId,
  onSelect,
  hideReset,
  scorecardsResult
}) => {
  const {
    value: scorecards,
    loading,
    error
  } = scorecardsResult;
  const sortedScorecards = useMemo(() => {
    var _a;
    return (_a = scorecards == null ? void 0 : scorecards.sort((a, b) => a.name.localeCompare(b.name))) != null ? _a : [];
  }, [scorecards]);
  const selected = useMemo(
    () => scorecards && scorecards.find((scorecard) => scorecard.id === selectedScorecardId),
    [scorecards, selectedScorecardId]
  );
  if (loading) {
    return /* @__PURE__ */ React__default.createElement(Progress, null);
  }
  if (error || scorecards === void 0) {
    return /* @__PURE__ */ React__default.createElement(WarningPanel, { severity: "error", title: "Could not load Scorecards." }, error == null ? void 0 : error.message);
  }
  return /* @__PURE__ */ React__default.createElement(Card, null, /* @__PURE__ */ React__default.createElement(FormControl, { variant: "standard" }, /* @__PURE__ */ React__default.createElement(InputLabel, null, "Select a Scorecard"), /* @__PURE__ */ React__default.createElement(
    Select,
    {
      value: selected == null ? void 0 : selected.id,
      onChange: (event) => onSelect(event.target.value)
    },
    sortedScorecards.map((scorecard) => /* @__PURE__ */ React__default.createElement(
      MenuItem,
      {
        key: `ScorecardOption-${scorecard.id}`,
        value: scorecard.id
      },
      scorecard.name
    )),
    hideReset !== true && /* @__PURE__ */ React__default.createElement(MenuItem, { value: void 0 }, "Reset")
  )));
};

export { ScorecardSelector };
//# sourceMappingURL=ScorecardSelector.esm.js.map
