import React__default, { useState, useCallback } from 'react';
import { CopyButton } from '../../Common/CopyButton.esm.js';
import FileCopyOutlinedIcon from '@material-ui/icons/FileCopy';
import { humanizeAnyEntityRef } from '../../../utils/types.esm.js';
import { defaultComponentRefContext } from '../../../utils/ComponentUtils.esm.js';
import { percentify } from '../../../utils/NumberUtils.esm.js';
import { toCsv } from '../../../utils/collections.esm.js';
import { Snackbar, IconButton } from '@material-ui/core';
import CloseIcon from '@material-ui/icons/Close';

const CopyCsvButton = ({ entitiesByTag, scores }) => {
  const [isSnackbarOpened, setOpenSnackbar] = useState(false);
  const getCsv = useCallback(() => {
    const getName = (score) => {
      var _a, _b;
      return (_b = (_a = entitiesByTag[score.componentRef]) == null ? void 0 : _a.name) != null ? _b : humanizeAnyEntityRef(score.componentRef, defaultComponentRefContext);
    };
    const rows = scores.sort((score1, score2) => score2.scorePercentage - score1.scorePercentage).map((score) => {
      var _a;
      return [
        `${getName(score)} (${(_a = entitiesByTag[score.componentRef]) == null ? void 0 : _a.codeTag})`,
        percentify(score.scorePercentage).toString()
      ];
    });
    rows.unshift(["Service", "Score"]);
    return toCsv(rows);
  }, [entitiesByTag, scores]);
  const handleSnackbarClose = (_event, reason) => {
    if (reason === "clickaway") {
      return;
    }
    setOpenSnackbar(false);
  };
  return /* @__PURE__ */ React__default.createElement(React__default.Fragment, null, /* @__PURE__ */ React__default.createElement(
    CopyButton,
    {
      textToCopy: getCsv,
      "aria-label": "Copy scores",
      onSuccess: () => setOpenSnackbar(true)
    },
    /* @__PURE__ */ React__default.createElement(FileCopyOutlinedIcon, null),
    "\xA0Copy scores"
  ), /* @__PURE__ */ React__default.createElement(
    Snackbar,
    {
      anchorOrigin: {
        vertical: "bottom",
        horizontal: "left"
      },
      open: isSnackbarOpened,
      autoHideDuration: 6e3,
      onClose: handleSnackbarClose,
      message: "Successfully copied text!",
      action: /* @__PURE__ */ React__default.createElement(React__default.Fragment, null, /* @__PURE__ */ React__default.createElement(
        IconButton,
        {
          size: "small",
          "aria-label": "close",
          color: "inherit",
          onClick: (event) => handleSnackbarClose()
        },
        /* @__PURE__ */ React__default.createElement(CloseIcon, { fontSize: "small" })
      ))
    }
  ));
};

export { CopyCsvButton as default };
//# sourceMappingURL=CopyCsvButton.esm.js.map
