import { Content } from '@backstage/core-components';
import React__default, { useState, useMemo } from 'react';
import { Grid, Box, Tabs, Tab, Button } from '@material-ui/core';
import { ScorecardMetadataCard } from './ScorecardMetadataCard/ScorecardMetadataCard.esm.js';
import { ScorecardScoresRulesCard } from './ScorecardRulesTab/ScorecardScoresRulesCard.esm.js';
import { ScorecardLadderRulesCard } from './ScorecardRulesTab/ScorecardLadderRulesCard.esm.js';
import { ScorecardLadderStatsCard } from './ScorecardStatsCard/ScorecardLadderStatsCard.esm.js';
import { ScorecardScoresStatsCard } from './ScorecardStatsCard/ScorecardScoresStatsCard.esm.js';
import CopyCsvButton from './CopyCsvButton.esm.js';
import { ScorecardReportsTab } from './ScorecardReportsTab/ScorecardReportsTab.esm.js';
import { ScorecardFilterDialogWrapper } from './ScorecardFilterDialog/ScorecardFilterDialog.esm.js';
import { getEntityCategoryFromFilter } from './ScorecardMetadataCard/ScorecardMetadataUtils.esm.js';
import { ScorecardRuleExemptionsTab } from './ScorecardRuleExemptionsTab/ScorecardRuleExemptionsTab.esm.js';
import { ScorecardsScoresTable } from './ScorecardsScoresTab/ScorecardsScoresTable.esm.js';

const ScorecardDetails = ({
  entitiesByTag,
  ladder,
  scorecard,
  scores,
  ruleExemptions
}) => {
  const [activeTab, setActiveTab] = useState("Scores" /* Scores */);
  const [isFilterDialogOpen, setIsFilterDialogOpen] = useState(false);
  const entityCategory = getEntityCategoryFromFilter(scorecard.filter);
  const [filter, setFilter] = useState(
    () => () => true
  );
  const filteredScores = useMemo(() => {
    return scores.filter(filter);
  }, [scores, filter]);
  const handleTabChange = (_event, newValue) => {
    setActiveTab(newValue);
  };
  const renderTab = (tabName) => {
    switch (tabName) {
      case "Scores" /* Scores */:
        return /* @__PURE__ */ React__default.createElement(
          ScorecardsScoresTable,
          {
            category: entityCategory != null ? entityCategory : "entity",
            entitiesByTag,
            scorecardId: scorecard.id,
            scores: filteredScores,
            ladder
          }
        );
      case "Rules" /* Rules */:
        return ladder ? /* @__PURE__ */ React__default.createElement(ScorecardLadderRulesCard, { ladder }) : /* @__PURE__ */ React__default.createElement(ScorecardScoresRulesCard, { scorecard });
      case "Reports" /* Reports */:
        return /* @__PURE__ */ React__default.createElement(ScorecardReportsTab, { scorecard });
      case "Rule Exemptions" /* RuleExemptions */:
        return /* @__PURE__ */ React__default.createElement(
          ScorecardRuleExemptionsTab,
          {
            entitiesByTag,
            ruleExemptions,
            scorecard,
            scores
          }
        );
    }
  };
  const handleFilterDialogClose = () => {
    setIsFilterDialogOpen(false);
  };
  return /* @__PURE__ */ React__default.createElement(Content, null, /* @__PURE__ */ React__default.createElement(Grid, { container: true, direction: "row", spacing: 1 }, /* @__PURE__ */ React__default.createElement(Grid, { item: true, lg: 5, xs: 12 }, /* @__PURE__ */ React__default.createElement(ScorecardMetadataCard, { scorecard, scores })), /* @__PURE__ */ React__default.createElement(Grid, { item: true, lg: 7, xs: 12 }, /* @__PURE__ */ React__default.createElement(Box, { display: "flex", flexDirection: "column" }, ladder ? /* @__PURE__ */ React__default.createElement(
    ScorecardLadderStatsCard,
    {
      entityCategory: entityCategory ? `${entityCategory}s` : "Entities",
      scores: filteredScores,
      scorecardLadder: ladder
    }
  ) : /* @__PURE__ */ React__default.createElement(
    ScorecardScoresStatsCard,
    {
      scores: filteredScores,
      entityCategory: entityCategory ? `${entityCategory}s` : "Entities"
    }
  )))), /* @__PURE__ */ React__default.createElement(Box, { display: "flex", justifyContent: "space-between", alignItems: "center" }, /* @__PURE__ */ React__default.createElement(
    Tabs,
    {
      value: activeTab,
      indicatorColor: "primary",
      textColor: "primary",
      onChange: handleTabChange
    },
    /* @__PURE__ */ React__default.createElement(
      Tab,
      {
        label: "Scores" /* Scores */,
        value: "Scores" /* Scores */
      }
    ),
    /* @__PURE__ */ React__default.createElement(
      Tab,
      {
        label: "Rules" /* Rules */,
        value: "Rules" /* Rules */
      }
    ),
    /* @__PURE__ */ React__default.createElement(
      Tab,
      {
        label: "Reports" /* Reports */,
        value: "Reports" /* Reports */
      }
    ),
    /* @__PURE__ */ React__default.createElement(
      Tab,
      {
        label: "Rule Exemptions" /* RuleExemptions */,
        value: "Rule Exemptions" /* RuleExemptions */
      }
    )
  ), activeTab === "Scores" /* Scores */ && /* @__PURE__ */ React__default.createElement(Box, { display: "flex", flexDirection: "row", gridGap: 8 }, /* @__PURE__ */ React__default.createElement(
    Button,
    {
      onClick: () => setIsFilterDialogOpen(true),
      variant: "outlined",
      "aria-label": "Filter"
    },
    "filter"
  ), /* @__PURE__ */ React__default.createElement(CopyCsvButton, { entitiesByTag, scores }))), /* @__PURE__ */ React__default.createElement(Box, { my: 1 }, renderTab(activeTab)), /* @__PURE__ */ React__default.createElement(
    ScorecardFilterDialogWrapper,
    {
      isOpen: isFilterDialogOpen,
      handleClose: handleFilterDialogClose,
      scorecard,
      setFilter: (filter2) => setFilter(() => filter2),
      ladder
    }
  ));
};

export { ScorecardDetails };
//# sourceMappingURL=ScorecardDetails.esm.js.map
