import React__default from 'react';
import { useRouteRefParams, useApi } from '@backstage/core-plugin-api';
import { scorecardRouteRef } from '../../../routes.esm.js';
import { cortexApiRef } from '../../../api/CortexClient.esm.js';
import { useAsync } from 'react-use';
import { Progress, WarningPanel } from '@backstage/core-components';
import { ScorecardDetails } from './ScorecardDetails.esm.js';
import { useEntitiesByTag } from '../../../utils/hooks.esm.js';

const ScorecardDetailsPage = () => {
  var _a;
  const { id: scorecardId } = useRouteRefParams(scorecardRouteRef);
  const cortexApi = useApi(cortexApiRef);
  const { value, loading, error } = useAsync(async () => {
    const [ladders2, scorecard2, scores2, ruleExemptions2] = await Promise.all([
      cortexApi.getScorecardLadders(+scorecardId),
      cortexApi.getScorecard(+scorecardId),
      cortexApi.getScorecardScores(+scorecardId),
      cortexApi.getScorecardRuleExemptions(+scorecardId)
    ]);
    return { ladders: ladders2, scorecard: scorecard2, scores: scores2, ruleExemptions: ruleExemptions2 };
  }, []);
  const { ladders, scorecard, scores, ruleExemptions } = value != null ? value : {
    ladders: [],
    scorecard: void 0,
    scores: void 0,
    ruleExemptions: { scorecardRuleExemptions: {} }
  };
  const { entitiesByTag, loading: loadingEntities } = useEntitiesByTag();
  if (loading || loadingEntities) {
    return /* @__PURE__ */ React__default.createElement(Progress, null);
  }
  if (error || scorecard === void 0 || scores === void 0) {
    return /* @__PURE__ */ React__default.createElement(WarningPanel, { severity: "error", title: "Could not load Scorecard." }, (_a = error == null ? void 0 : error.message) != null ? _a : "");
  }
  const ladder = ladders == null ? void 0 : ladders[0];
  return /* @__PURE__ */ React__default.createElement(
    ScorecardDetails,
    {
      entitiesByTag,
      ladder,
      scorecard,
      scores,
      ruleExemptions: ruleExemptions.scorecardRuleExemptions
    }
  );
};

export { ScorecardDetailsPage };
//# sourceMappingURL=ScorecardDetailsPage.esm.js.map
