import { RELATION_OWNED_BY, parseEntityRef, RELATION_PART_OF } from '@backstage/catalog-model';
import { getEntityRelations, humanizeEntityRef } from '@backstage/plugin-catalog-react';
import { defaultGroupRefContext, defaultSystemRefContext } from '../../../../utils/ComponentUtils.esm.js';
import { isNotApplicableRuleOutcome, isNotEvaluatedRuleOutcome, isApplicableRuleOutcome } from '../../../../utils/ScorecardRules.esm.js';
import { stringifyAnyEntityRef } from '../../../../utils/types.esm.js';
import { isEmpty, isNil } from 'lodash';

const createLevelPredicate = (levelId) => {
  return (score) => {
    var _a;
    if (isEmpty(levelId)) {
      return isNil(score.ladderLevels[0].currentLevel);
    }
    return ((_a = score.ladderLevels[0].currentLevel) == null ? void 0 : _a.id.toString()) === levelId;
  };
};
const createExemptRulePredicate = (ruleExpression) => {
  return (score) => {
    return isNotApplicableRuleOutcome(
      score.rules.find((rule) => ruleExpression === rule.rule.expression)
    );
  };
};
const createNotEvaluatedRulePredicate = (ruleExpression) => {
  return (score) => {
    return isNotEvaluatedRuleOutcome(
      score.rules.find((rule) => ruleExpression === rule.rule.expression)
    );
  };
};
const createApplicableRulePredicate = (pass, ruleExpression) => {
  return (score) => {
    var _a;
    const rule = (_a = score == null ? void 0 : score.rules) == null ? void 0 : _a.find(
      (rule2) => ruleExpression === rule2.rule.expression
    );
    if (isApplicableRuleOutcome(rule)) {
      const rulePassed = rule.score > 0;
      return rulePassed === pass;
    }
    return false;
  };
};
const groupAndSystemFilters = [
  {
    name: "Groups",
    groupProperty: (entity) => getEntityRelations(entity, RELATION_OWNED_BY, {
      kind: "group"
    }).map(
      (entityRef) => stringifyAnyEntityRef(entityRef, { defaultKind: "group" })
    ),
    formatProperty: (groupRef) => humanizeEntityRef(parseEntityRef(groupRef), defaultGroupRefContext)
  },
  {
    name: "Systems",
    groupProperty: (entity) => getEntityRelations(entity, RELATION_PART_OF, {
      kind: "system"
    }).map(
      (entityRef) => stringifyAnyEntityRef(entityRef, { defaultKind: "system" })
    ),
    formatProperty: (groupRef) => humanizeEntityRef(parseEntityRef(groupRef), defaultSystemRefContext)
  }
];
const toPredicateFilters = (filters, name) => {
  const predicateFilters = {};
  Object.keys(filters).filter((key) => key.includes(name)).forEach((key) => {
    const newKey = key.replace(name, "");
    predicateFilters[newKey] = filters[key];
  });
  return predicateFilters;
};

export { createApplicableRulePredicate, createExemptRulePredicate, createLevelPredicate, createNotEvaluatedRulePredicate, groupAndSystemFilters, toPredicateFilters };
//# sourceMappingURL=ScorecardFilterDialogUtils.esm.js.map
