import React__default from 'react';
import { makeStyles, Box, Typography } from '@material-ui/core';
import moment from 'moment';
import { MarkdownContent } from '@backstage/core-components';
import { CortexInfoCard } from '../../../Common/CortexInfoCard.esm.js';
import { HoverTimestamp } from '../../../Common/HoverTimestamp.esm.js';
import ScorecardMetadataFilter from './ScorecardMetadataFilter.esm.js';
import { CaptionTypography } from '../../../Common/StatsItem.esm.js';
import { Truncated } from '../../../Common/Truncated.esm.js';

const useScorecardMetadataCardStyles = makeStyles((theme) => ({
  markdownBox: {
    "& p": {
      marginTop: theme.spacing(1),
      marginBottom: theme.spacing(1)
    },
    "& p:first-child": {
      marginTop: 0
    },
    "& p:last-child": {
      marginBottom: 0
    }
  }
}));
const ScorecardMetadataCard = ({
  scorecard,
  scores
}) => {
  const classes = useScorecardMetadataCardStyles();
  const lastUpdated = scores.length === 0 ? void 0 : moment.max(scores.map((score) => moment.utc(score.lastUpdated).local()));
  const nextUpdated = scorecard.nextUpdated ? moment.utc(scorecard.nextUpdated) : void 0;
  return /* @__PURE__ */ React__default.createElement(
    CortexInfoCard,
    {
      title: /* @__PURE__ */ React__default.createElement(Box, { display: "flex", flexDirection: "column" }, /* @__PURE__ */ React__default.createElement(Typography, { variant: "h6" }, scorecard.name), /* @__PURE__ */ React__default.createElement(Typography, { variant: "subtitle2" }, scorecard.tag))
    },
    /* @__PURE__ */ React__default.createElement(Box, { display: "flex", flexDirection: "column" }, scorecard.description && /* @__PURE__ */ React__default.createElement(Box, { mb: 2, className: classes.markdownBox }, /* @__PURE__ */ React__default.createElement(CaptionTypography, { variant: "caption" }, "Description"), /* @__PURE__ */ React__default.createElement(
      Truncated,
      {
        text: scorecard.description,
        truncateToLines: 10,
        renderText: (text) => /* @__PURE__ */ React__default.createElement(MarkdownContent, { content: text })
      }
    )), /* @__PURE__ */ React__default.createElement(Box, { mb: 2 }, /* @__PURE__ */ React__default.createElement(CaptionTypography, { variant: "caption" }, "Filter"), /* @__PURE__ */ React__default.createElement(ScorecardMetadataFilter, { scorecard })), (lastUpdated || nextUpdated) && /* @__PURE__ */ React__default.createElement(CaptionTypography, { variant: "caption" }, "Evaluation"), lastUpdated && /* @__PURE__ */ React__default.createElement(Typography, { component: "span", variant: "caption" }, "Updated ", /* @__PURE__ */ React__default.createElement(HoverTimestamp, { ts: lastUpdated })), nextUpdated && /* @__PURE__ */ React__default.createElement(Typography, { component: "span", variant: "caption" }, "Next Evaluation ", /* @__PURE__ */ React__default.createElement(HoverTimestamp, { ts: nextUpdated })))
  );
};

export { ScorecardMetadataCard };
//# sourceMappingURL=ScorecardMetadataCard.esm.js.map
