import React__default, { useMemo } from 'react';
import { FilterType } from '../../../../api/types.esm.js';
import { makeStyles, Typography } from '@material-ui/core';
import { isEmpty, isNil } from 'lodash';
import { isNotNullOrEmpty, joinWithAnds } from '../../../../utils/strings.esm.js';
import { getEntityCategoryFromFilter, getEntityGroupsFromFilter, getResourceTypesFromFilter, getQueryFromFilter } from './ScorecardMetadataUtils.esm.js';

const useStyles = makeStyles(() => ({
  ruleQuery: {
    fontFamily: "Monospace",
    fontSize: 12
  }
}));
const ScorecardMetadataFilter = ({
  scorecard
}) => {
  var _a, _b, _c, _d;
  const classes = useStyles();
  const { filter } = scorecard;
  const entityCategory = getEntityCategoryFromFilter(filter);
  const { entityGroups, excludeEntityGroups } = useMemo(() => {
    return getEntityGroupsFromFilter(filter);
  }, [filter]);
  const { include: includingResourceTypes, types: resourceTypes } = useMemo(() => {
    return getResourceTypesFromFilter(filter);
  }, [filter]);
  const cqlQuery = useMemo(() => {
    return getQueryFromFilter(filter);
  }, [filter]);
  const hasFilter = useMemo(() => {
    return !isEmpty(entityGroups) || !isEmpty(excludeEntityGroups) || isNotNullOrEmpty(cqlQuery) || !isEmpty(resourceTypes);
  }, [cqlQuery, excludeEntityGroups, entityGroups, resourceTypes]);
  if (!hasFilter) {
    return /* @__PURE__ */ React__default.createElement(Typography, { variant: "body2" }, "Applies to all ", (_a = entityCategory == null ? void 0 : entityCategory.toLowerCase()) != null ? _a : "entitie", "s");
  }
  if (!isNil(cqlQuery)) {
    return /* @__PURE__ */ React__default.createElement(Typography, { variant: "body2" }, "Applies to all ", (_b = entityCategory == null ? void 0 : entityCategory.toLowerCase()) != null ? _b : "entitie", "s matching", " ", /* @__PURE__ */ React__default.createElement(
      Typography,
      {
        variant: "body2",
        component: "span",
        className: classes.ruleQuery
      },
      cqlQuery
    ));
  }
  if (!isEmpty(resourceTypes)) {
    return /* @__PURE__ */ React__default.createElement(Typography, { variant: "body2" }, "Applies to ", (filter == null ? void 0 : filter.type) === FilterType.COMPOUND_FILTER ? "entities" : "resources", " ", includingResourceTypes ? "of type " : "excluding types ", joinWithAnds(resourceTypes), (!isEmpty(entityGroups) || !isEmpty(excludeEntityGroups)) && /* @__PURE__ */ React__default.createElement(React__default.Fragment, null, " ", "in ", isEmpty(entityGroups) && " all ", " groups", " ", !isEmpty(entityGroups) && joinWithAnds(entityGroups), !isEmpty(excludeEntityGroups) && /* @__PURE__ */ React__default.createElement(React__default.Fragment, null, ", excluding ", joinWithAnds(excludeEntityGroups))));
  }
  return /* @__PURE__ */ React__default.createElement(Typography, { variant: "body2" }, isEmpty(entityGroups) ? "All" : /* @__PURE__ */ React__default.createElement(React__default.Fragment, null, "Applies to ", joinWithAnds(entityGroups)), " ", (_c = entityCategory == null ? void 0 : entityCategory.toLowerCase()) != null ? _c : "entitie", "s", !isEmpty(excludeEntityGroups) && /* @__PURE__ */ React__default.createElement(React__default.Fragment, null, ", excluding ", (_d = entityCategory == null ? void 0 : entityCategory.toLowerCase()) != null ? _d : "entitie", "s in", " ", joinWithAnds(excludeEntityGroups)));
};

export { ScorecardMetadataFilter as default };
//# sourceMappingURL=ScorecardMetadataFilter.esm.js.map
