import { makeStyles, Box, Typography } from '@material-ui/core';
import classNames from 'classnames';
import React__default from 'react';
import { ExemptionStatusResponseType } from '../../../../api/types.esm.js';
import { fallbackPalette } from '../../../../styles/styles.esm.js';

const useRuleExemptionStyles = makeStyles((theme) => ({
  root: {
    display: "block",
    width: 100,
    padding: theme.spacing(0.5, 1),
    marginRight: theme.spacing(1)
  },
  pending: {
    backgroundColor: fallbackPalette.common.grayLight
  },
  approved: {
    backgroundColor: fallbackPalette.common.orange[100]
  },
  text: {
    color: fallbackPalette.common.black
  }
}));
const typeToNameMap = {
  [ExemptionStatusResponseType.APPROVED]: "Exempt",
  [ExemptionStatusResponseType.PENDING]: "Requested",
  [ExemptionStatusResponseType.REJECTED]: "Rejected"
};
const RuleExemptionStatus = ({
  type
}) => {
  const classes = useRuleExemptionStyles();
  return /* @__PURE__ */ React__default.createElement(
    Box,
    {
      className: classNames(classes.root, {
        [classes.approved]: type === ExemptionStatusResponseType.APPROVED,
        [classes.pending]: type === ExemptionStatusResponseType.PENDING
      })
    },
    /* @__PURE__ */ React__default.createElement(Typography, { variant: "body2", className: classes.text }, typeToNameMap[type])
  );
};

export { RuleExemptionStatus };
//# sourceMappingURL=RuleExemptionStatus.esm.js.map
