import React__default, { useMemo } from 'react';
import { makeStyles, Box, Typography, Tooltip } from '@material-ui/core';
import { getRuleTitle } from '../../../../utils/ScorecardRules.esm.js';
import { RuleExemptionStatus } from './RuleExemptionStatus.esm.js';
import { CortexInfoCard } from '../../../Common/CortexInfoCard.esm.js';
import { getIsActive, getExpirationText } from './ScorecardRuleExemptionsTabUtils.esm.js';
import ScorecardRuleExemptionTooltip from './ScorecardRuleExemptionTooltip.esm.js';
import { ScorecardServiceRefLink } from '../../../ScorecardServiceRefLink/ScorecardServiceRefLink.esm.js';
import { isEmpty } from 'lodash';
import { entityComponentRef } from '../../../../utils/ComponentUtils.esm.js';

const useRuleExemptionsTabStyles = makeStyles(() => ({
  text: {
    fontWeight: 600
  }
}));
const ScorecardRuleExemptionsTab = ({
  entitiesByTag,
  ruleExemptions = {},
  scorecard,
  scores
}) => {
  const classes = useRuleExemptionsTabStyles();
  const rulesMap = useMemo(
    () => scorecard.rules.reduce((acc, rule) => {
      acc[rule.id] = getRuleTitle(rule);
      return acc;
    }, {}),
    [scorecard.rules]
  );
  const scoresMap = useMemo(
    () => scores.reduce(
      (acc, score) => {
        acc[score.serviceId] = score.componentRef;
        return acc;
      },
      {}
    ),
    [scores]
  );
  return /* @__PURE__ */ React__default.createElement(CortexInfoCard, null, /* @__PURE__ */ React__default.createElement(Box, { display: "flex", flexDirection: "column" }, isEmpty(ruleExemptions) ? /* @__PURE__ */ React__default.createElement(Typography, { variant: "body2" }, "No rule exemptions found for this Scorecard.") : Object.entries(ruleExemptions).map(([id, ruleExemptionById]) => {
    return /* @__PURE__ */ React__default.createElement(React__default.Fragment, { key: `RuleExemption-${id}` }, ruleExemptionById.filter(getIsActive).map((ruleExemption) => {
      var _a;
      const entityTag = (_a = scoresMap[ruleExemption.entityId]) != null ? _a : "";
      return /* @__PURE__ */ React__default.createElement(
        Tooltip,
        {
          key: `RuleExemption-${id}-${ruleExemption.id}`,
          title: /* @__PURE__ */ React__default.createElement(
            ScorecardRuleExemptionTooltip,
            {
              exemption: ruleExemption
            }
          ),
          placement: "bottom-start"
        },
        /* @__PURE__ */ React__default.createElement(
          Box,
          {
            display: "flex",
            flexDirection: "row",
            alignItems: "center",
            justifyContent: "space-between",
            mb: 1
          },
          /* @__PURE__ */ React__default.createElement(
            Box,
            {
              display: "flex",
              flexDirection: "row",
              alignItems: "center"
            },
            /* @__PURE__ */ React__default.createElement(
              RuleExemptionStatus,
              {
                type: ruleExemption.status.type
              }
            ),
            /* @__PURE__ */ React__default.createElement(Typography, { variant: "body2" }, /* @__PURE__ */ React__default.createElement(
              Typography,
              {
                variant: "body2",
                component: "span",
                className: classes.text
              },
              rulesMap[ruleExemption.ruleId]
            ), " ", "for", " ", entityTag ? /* @__PURE__ */ React__default.createElement(
              ScorecardServiceRefLink,
              {
                scorecardId: scorecard.id,
                componentRef: entityComponentRef(
                  entitiesByTag,
                  entityTag
                )
              },
              ruleExemption.entityName
            ) : ruleExemption.entityName)
          ),
          /* @__PURE__ */ React__default.createElement(Typography, { variant: "body2" }, getExpirationText(ruleExemption))
        )
      );
    }));
  })));
};

export { ScorecardRuleExemptionsTab };
//# sourceMappingURL=ScorecardRuleExemptionsTab.esm.js.map
