import { isNil, capitalize } from 'lodash';
import { ExemptionStatusResponseType } from '../../../../api/types.esm.js';
import { maybePluralize } from '../../../../utils/strings.esm.js';
import { daysUntil, getFormattedDate } from '../../../../utils/MomentUtils.esm.js';

const getExpiresInDays = (exemption) => {
  return !isNil(exemption.endDate) ? daysUntil(exemption.endDate) : void 0;
};
const getExpirationText = (exemption) => {
  const expiresInDays = getExpiresInDays(exemption);
  return !isNil(expiresInDays) ? `Expires in ${maybePluralize(expiresInDays, "day")}` : "Permanent";
};
const getExemptionActionDetailsText = (action, user, date, capitalized = true) => {
  return `${capitalized ? capitalize(action) : action} ${getFormattedDate(
    date
  )} by ${user}`;
};
const getExemptionRequestedDetailsText = (exemption) => {
  return getExemptionActionDetailsText(
    "requested",
    exemption.requestedBy,
    exemption.requestedDate
  );
};
const getExemptionApprovedDetailsText = (exemption, capitalized = true) => {
  if (exemption.status.type !== ExemptionStatusResponseType.APPROVED) {
    return void 0;
  }
  return getExemptionActionDetailsText(
    "approved",
    exemption.status.approvedBy,
    exemption.status.approvedDate,
    capitalized
  );
};
const getExemptionRejectedDetailsText = (exemption, capitalized = true) => {
  if (exemption.status.type !== ExemptionStatusResponseType.REJECTED) {
    return void 0;
  }
  return getExemptionActionDetailsText(
    "rejected",
    exemption.status.rejectedBy,
    exemption.status.rejectedDate,
    capitalized
  );
};
const getIsExpired = (exemption) => {
  if (exemption.endDate === null)
    return false;
  const remainingDays = daysUntil(exemption.endDate);
  return !isNil(remainingDays) && remainingDays < 0;
};
const getIsActive = (exemption) => {
  return !getIsExpired(exemption) && exemption.status.type !== ExemptionStatusResponseType.REJECTED;
};
const isRejectedStatus = (status) => {
  return status.type === ExemptionStatusResponseType.REJECTED;
};

export { getExemptionApprovedDetailsText, getExemptionRejectedDetailsText, getExemptionRequestedDetailsText, getExpirationText, getExpiresInDays, getIsActive, getIsExpired, isRejectedStatus };
//# sourceMappingURL=ScorecardRuleExemptionsTabUtils.esm.js.map
