import React__default, { useMemo } from 'react';
import { makeStyles, alpha, Box, Grid } from '@material-ui/core';
import { fallbackPalette } from '../../../../styles/styles.esm.js';
import { CortexInfoCard } from '../../../Common/CortexInfoCard.esm.js';
import { ScorecardLadderLevelBadge } from '../../../Common/ScorecardLadderLevelBadge.esm.js';
import { ScorecardRuleRow } from './ScorecardRuleRow.esm.js';

const useCortexInfoCardStyles = makeStyles(() => ({
  levelBlock: {
    padding: 16,
    borderBottom: `1px solid ${alpha(fallbackPalette.common.white, 0.12)}`,
    "&:last-child": {
      borderBottom: "none"
    }
  }
}));
const ScorecardLadderRulesCard = ({
  ladder
}) => {
  const classes = useCortexInfoCardStyles();
  const sortedLevels = useMemo(
    () => ladder.levels.sort((level1, level2) => level2.rank - level1.rank),
    [ladder]
  );
  return /* @__PURE__ */ React__default.createElement(CortexInfoCard, { padding: "dense" }, sortedLevels.map((level) => /* @__PURE__ */ React__default.createElement(
    Box,
    {
      key: `ScorecardLadderRow-${level.id}`,
      className: classes.levelBlock
    },
    /* @__PURE__ */ React__default.createElement(Grid, { container: true, spacing: 0 }, /* @__PURE__ */ React__default.createElement(Grid, { item: true, md: 2, xs: 3 }, /* @__PURE__ */ React__default.createElement(
      ScorecardLadderLevelBadge,
      {
        showName: true,
        name: level.name,
        color: level.color
      }
    )), /* @__PURE__ */ React__default.createElement(Grid, { item: true, md: 10, xs: 9 }, /* @__PURE__ */ React__default.createElement(Box, { display: "flex", flexDirection: "column" }, level.rules.map((rule) => /* @__PURE__ */ React__default.createElement(
      ScorecardRuleRow,
      {
        key: `ScorecardRuleRowNew-${rule.id}`,
        rule
      }
    )))))
  )));
};

export { ScorecardLadderRulesCard, useCortexInfoCardStyles };
//# sourceMappingURL=ScorecardLadderRulesCard.esm.js.map
