import { ruleName } from '../../../../api/types.esm.js';
import { fallbackPalette } from '../../../../styles/styles.esm.js';
import React__default, { useState } from 'react';
import { makeStyles, Box, IconButton, Typography, Collapse } from '@material-ui/core';
import KeyboardArrowDownIcon from '@material-ui/icons/KeyboardArrowDown';
import KeyboardArrowRight from '@material-ui/icons/KeyboardArrowRight';
import { MarkdownContent } from '@backstage/core-components';

const useStyles = makeStyles((theme) => ({
  root: {
    display: "flex",
    flexDirection: "row",
    justifyContent: "space-between",
    marginBottom: theme.spacing(1),
    "&:last-child": {
      marginBottom: 0
    }
  },
  expandIcon: {
    padding: 0
  },
  ruleDescription: {
    margin: theme.spacing(1, 0),
    color: fallbackPalette.common.gray,
    "& p": {
      margin: 0
    }
  },
  ruleQuery: {
    fontFamily: "Monospace",
    fontSize: 12
  }
}));
const ScorecardRuleRow = ({ rule }) => {
  const [open, setOpen] = useState(false);
  const classes = useStyles();
  const showExpandButton = rule.description || rule.filter || rule.expression;
  const hasWeight = "weight" in rule;
  return /* @__PURE__ */ React__default.createElement(Box, { className: classes.root }, /* @__PURE__ */ React__default.createElement(Box, { display: "flex", flexDirection: "row" }, /* @__PURE__ */ React__default.createElement(Box, null, showExpandButton && /* @__PURE__ */ React__default.createElement(
    IconButton,
    {
      size: "small",
      onClick: () => setOpen(!open),
      className: classes.expandIcon
    },
    open ? /* @__PURE__ */ React__default.createElement(KeyboardArrowDownIcon, null) : /* @__PURE__ */ React__default.createElement(KeyboardArrowRight, null)
  )), /* @__PURE__ */ React__default.createElement(Box, null, /* @__PURE__ */ React__default.createElement(Box, { display: "flex", flexDirection: "row" }, hasWeight && /* @__PURE__ */ React__default.createElement(Box, { ml: 2, mr: 1.5 }, /* @__PURE__ */ React__default.createElement(Typography, { variant: "subtitle2" }, rule.weight, " pt")), /* @__PURE__ */ React__default.createElement(Typography, { variant: "subtitle2" }, ruleName(rule))), /* @__PURE__ */ React__default.createElement(Collapse, { in: open, timeout: "auto", unmountOnExit: true }, /* @__PURE__ */ React__default.createElement(Box, { ml: 2 }, rule.description && /* @__PURE__ */ React__default.createElement(
    MarkdownContent,
    {
      className: classes.ruleDescription,
      content: rule.description
    }
  ), rule.expression && /* @__PURE__ */ React__default.createElement(Typography, { variant: "caption", className: classes.ruleQuery }, rule.expression), rule.filter && "query" in rule.filter && /* @__PURE__ */ React__default.createElement(Typography, { variant: "overline" }, rule.filter.query))))));
};

export { ScorecardRuleRow };
//# sourceMappingURL=ScorecardRuleRow.esm.js.map
