import React__default, { useMemo } from 'react';
import { makeStyles, Paper, Box, Typography } from '@material-ui/core';
import { isEmpty, isNil } from 'lodash';
import { median } from 'simple-statistics';
import Stats from '../../../Common/Stats.esm.js';
import StatsItem, { CaptionTypography } from '../../../Common/StatsItem.esm.js';
import { safeDivide } from '../../../../utils/NumberUtils.esm.js';
import { ScorecardLadderLevelBadge } from '../../../Common/ScorecardLadderLevelBadge.esm.js';

const useStyles = makeStyles((theme) => ({
  levelBox: {
    display: "flex",
    flexDirection: "row",
    gap: theme.spacing(0.5),
    alignItems: "center"
  }
}));
const ScorecardLadderStatsCard = ({
  entityCategory,
  scores,
  scorecardLadder
}) => {
  var _a;
  const classes = useStyles();
  const numberOfEntities = scores.length;
  const medianLevel = useMemo(() => {
    const levelRanks = scores.map(
      (score) => {
        var _a2, _b, _c, _d;
        return (_d = (_c = (_b = (_a2 = score.ladderLevels) == null ? void 0 : _a2[0]) == null ? void 0 : _b.currentLevel) == null ? void 0 : _c.rank) != null ? _d : 0;
      }
    );
    const medianLevelRank = !isEmpty(levelRanks) ? median(levelRanks) : 0;
    return scorecardLadder.levels.find((level) => level.rank === medianLevelRank);
  }, [scores, scorecardLadder]);
  const percentAtHighestLevel = useMemo(() => {
    return safeDivide(
      scores.filter((score) => {
        var _a2, _b;
        return isNil((_b = (_a2 = score.ladderLevels) == null ? void 0 : _a2[0]) == null ? void 0 : _b.nextLevel);
      }).length,
      numberOfEntities
    );
  }, [scores, numberOfEntities]);
  const percentNoLevel = useMemo(() => {
    return safeDivide(
      scores.filter((score) => {
        var _a2, _b;
        return isNil((_b = (_a2 = score.ladderLevels) == null ? void 0 : _a2[0]) == null ? void 0 : _b.currentLevel);
      }).length,
      numberOfEntities
    );
  }, [scores, numberOfEntities]);
  return /* @__PURE__ */ React__default.createElement(Paper, { elevation: 0, style: { marginBottom: 8 } }, /* @__PURE__ */ React__default.createElement(Stats, null, /* @__PURE__ */ React__default.createElement(Box, { display: "flex", flexDirection: "column" }, /* @__PURE__ */ React__default.createElement(CaptionTypography, { variant: "caption" }, "Level"), /* @__PURE__ */ React__default.createElement(Box, { className: classes.levelBox }, /* @__PURE__ */ React__default.createElement(
    ScorecardLadderLevelBadge,
    {
      name: medianLevel == null ? void 0 : medianLevel.name,
      color: medianLevel == null ? void 0 : medianLevel.color
    }
  ), /* @__PURE__ */ React__default.createElement(Typography, { variant: "body1" }, (_a = medianLevel == null ? void 0 : medianLevel.name) != null ? _a : "No Level"))), /* @__PURE__ */ React__default.createElement(
    StatsItem,
    {
      caption: "% at highest level",
      percentage: true,
      type: "PERCENTAGE",
      value: percentAtHighestLevel
    }
  ), /* @__PURE__ */ React__default.createElement(
    StatsItem,
    {
      caption: "% without level",
      percentage: true,
      type: "PERCENTAGE",
      value: percentNoLevel
    }
  ), /* @__PURE__ */ React__default.createElement(
    StatsItem,
    {
      caption: entityCategory,
      type: "NONE",
      value: numberOfEntities
    }
  )));
};

export { ScorecardLadderStatsCard };
//# sourceMappingURL=ScorecardLadderStatsCard.esm.js.map
