import React__default, { useMemo } from 'react';
import { Paper } from '@material-ui/core';
import { isEmpty, round, mean } from 'lodash';
import { quantileSorted, median } from 'simple-statistics';
import Stats from '../../../Common/Stats.esm.js';
import StatsItem from '../../../Common/StatsItem.esm.js';

const ScorecardScoresStatsCard = ({
  entityCategory,
  scores
}) => {
  const type = "PERCENTAGE";
  const percentages = useMemo(
    () => isEmpty(scores) ? [0] : scores.map((score) => score.scorePercentage),
    [scores]
  );
  const avgScore = useMemo(() => round(mean(percentages), 2), [percentages]);
  const percentile = useMemo(
    () => quantileSorted([...percentages].reverse(), 0.8),
    [percentages]
  );
  const medianScore = useMemo(() => median(percentages), [percentages]);
  return /* @__PURE__ */ React__default.createElement(Paper, { elevation: 0, style: { marginBottom: 8 } }, /* @__PURE__ */ React__default.createElement(Stats, null, /* @__PURE__ */ React__default.createElement(
    StatsItem,
    {
      caption: "Avg score",
      percentage: true,
      type,
      value: avgScore
    }
  ), /* @__PURE__ */ React__default.createElement(
    StatsItem,
    {
      caption: "Median score",
      percentage: true,
      type,
      value: medianScore
    }
  ), /* @__PURE__ */ React__default.createElement(
    StatsItem,
    {
      caption: "80th percentile",
      percentage: true,
      type,
      value: percentile
    }
  ), /* @__PURE__ */ React__default.createElement(
    StatsItem,
    {
      caption: entityCategory,
      type: "NONE",
      value: scores.length
    }
  )));
};

export { ScorecardScoresStatsCard };
//# sourceMappingURL=ScorecardScoresStatsCard.esm.js.map
