import React__default, { useMemo } from 'react';
import { InfoCard, EmptyState, Table } from '@backstage/core-components';
import { useDetailCardStyles } from '../../../../styles/styles.esm.js';
import { humanizeAnyEntityRef } from '../../../../utils/types.esm.js';
import { entityComponentRef, defaultComponentRefContext } from '../../../../utils/ComponentUtils.esm.js';
import { ScorecardServiceRefLink } from '../../../ScorecardServiceRefLink/ScorecardServiceRefLink.esm.js';
import { makeStyles, Box, Typography } from '@material-ui/core';
import { isNil } from 'lodash';
import { levelSort, scorePercentageSort, levelColumn, scoreColumn, PAGE_SIZE } from './ScorecardsScoresTableConfig.esm.js';
import useLinearProgressWithLabelStyles from '../../../Common/useLinearProgressWithLabelStyles.esm.js';

const useScorecardsScoresTableCardStyle = makeStyles(() => ({
  tag: {
    fontFamily: "Monospace",
    fontSize: 12
  }
}));
const ScorecardsScoresTable = ({
  category,
  entitiesByTag,
  ladder,
  scorecardId,
  scores
}) => {
  const classes = useDetailCardStyles();
  const scorecardsTableCardClasses = useScorecardsScoresTableCardStyle();
  const linearProgressWithLabelClasses = useLinearProgressWithLabelStyles();
  const columns = useMemo(
    () => [
      {
        customFilterAndSearch: (filter, rowData) => {
          var _a, _b;
          return (_b = (_a = rowData.name) == null ? void 0 : _a.toLocaleLowerCase().includes(filter.toLocaleLowerCase())) != null ? _b : false;
        },
        customSort: (data1, data2) => {
          var _a, _b, _c;
          return (_c = (_a = data2 == null ? void 0 : data2.name) != null ? _a : "") == null ? void 0 : _c.localeCompare((_b = data1 == null ? void 0 : data1.name) != null ? _b : "");
        },
        field: "name",
        highlight: true,
        sorting: true,
        title: `${category} name`,
        render: ({
          name,
          tag = "",
          description
        }) => /* @__PURE__ */ React__default.createElement(Box, null, /* @__PURE__ */ React__default.createElement(
          ScorecardServiceRefLink,
          {
            scorecardId,
            componentRef: entityComponentRef(entitiesByTag, tag)
          },
          name
        ), description && /* @__PURE__ */ React__default.createElement(Typography, { variant: "subtitle2" }, description))
      },
      {
        sorting: true,
        field: "tag",
        title: "Tag",
        customSort: (data1, data2) => {
          var _a, _b;
          const tag1 = (_a = data1 == null ? void 0 : data1.tag) != null ? _a : "";
          const tag2 = (_b = data2 == null ? void 0 : data2.tag) != null ? _b : "";
          return tag2.localeCompare(tag1);
        },
        customFilterAndSearch: (filter, rowData) => {
          var _a, _b;
          return (_b = (_a = rowData.tag) == null ? void 0 : _a.toLocaleLowerCase().includes(filter.toLocaleLowerCase())) != null ? _b : false;
        },
        render: ({ tag }) => /* @__PURE__ */ React__default.createElement(
          Typography,
          {
            variant: "subtitle2",
            className: scorecardsTableCardClasses.tag
          },
          tag
        )
      }
    ],
    [category, scorecardId, scorecardsTableCardClasses.tag, entitiesByTag]
  );
  const data = useMemo(() => {
    return scores.map((score) => {
      var _a, _b, _c, _d;
      const currentLevel = (_b = (_a = score.ladderLevels) == null ? void 0 : _a[0]) == null ? void 0 : _b.currentLevel;
      const serviceName = (_d = (_c = entitiesByTag[score.componentRef]) == null ? void 0 : _c.name) != null ? _d : humanizeAnyEntityRef(score.componentRef, defaultComponentRefContext);
      return {
        level: currentLevel,
        linearProgressClasses: linearProgressWithLabelClasses,
        name: serviceName,
        scorePercentage: score.scorePercentage,
        description: score.description,
        tag: score.componentRef
      };
    }).sort(!isNil(ladder) ? levelSort : scorePercentageSort);
  }, [entitiesByTag, ladder, linearProgressWithLabelClasses, scores]);
  const tableColumns = useMemo(() => {
    return !isNil(ladder) ? [levelColumn, ...columns] : [scoreColumn, ...columns];
  }, [columns, ladder]);
  const showPagination = scores.length > PAGE_SIZE;
  if (scores.length === 0) {
    return /* @__PURE__ */ React__default.createElement(InfoCard, { title: "Scores", className: classes.root }, /* @__PURE__ */ React__default.createElement(EmptyState, { missing: "data", title: "No scores found." }));
  }
  return /* @__PURE__ */ React__default.createElement(
    Table,
    {
      columns: tableColumns,
      data,
      options: {
        pageSize: PAGE_SIZE,
        pageSizeOptions: [PAGE_SIZE, PAGE_SIZE * 2, PAGE_SIZE * 4],
        paging: showPagination,
        padding: "dense"
      }
    }
  );
};

export { ScorecardsScoresTable };
//# sourceMappingURL=ScorecardsScoresTable.esm.js.map
