import React__default, { useState } from 'react';
import { ruleName } from '../../../../api/types.esm.js';
import { makeStyles, ListItem, ListItemAvatar, IconButton, Grid, ListItemText, Collapse, Typography } from '@material-ui/core';
import ErrorIcon from '@material-ui/icons/Error';
import CheckIcon from '@material-ui/icons/Check';
import { MarkdownContent } from '@backstage/core-components';
import { MetadataItem } from '../../../MetadataItem/MetadataItem.esm.js';
import KeyboardArrowDownIcon from '@material-ui/icons/KeyboardArrowDown';
import KeyboardArrowRight from '@material-ui/icons/KeyboardArrowRight';
import { isRuleOutcomePassing, isRuleOutcomeFailing, isApplicableRuleOutcome } from '../../../../utils/ScorecardRules.esm.js';
import { NotInterested } from '@material-ui/icons';

const useStyles = makeStyles({
  rule: {
    borderRadius: 8
  }
});
const RuleResultDetails = ({
  ruleOutcome,
  hideWeight
}) => {
  const classes = useStyles();
  const [open, setOpen] = useState(false);
  const showExpandButton = ruleOutcome.rule.description || ruleOutcome.rule.title;
  const hasTitle = !!ruleOutcome.rule.title;
  const isPassing = isRuleOutcomePassing(ruleOutcome);
  const isFailing = isRuleOutcomeFailing(ruleOutcome);
  return /* @__PURE__ */ React__default.createElement(ListItem, { alignItems: "flex-start" }, /* @__PURE__ */ React__default.createElement(ListItemAvatar, null, showExpandButton ? /* @__PURE__ */ React__default.createElement(IconButton, { size: "small", onClick: () => setOpen(!open) }, open ? /* @__PURE__ */ React__default.createElement(KeyboardArrowDownIcon, null) : /* @__PURE__ */ React__default.createElement(KeyboardArrowRight, null)) : /* @__PURE__ */ React__default.createElement(React__default.Fragment, null)), /* @__PURE__ */ React__default.createElement(ListItemAvatar, null, isPassing ? /* @__PURE__ */ React__default.createElement(CheckIcon, { color: "primary" }) : isFailing ? /* @__PURE__ */ React__default.createElement(ErrorIcon, { color: "error" }) : /* @__PURE__ */ React__default.createElement(NotInterested, { color: "primary" })), /* @__PURE__ */ React__default.createElement(ListItem, null, /* @__PURE__ */ React__default.createElement(
    Grid,
    {
      container: true,
      direction: "row",
      justify: "space-between",
      alignItems: "center",
      className: classes.rule
    },
    /* @__PURE__ */ React__default.createElement(Grid, { item: true, xs: 10 }, /* @__PURE__ */ React__default.createElement(
      ListItemText,
      {
        primary: ruleName(ruleOutcome.rule),
        style: { wordWrap: "break-word" }
      }
    ), /* @__PURE__ */ React__default.createElement(Collapse, { in: open, timeout: "auto", unmountOnExit: true }, /* @__PURE__ */ React__default.createElement(React__default.Fragment, null, ruleOutcome.rule.description && /* @__PURE__ */ React__default.createElement(MetadataItem, { gridSizes: { xs: 12 }, label: "Description" }, /* @__PURE__ */ React__default.createElement(MarkdownContent, { content: ruleOutcome.rule.description })), hasTitle && /* @__PURE__ */ React__default.createElement(MetadataItem, { gridSizes: { xs: 12 }, label: "Expression" }, ruleOutcome.rule.expression)))),
    isApplicableRuleOutcome(ruleOutcome) && ruleOutcome.error && /* @__PURE__ */ React__default.createElement(Grid, { item: true, xs: 10 }, /* @__PURE__ */ React__default.createElement(Typography, { color: "error", style: { wordWrap: "break-word" } }, ruleOutcome.error)),
    isFailing && ruleOutcome.rule.failureMessage && /* @__PURE__ */ React__default.createElement(Grid, { item: true, xs: 10 }, /* @__PURE__ */ React__default.createElement(Typography, { color: "error", style: { wordWrap: "break-word" } }, /* @__PURE__ */ React__default.createElement(MarkdownContent, { content: ruleOutcome.rule.failureMessage })))
  )), hideWeight !== true && /* @__PURE__ */ React__default.createElement(ListItemText, { primary: `${ruleOutcome.rule.weight}` }));
};

export { RuleResultDetails };
//# sourceMappingURL=RuleResultDetails.esm.js.map
