import React__default, { useMemo } from 'react';
import { List, ListItem, Typography } from '@material-ui/core';
import { RuleResultDetails } from './RuleResultDetails.esm.js';
import { ruleName } from '../../../../api/types.esm.js';
import { isApplicableRuleOutcome } from '../../../../utils/ScorecardRules.esm.js';

const ScorecardResultDetails = ({
  ruleOutcomes,
  hideWeights
}) => {
  const sortedRules = useMemo(
    () => [...ruleOutcomes].sort((a, b) => {
      if (isApplicableRuleOutcome(a) && !isApplicableRuleOutcome(b)) {
        return -1;
      }
      if (!isApplicableRuleOutcome(a) && isApplicableRuleOutcome(b)) {
        return 1;
      }
      if (isApplicableRuleOutcome(a) && isApplicableRuleOutcome(b)) {
        if (a.score === b.score) {
          return ruleName(a.rule).localeCompare(ruleName(b.rule));
        } else {
          return a.score - b.score;
        }
      }
      return ruleName(a.rule).localeCompare(ruleName(b.rule));
    }),
    [ruleOutcomes]
  );
  return /* @__PURE__ */ React__default.createElement(List, null, sortedRules.length === 0 && /* @__PURE__ */ React__default.createElement(ListItem, { alignItems: "flex-start" }, /* @__PURE__ */ React__default.createElement(Typography, { variant: "body1" }, "No rules.")), sortedRules.map((rule) => /* @__PURE__ */ React__default.createElement(
    RuleResultDetails,
    {
      key: `RuleResultDetails-${rule.rule.id}`,
      ruleOutcome: rule,
      hideWeight: hideWeights
    }
  )));
};

export { ScorecardResultDetails };
//# sourceMappingURL=ScorecardResultDetails.esm.js.map
