import React__default from 'react';
import { Button } from '@material-ui/core';
import { useAsync } from 'react-use';
import { Routes, Route } from 'react-router-dom';
import { Progress, WarningPanel, EmptyState } from '@backstage/core-components';
import { useApi } from '@backstage/core-plugin-api';
import { cortexApiRef } from '../../../api/CortexClient.esm.js';
import { ScorecardDetailsPage } from '../ScorecardDetailsPage/ScorecardDetailsPage.esm.js';
import { ScorecardsServicePage } from '../ScorecardsServicePage/ScorecardsServicePage.esm.js';
import { ScorecardList } from './ScorecardList.esm.js';

const ScorecardsPage = () => {
  const cortexApi = useApi(cortexApiRef);
  const {
    value: scorecards,
    loading,
    error
  } = useAsync(async () => {
    return await cortexApi.getScorecards();
  }, []);
  if (loading) {
    return /* @__PURE__ */ React__default.createElement(Progress, null);
  }
  if (error) {
    return /* @__PURE__ */ React__default.createElement(WarningPanel, { severity: "error", title: "Could not load Scorecards." }, error.message);
  }
  if (!(scorecards == null ? void 0 : scorecards.length)) {
    return /* @__PURE__ */ React__default.createElement(
      EmptyState,
      {
        missing: "info",
        title: "No scorecards to display",
        description: "You haven't added any scorecards yet.",
        action: /* @__PURE__ */ React__default.createElement(
          Button,
          {
            variant: "contained",
            color: "primary",
            href: "https://backstage.io/docs/features/software-catalog/descriptor-format#kind-domain"
          },
          "Read more"
        )
      }
    );
  }
  return /* @__PURE__ */ React__default.createElement(Routes, null, /* @__PURE__ */ React__default.createElement(
    Route,
    {
      path: "/:scorecardId/:namespace/:kind/:name",
      element: /* @__PURE__ */ React__default.createElement(ScorecardsServicePage, null)
    }
  ), /* @__PURE__ */ React__default.createElement(Route, { path: "/:id", element: /* @__PURE__ */ React__default.createElement(ScorecardDetailsPage, null) }), /* @__PURE__ */ React__default.createElement(Route, { path: "/", element: /* @__PURE__ */ React__default.createElement(ScorecardList, null) }));
};

export { ScorecardsPage };
//# sourceMappingURL=ScorecardsPage.esm.js.map
