import React__default, { useMemo } from 'react';
import { useRouteRefParams, useRouteRef } from '@backstage/core-plugin-api';
import { Link, MarkdownContent } from '@backstage/core-components';
import { Typography } from '@material-ui/core';
import { scorecardServiceDetailsRouteRef, scorecardRouteRef } from '../../../routes.esm.js';
import Box from '@material-ui/core/Box';
import { DefaultEntityRefLink } from '../../DefaultEntityLink/DefaultEntityRefLink.esm.js';
import { cortexScorecardServicePageUrl } from '../../../utils/URLUtils.esm.js';
import { useCortexFrontendUrl, useHideCortexLinks } from '../../../utils/hooks.esm.js';
import { KeyboardArrowLeft } from '@material-ui/icons';
import { isNil } from 'lodash';
import moment from 'moment';
import { HoverTimestamp } from '../../Common/HoverTimestamp.esm.js';
import { Truncated } from '../../Common/Truncated.esm.js';

const ScorecardServiceHeader = ({
  entitiesByTag,
  score,
  scorecard
}) => {
  var _a;
  const { scorecardId, kind, namespace, name } = useRouteRefParams(
    scorecardServiceDetailsRouteRef
  );
  const entityRef = { kind, namespace, name };
  const scorecardRef = useRouteRef(scorecardRouteRef);
  const cortexBaseUrl = useCortexFrontendUrl();
  const lastEvaluation = useMemo(() => {
    return !isNil(score) ? moment.utc(score.lastUpdated) : void 0;
  }, [score]);
  const hideLink = useHideCortexLinks();
  return /* @__PURE__ */ React__default.createElement(Box, null, /* @__PURE__ */ React__default.createElement(Box, { display: "flex", flexDirection: "row", mb: 2 }, /* @__PURE__ */ React__default.createElement(Link, { to: scorecardRef({ id: `${scorecardId}` }) }, /* @__PURE__ */ React__default.createElement(
    Box,
    {
      display: "flex",
      flexDirection: "row",
      justifyContent: "flex-start",
      alignItems: "center"
    },
    /* @__PURE__ */ React__default.createElement(KeyboardArrowLeft, null),
    /* @__PURE__ */ React__default.createElement("b", null, "Back to Scorecard")
  ))), /* @__PURE__ */ React__default.createElement(
    Box,
    {
      display: "flex",
      flexDirection: "row",
      justifyContent: "flex-start",
      alignItems: "flex-start",
      mb: 3
    },
    /* @__PURE__ */ React__default.createElement(Box, { alignSelf: "center", flex: "1" }, /* @__PURE__ */ React__default.createElement(Box, { mb: 1 }, /* @__PURE__ */ React__default.createElement(Typography, { variant: "h4", component: "h2" }, /* @__PURE__ */ React__default.createElement(
      DefaultEntityRefLink,
      {
        entityRef,
        title: (_a = entitiesByTag[entityRef.name]) == null ? void 0 : _a.name
      }
    ))), scorecard.description && /* @__PURE__ */ React__default.createElement(Box, { mb: 1 }, /* @__PURE__ */ React__default.createElement(
      Truncated,
      {
        text: scorecard.description,
        truncateToLines: 10,
        renderText: (text) => /* @__PURE__ */ React__default.createElement(MarkdownContent, { content: text })
      }
    )), lastEvaluation && /* @__PURE__ */ React__default.createElement(Typography, { component: "span", variant: "body2" }, "Updated ", /* @__PURE__ */ React__default.createElement(HoverTimestamp, { ts: lastEvaluation }))),
    !hideLink && /* @__PURE__ */ React__default.createElement(Box, null, /* @__PURE__ */ React__default.createElement(
      Link,
      {
        to: cortexScorecardServicePageUrl({
          scorecardId,
          serviceId: score.serviceId,
          cortexUrl: cortexBaseUrl
        }),
        target: "_blank"
      },
      /* @__PURE__ */ React__default.createElement("b", null, "View in Cortex")
    ))
  ));
};

export { ScorecardServiceHeader };
//# sourceMappingURL=ScorecardsServiceHeader.esm.js.map
