import React__default from 'react';
import { Box, Typography } from '@material-ui/core';
import { Progress, WarningPanel } from '@backstage/core-components';
import { useCortexApi } from '../../../utils/hooks.esm.js';
import { stringifyAnyEntityRef } from '../../../utils/types.esm.js';
import { ScorecardLadderLevelBadge } from '../../Common/ScorecardLadderLevelBadge.esm.js';
import { isNil } from 'lodash';
import { ScorecardServiceRuleRow } from './ScorecardsServiceRuleRow.esm.js';
import { useCortexInfoCardStyles, CortexInfoCard } from '../../Common/CortexInfoCard.esm.js';
import useScorecardServiceRuleRowStyle from './useScorecardServiceRuleRowStyles.esm.js';

const ScorecardsServiceNextRules = ({
  entityRef,
  scorecardId
}) => {
  var _a;
  const {
    value,
    loading: nextStepsLoading,
    error: nextStepsError
  } = useCortexApi(
    async (cortexApi) => {
      return await cortexApi.getServiceNextSteps(
        stringifyAnyEntityRef(entityRef),
        scorecardId
      );
    },
    [entityRef]
  );
  const rulesCardClasses = useCortexInfoCardStyles();
  const scorecardServiceRuleRowClasses = useScorecardServiceRuleRowStyle();
  const nextSteps = (_a = value == null ? void 0 : value[0]) != null ? _a : void 0;
  if (nextStepsLoading) {
    return /* @__PURE__ */ React__default.createElement(Progress, null);
  }
  if (nextSteps === void 0 || nextStepsError) {
    return /* @__PURE__ */ React__default.createElement(
      WarningPanel,
      {
        severity: "error",
        title: "Ran into an error loading next steps for service."
      },
      nextStepsError == null ? void 0 : nextStepsError.message
    );
  }
  if (isNil(nextSteps.nextLevel) || isNil(nextSteps.rulesToComplete)) {
    return null;
  }
  return /* @__PURE__ */ React__default.createElement(
    CortexInfoCard,
    {
      title: /* @__PURE__ */ React__default.createElement(Box, { display: "flex", flexDirection: "row" }, /* @__PURE__ */ React__default.createElement(
        Typography,
        {
          variant: "body1",
          className: rulesCardClasses.cardHeaderTitle
        },
        "Tasks to advance to ",
        nextSteps.nextLevel.name
      ), /* @__PURE__ */ React__default.createElement(
        ScorecardLadderLevelBadge,
        {
          name: nextSteps.nextLevel.name,
          color: nextSteps.nextLevel.color
        }
      ))
    },
    nextSteps.rulesToComplete.map((rule) => /* @__PURE__ */ React__default.createElement(
      ScorecardServiceRuleRow,
      {
        key: `rule-to-complete-${rule.id}`,
        classes: scorecardServiceRuleRowClasses,
        rule
      }
    ))
  );
};

export { ScorecardsServiceNextRules };
//# sourceMappingURL=ScorecardsServiceNextRules.esm.js.map
