import React__default, { useMemo } from 'react';
import { Timeseries } from '../../Timeseries/Timeseries.esm.js';
import { sortRules, isRuleFailing } from '../../../utils/ScorecardRules.esm.js';
import { ScorecardsServiceTooltipRuleRow } from './ScorecardsServiceTooltipRuleRow.esm.js';
import { makeStyles, Paper, Box, Typography } from '@material-ui/core';

const useStyles = makeStyles((theme) => ({
  tooltipRoot: {
    margin: theme.spacing(1),
    maxWidth: "400px",
    minWidth: "400px"
  }
}));
const ScorecardsServiceOverallScoreProgress = ({ results, scorecardId }) => {
  const classes = useStyles();
  const data = useMemo(() => {
    return [
      {
        data: results == null ? void 0 : results.map((scorecardResult) => {
          return {
            x: new Date(scorecardResult.dateCreated),
            y: (scorecardResult.possibleScore === 0 ? 0 : scorecardResult.totalScore / scorecardResult.possibleScore * 100).toFixed(2)
          };
        }),
        id: scorecardId
      }
    ];
  }, [results, scorecardId]);
  if (results === void 0) {
    return null;
  }
  return /* @__PURE__ */ React__default.createElement(
    Timeseries,
    {
      data,
      tooltip: (point) => {
        const sortedRules = sortRules(results[point.point.index].ruleResults);
        return /* @__PURE__ */ React__default.createElement(Paper, null, /* @__PURE__ */ React__default.createElement(
          Box,
          {
            key: `tooltip-${point.point.index}`,
            className: classes.tooltipRoot
          },
          /* @__PURE__ */ React__default.createElement(Typography, { variant: "body1" }, point.point.data.xFormatted),
          sortedRules.filter((rule) => isRuleFailing(rule)).map((rule) => {
            var _a;
            return /* @__PURE__ */ React__default.createElement(
              ScorecardsServiceTooltipRuleRow,
              {
                key: `TooltipRuleRow-${point.point.index}-${(_a = rule.id) != null ? _a : rule.expression}`,
                rule
              }
            );
          })
        ));
      }
    }
  );
};

export { ScorecardsServiceOverallScoreProgress };
//# sourceMappingURL=ScorecardsServiceOverallScoreProgress.esm.js.map
