import React__default, { useState, useEffect, useMemo } from 'react';
import { useApi, useRouteRefParams } from '@backstage/core-plugin-api';
import { Progress, WarningPanel, Content } from '@backstage/core-components';
import { Grid } from '@material-ui/core';
import { useAsync } from 'react-use';
import { cortexApiRef } from '../../../api/CortexClient.esm.js';
import { scorecardServiceDetailsRouteRef } from '../../../routes.esm.js';
import Box from '@material-ui/core/Box';
import { ScorecardsServiceProgress } from './ScorecardsServiceProgress.esm.js';
import { entityEquals } from '../../../utils/types.esm.js';
import { ScorecardsServiceNextRules } from './ScorecardsServiceNextRules.esm.js';
import { useEntitiesByTag } from '../../../utils/hooks.esm.js';
import { ScorecardsServiceRulesDetails } from './ScorecardsServiceRulesDetails.esm.js';
import { ScorecardsServiceStatistics } from './ScorecardsServiceStatistics.esm.js';
import { ScorecardServiceHeader } from './ScorecardsServiceHeader.esm.js';

const ScorecardsServicePage = () => {
  var _a;
  const cortexApi = useApi(cortexApiRef);
  const { scorecardId, kind, namespace, name } = useRouteRefParams(
    scorecardServiceDetailsRouteRef
  );
  const { entitiesByTag, loading: loadingEntities } = useEntitiesByTag();
  const entityRef = { kind, namespace, name };
  const [selectedRules, setSelectedRules] = useState([]);
  const { value, loading, error } = useAsync(async () => {
    const allScores2 = await cortexApi.getScorecardScores(+scorecardId);
    const ladders2 = await cortexApi.getScorecardLadders(+scorecardId);
    const scorecard2 = await cortexApi.getScorecard(+scorecardId);
    const score2 = allScores2.find((entityScore) => {
      if (!entitiesByTag[entityScore.componentRef]) {
        return false;
      }
      return entityEquals(
        entitiesByTag[entityScore.componentRef].definition,
        entityRef
      );
    });
    return { allScores: allScores2, score: score2, scorecard: scorecard2, ladders: ladders2 };
  }, [entitiesByTag]);
  const { allScores, score, ladders, scorecard } = value != null ? value : {
    allScores: [],
    score: void 0,
    scorecard: void 0,
    ladders: []
  };
  useEffect(() => {
    var _a2;
    setSelectedRules((_a2 = score == null ? void 0 : score.rules) != null ? _a2 : []);
  }, [score]);
  const scores = useMemo(
    () => allScores == null ? void 0 : allScores.map((score2) => score2.scorePercentage).sort(),
    [allScores]
  );
  if (loading || loadingEntities) {
    return /* @__PURE__ */ React__default.createElement(Progress, null);
  }
  if (error || score === void 0 || scorecard === void 0) {
    return /* @__PURE__ */ React__default.createElement(WarningPanel, { severity: "error", title: "Could not load Scorecard scores." }, (_a = error == null ? void 0 : error.message) != null ? _a : "");
  }
  const ladder = ladders == null ? void 0 : ladders[0];
  return /* @__PURE__ */ React__default.createElement(Content, null, /* @__PURE__ */ React__default.createElement(
    ScorecardServiceHeader,
    {
      entitiesByTag,
      score,
      scorecard
    }
  ), /* @__PURE__ */ React__default.createElement(Grid, { container: true, direction: "row", spacing: 1 }, /* @__PURE__ */ React__default.createElement(Grid, { item: true, lg: 4 }, /* @__PURE__ */ React__default.createElement(ScorecardsServiceRulesDetails, { ruleOutcomes: selectedRules })), /* @__PURE__ */ React__default.createElement(Grid, { item: true, lg: 8, xs: 12 }, /* @__PURE__ */ React__default.createElement(Box, { marginBottom: 1 }, /* @__PURE__ */ React__default.createElement(
    ScorecardsServiceStatistics,
    {
      scores,
      score,
      rules: selectedRules
    }
  )), ladder && /* @__PURE__ */ React__default.createElement(
    ScorecardsServiceNextRules,
    {
      scorecardId: +scorecardId,
      entityRef
    }
  ), /* @__PURE__ */ React__default.createElement(
    ScorecardsServiceProgress,
    {
      scorecardId,
      entityRef,
      rules: selectedRules
    }
  ))));
};

export { ScorecardsServicePage };
//# sourceMappingURL=ScorecardsServicePage.esm.js.map
