import React__default, { useState, useMemo } from 'react';
import { Typography, Button } from '@material-ui/core';
import { useDropdown, useCortexFrontendUrl, useHideCortexLinks } from '../../../utils/hooks.esm.js';
import { useApi } from '@backstage/core-plugin-api';
import { cortexApiRef } from '../../../api/CortexClient.esm.js';
import { useAsync } from 'react-use';
import { Progress, WarningPanel, EmptyState } from '@backstage/core-components';
import Box from '@material-ui/core/Box';
import { Lookback, getLookbackRange } from '../../../utils/lookback.esm.js';
import { LookbackDropdown } from '../../ReportsPage/Common/LookbackDropdown.esm.js';
import { cortexScorecardPageUrl } from '../../../utils/URLUtils.esm.js';
import { isUndefined } from 'lodash';
import { ScorecardsServiceOverallScoreProgress } from './ScorecardsServiceOverallScoreProgress.esm.js';
import { ScorecardsServiceRuleProgress } from './ScorecardsServiceRuleProgress.esm.js';
import ScorecardsServiceRulesFilter from './ScorecardsServiceRulesFilter.esm.js';
import { useCortexInfoCardStyles, CortexInfoCard } from '../../Common/CortexInfoCard.esm.js';

const ScorecardsServiceProgress = ({
  scorecardId,
  entityRef,
  rules
}) => {
  var _a;
  const cortexApi = useApi(cortexApiRef);
  const [lookback, setLookback] = useDropdown(Lookback.MONTHS_1);
  const [selected, setSelected] = useState(void 0);
  const {
    value: historicalScores,
    loading,
    error
  } = useAsync(async () => {
    const [startDate, endDate] = getLookbackRange(lookback);
    return cortexApi.getHistoricalScores(
      scorecardId,
      entityRef,
      startDate,
      endDate
    );
  }, [lookback]);
  const data = useMemo(() => {
    return historicalScores == null ? void 0 : historicalScores.map((scorecardResult) => {
      return {
        x: new Date(scorecardResult.dateCreated),
        y: (scorecardResult.possibleScore === 0 ? 0 : scorecardResult.totalScore / scorecardResult.possibleScore * 100).toFixed(2)
      };
    });
  }, [historicalScores]);
  const cortexBaseUrl = useCortexFrontendUrl();
  const rulesCardClasses = useCortexInfoCardStyles();
  const hideLink = useHideCortexLinks();
  if (loading) {
    return /* @__PURE__ */ React__default.createElement(Progress, null);
  }
  if (error || data === void 0 || historicalScores === void 0) {
    return /* @__PURE__ */ React__default.createElement(WarningPanel, { severity: "error", title: "Could not load Scorecard scores." }, (_a = error == null ? void 0 : error.message) != null ? _a : "");
  }
  if (data.length === 0) {
    const actionButton = hideLink ? void 0 : /* @__PURE__ */ React__default.createElement(
      Button,
      {
        variant: "contained",
        color: "primary",
        href: cortexScorecardPageUrl({
          scorecardId,
          cortexUrl: cortexBaseUrl
        })
      },
      "Go to Cortex"
    );
    return /* @__PURE__ */ React__default.createElement(CortexInfoCard, { title: "Progress" }, /* @__PURE__ */ React__default.createElement(
      EmptyState,
      {
        missing: "data",
        title: "Scorecard has not been evaluated yet.",
        description: "Wait until next Scorecard evaluation, or manually trigger from within Cortex.",
        action: actionButton
      }
    ));
  }
  return /* @__PURE__ */ React__default.createElement(
    CortexInfoCard,
    {
      title: /* @__PURE__ */ React__default.createElement(Box, { display: "flex", justifyContent: "space-between", alignItems: "center" }, /* @__PURE__ */ React__default.createElement(
        Typography,
        {
          variant: "body1",
          className: rulesCardClasses.cardHeaderTitle
        },
        "Progress"
      ), /* @__PURE__ */ React__default.createElement(Box, { display: "flex", flexDirection: "row", gridGap: 8 }, /* @__PURE__ */ React__default.createElement(LookbackDropdown, { lookback, setLookback }), /* @__PURE__ */ React__default.createElement(
        ScorecardsServiceRulesFilter,
        {
          selected,
          rules,
          setSelected
        }
      )))
    },
    isUndefined(selected) ? /* @__PURE__ */ React__default.createElement(
      ScorecardsServiceOverallScoreProgress,
      {
        results: historicalScores,
        scorecardId
      }
    ) : /* @__PURE__ */ React__default.createElement(
      ScorecardsServiceRuleProgress,
      {
        expression: selected.expression,
        results: historicalScores,
        scorecardId
      }
    )
  );
};

export { ScorecardsServiceProgress };
//# sourceMappingURL=ScorecardsServiceProgress.esm.js.map
