import React__default, { useMemo, useRef } from 'react';
import { makeStyles, useTheme, Typography, Paper, Box } from '@material-ui/core';
import { useDimensions } from '../../../utils/pureHooks.esm.js';
import { LineCanvas } from '@nivo/line';
import { nivoTheme } from '../../Timeseries/Timeseries.esm.js';
import { fallbackPalette } from '../../../styles/styles.esm.js';
import { unflattenScorecardResults, precision } from './ScorecardsServiceRuleProgressUtils.esm.js';

const useStyles = makeStyles((theme) => ({
  tooltipRoot: {
    minWidth: "140px",
    margin: theme.spacing(1)
  }
}));
const ScorecardsServiceRuleProgress = ({ expression, results, scorecardId }) => {
  const apexCharts = useMemo(() => {
    return unflattenScorecardResults([expression], results);
  }, [expression, results]);
  const ref = useRef(null);
  const { width } = useDimensions(ref);
  const theme = useTheme();
  const classes = useStyles();
  const mapped = useMemo(
    () => {
      var _a, _b, _c;
      return (_c = (_b = (_a = apexCharts == null ? void 0 : apexCharts[expression]) == null ? void 0 : _a.data) == null ? void 0 : _b.map(({ x, y }) => ({
        x: new Date(x),
        y: Number.parseFloat(y)
      }))) == null ? void 0 : _c.filter(({ y }) => !isNaN(y));
    },
    [apexCharts, expression]
  );
  const seriesData = apexCharts[expression];
  if (!seriesData || seriesData.data.length === 0) {
    return /* @__PURE__ */ React__default.createElement(Typography, null, "No data found for this rule.");
  }
  return /* @__PURE__ */ React__default.createElement("div", { ref }, /* @__PURE__ */ React__default.createElement(
    LineCanvas,
    {
      axisBottom: {
        format: "%d %b",
        tickValues: precision(mapped.length)
      },
      axisLeft: null,
      axisRight: {},
      height: 400,
      colors: fallbackPalette.common.purple[400],
      curve: "linear",
      data: [{ data: mapped, id: scorecardId }],
      enablePoints: false,
      margin: { bottom: 30, left: 10, right: 40, top: 30 },
      markers: [
        {
          axis: "y",
          legend: `Target: ${seriesData.target.label.text}`,
          lineStyle: {
            stroke: fallbackPalette.common.purple[300],
            strokeWidth: 2
          },
          value: seriesData.target.y
        }
      ],
      theme: nivoTheme(theme),
      tooltip: (point) => {
        var _a, _b, _c, _d;
        return /* @__PURE__ */ React__default.createElement(Paper, null, /* @__PURE__ */ React__default.createElement(
          Box,
          {
            key: `tooltip-${point.point.index}`,
            className: classes.tooltipRoot
          },
          /* @__PURE__ */ React__default.createElement(Typography, { component: "div" }, (_b = (_a = point == null ? void 0 : point.point) == null ? void 0 : _a.data) == null ? void 0 : _b.xFormatted, ":", " ", (_d = (_c = point == null ? void 0 : point.point) == null ? void 0 : _c.data) == null ? void 0 : _d.yFormatted)
        ));
      },
      width: width > 48 ? width - 48 : 0,
      xFormat: "time:%m/%d/%Y",
      xScale: {
        precision: "hour",
        type: "time",
        useUTC: true
      }
    }
  ));
};

export { ScorecardsServiceRuleProgress };
//# sourceMappingURL=ScorecardsServiceRuleProgress.esm.js.map
