import moment from 'moment';
import { pickBy } from 'lodash';

function unflattenScorecardResults(currentExpressions, results) {
  const seriesByExpression = currentExpressions.reduce(
    (datasets, ruleExpression) => {
      datasets[ruleExpression] = {
        data: [],
        name: ruleExpression,
        target: { label: { text: "" }, y: 0 }
      };
      return datasets;
    },
    {}
  );
  results.forEach((result, idx) => {
    Object.values(seriesByExpression).forEach((series) => {
      series.data[idx] = {
        x: moment.utc(result.dateCreated).local().toISOString(),
        y: null
      };
    });
    result.ruleResults.forEach((ruleResult) => {
      const series = seriesByExpression[ruleResult.expression];
      if (series !== void 0) {
        if (ruleResult.leftExpression !== void 0 && ruleResult.leftResult !== void 0 && Number.isFinite(ruleResult.leftResult)) {
          series.name = ruleResult.leftExpression;
          series.data[idx].y = ruleResult.leftResult;
          series.target = {
            label: { text: ruleResult.rightExpression },
            y: ruleResult.rightResult
          };
        } else {
          series.name = ruleResult.expression;
          series.data[idx].y = ruleResult.score;
          series.target = {
            label: { text: ruleResult.expression },
            y: ruleResult.score
          };
        }
      }
    });
  });
  return pickBy(seriesByExpression, (apexSeries) => {
    return apexSeries.data.reduce(
      (shouldTake, datum) => {
        return shouldTake || datum.y !== null;
      },
      false
    );
  });
}
function precision(val) {
  if (val >= 10 * 30 * 6) {
    return "every 3 months";
  } else if (val >= 30 * 6) {
    return "every 1 month";
  } else if (val >= 10 * 6) {
    return "every 10 days";
  } else if (val >= 24) {
    return "every 4 days";
  } else if (val >= 14) {
    return "every 2 days";
  } else {
    return "every 1 days";
  }
}

export { precision, unflattenScorecardResults };
//# sourceMappingURL=ScorecardsServiceRuleProgressUtils.esm.js.map
