import React__default, { useState } from 'react';
import { Box, IconButton, Typography, Collapse } from '@material-ui/core';
import KeyboardArrowDownIcon from '@material-ui/icons/KeyboardArrowDown';
import KeyboardArrowRight from '@material-ui/icons/KeyboardArrowRight';
import CheckCircleIcon from '@material-ui/icons/CheckCircle';
import CancelIcon from '@material-ui/icons/Cancel';
import { MarkdownContent } from '@backstage/core-components';
import classNames from 'classnames';
import { useIconsStyles } from '../../../styles/styles.esm.js';
import { isRuleFailing } from '../../../utils/ScorecardRules.esm.js';
import { ruleName } from '../../../api/types.esm.js';
import { isNil } from 'lodash';

const ScorecardServiceRuleRow = ({
  classes,
  hideWeight,
  rule
}) => {
  const [open, setOpen] = useState(false);
  const iconsClasses = useIconsStyles();
  const showExpandButton = rule.description || rule.filter || rule.expression;
  const isFailing = isRuleFailing(rule);
  return /* @__PURE__ */ React__default.createElement(Box, { className: classes.root }, /* @__PURE__ */ React__default.createElement(Box, { display: "flex", flexDirection: "row" }, /* @__PURE__ */ React__default.createElement(Box, null, showExpandButton && /* @__PURE__ */ React__default.createElement(
    IconButton,
    {
      size: "small",
      onClick: () => setOpen(!open),
      className: classes.expandIcon
    },
    open ? /* @__PURE__ */ React__default.createElement(KeyboardArrowDownIcon, null) : /* @__PURE__ */ React__default.createElement(KeyboardArrowRight, null)
  )), !isNil(rule.score) && /* @__PURE__ */ React__default.createElement(React__default.Fragment, null, isFailing ? /* @__PURE__ */ React__default.createElement(
    CancelIcon,
    {
      color: "error",
      className: classNames(
        iconsClasses.statusIcon,
        iconsClasses.failingRule
      )
    }
  ) : /* @__PURE__ */ React__default.createElement(
    CheckCircleIcon,
    {
      className: classNames(
        iconsClasses.statusIcon,
        iconsClasses.passingRule
      )
    }
  )), /* @__PURE__ */ React__default.createElement(Box, null, /* @__PURE__ */ React__default.createElement(
    Typography,
    {
      variant: "subtitle2",
      className: classNames({ [iconsClasses.failingRule]: isFailing })
    },
    ruleName(rule)
  ), /* @__PURE__ */ React__default.createElement(Collapse, { in: open, timeout: "auto", unmountOnExit: true }, /* @__PURE__ */ React__default.createElement(React__default.Fragment, null, rule.error && /* @__PURE__ */ React__default.createElement(Typography, { color: "error", className: classes.ruleQuery }, rule.error), isFailing && rule.failureMessage && /* @__PURE__ */ React__default.createElement(
    MarkdownContent,
    {
      className: classes.ruleDescription,
      content: rule.failureMessage
    }
  ), rule.description && /* @__PURE__ */ React__default.createElement(
    MarkdownContent,
    {
      className: classes.ruleDescription,
      content: rule.description
    }
  ), rule.expression && /* @__PURE__ */ React__default.createElement(Typography, { variant: "caption", className: classes.ruleQuery }, rule.expression), rule.filter && "query" in rule.filter && /* @__PURE__ */ React__default.createElement(Typography, { variant: "overline" }, rule.filter.query))))), !hideWeight && /* @__PURE__ */ React__default.createElement(Box, null, /* @__PURE__ */ React__default.createElement(Typography, { variant: "caption" }, rule.weight)));
};

export { ScorecardServiceRuleRow };
//# sourceMappingURL=ScorecardsServiceRuleRow.esm.js.map
