import React__default, { useMemo } from 'react';
import { partition, isEmpty } from 'lodash';
import { getApplicableRules, chainedComparator, filterNotEvaluatedRuleOutcomes, getRuleTitle } from '../../../utils/ScorecardRules.esm.js';
import { ScorecardServiceRuleRow } from './ScorecardsServiceRuleRow.esm.js';
import { CortexInfoCard } from '../../Common/CortexInfoCard.esm.js';
import useScorecardServiceRuleRowStyle from './useScorecardServiceRuleRowStyles.esm.js';

const ScorecardsServiceRulesDetails = ({
  hideWeights,
  ruleOutcomes
}) => {
  const [failingRules, passingRules] = useMemo(() => {
    const applicableRules = getApplicableRules(ruleOutcomes);
    const sortedRules = [...applicableRules].sort(
      chainedComparator(
        (left, right) => {
          var _a, _b, _c, _d;
          return ((_b = (_a = right == null ? void 0 : right.rule) == null ? void 0 : _a.weight) != null ? _b : 0) - ((_d = (_c = left == null ? void 0 : left.rule) == null ? void 0 : _c.weight) != null ? _d : 0);
        },
        (left, right) => getRuleTitle(left == null ? void 0 : left.rule).localeCompare(getRuleTitle(right == null ? void 0 : right.rule))
      )
    );
    return partition(sortedRules, { score: 0 });
  }, [ruleOutcomes]);
  const notEvaluatedRules = useMemo(() => {
    return filterNotEvaluatedRuleOutcomes(ruleOutcomes);
  }, [ruleOutcomes]);
  const scorecardServiceRuleRowClasses = useScorecardServiceRuleRowStyle();
  return /* @__PURE__ */ React__default.createElement(React__default.Fragment, null, !isEmpty(failingRules) && /* @__PURE__ */ React__default.createElement(CortexInfoCard, { title: "Failing rules" }, failingRules.map((failingRule) => /* @__PURE__ */ React__default.createElement(
    ScorecardServiceRuleRow,
    {
      key: `failing-rule-${failingRule.rule.id}`,
      classes: scorecardServiceRuleRowClasses,
      rule: {
        ...failingRule.rule,
        score: failingRule.score,
        error: failingRule.error
      },
      hideWeight: hideWeights
    }
  ))), !isEmpty(passingRules) && /* @__PURE__ */ React__default.createElement(CortexInfoCard, { title: "Passing rules" }, passingRules.map((passingRule) => /* @__PURE__ */ React__default.createElement(
    ScorecardServiceRuleRow,
    {
      key: `passing-rule-${passingRule.rule.id}`,
      classes: scorecardServiceRuleRowClasses,
      rule: {
        ...passingRule.rule,
        score: passingRule.score
      },
      hideWeight: hideWeights
    }
  ))), !isEmpty(notEvaluatedRules) && /* @__PURE__ */ React__default.createElement(CortexInfoCard, { title: "Not evaluated rules" }, notEvaluatedRules.map((notEvaluatedRule) => /* @__PURE__ */ React__default.createElement(
    ScorecardServiceRuleRow,
    {
      key: `not-evaluated-rule-${notEvaluatedRule.rule.id}`,
      classes: scorecardServiceRuleRowClasses,
      rule: notEvaluatedRule.rule,
      hideWeight: hideWeights
    }
  ))));
};

export { ScorecardsServiceRulesDetails };
//# sourceMappingURL=ScorecardsServiceRulesDetails.esm.js.map
