import React__default from 'react';
import { makeStyles, Paper, Typography } from '@material-ui/core';
import Box from '@material-ui/core/Box';
import Stats from '../../Common/Stats.esm.js';
import StatsItem, { CaptionTypography } from '../../Common/StatsItem.esm.js';
import { ScorecardLadderLevelBadge } from '../../Common/ScorecardLadderLevelBadge.esm.js';
import { percentify } from '../../../utils/NumberUtils.esm.js';
import { quantileRankSorted } from 'simple-statistics';
import { filterFailingRuleOutcomes } from '../../../utils/ScorecardRules.esm.js';
import { LinearProgressWithLabel } from '../../Common/LinearProgressWithLabel.esm.js';
import useLinearProgressWithLabelStyles from '../../Common/useLinearProgressWithLabelStyles.esm.js';

const useStyles = makeStyles((theme) => ({
  levelBox: {
    display: "flex",
    flexDirection: "row",
    gap: theme.spacing(0.5),
    alignItems: "center"
  }
}));
const ScorecardsServiceStatistics = ({ scores, score, rules }) => {
  var _a;
  const classes = useStyles();
  const currentLevel = (_a = score.ladderLevels[0]) == null ? void 0 : _a.currentLevel;
  const rank = [...scores].reverse().indexOf(score.scorePercentage) + 1;
  const percentileRank = quantileRankSorted(scores, score.scorePercentage);
  const failingRules = filterFailingRuleOutcomes(rules).length;
  const linearProgressWithLabelClasses = useLinearProgressWithLabelStyles();
  return /* @__PURE__ */ React__default.createElement(Paper, { elevation: 0 }, /* @__PURE__ */ React__default.createElement(Stats, null, currentLevel && /* @__PURE__ */ React__default.createElement(Box, { display: "flex", flexDirection: "column" }, /* @__PURE__ */ React__default.createElement(CaptionTypography, { variant: "caption" }, "Level"), /* @__PURE__ */ React__default.createElement(Box, { className: classes.levelBox }, /* @__PURE__ */ React__default.createElement(
    ScorecardLadderLevelBadge,
    {
      name: currentLevel.name,
      color: currentLevel.color
    }
  ), /* @__PURE__ */ React__default.createElement(Typography, { variant: "body1" }, currentLevel.name))), /* @__PURE__ */ React__default.createElement(Box, null, /* @__PURE__ */ React__default.createElement(CaptionTypography, { variant: "caption" }, "Score"), /* @__PURE__ */ React__default.createElement(
    LinearProgressWithLabel,
    {
      classes: linearProgressWithLabelClasses,
      value: percentify(score.scorePercentage)
    }
  )), /* @__PURE__ */ React__default.createElement(StatsItem, { caption: "Rank", type: "NTH", value: rank }), /* @__PURE__ */ React__default.createElement(
    StatsItem,
    {
      caption: "Percentile",
      percentage: true,
      type: "NTH",
      value: percentileRank
    }
  ), /* @__PURE__ */ React__default.createElement(
    StatsItem,
    {
      caption: "Failing rules",
      type: "NONE",
      value: failingRules
    }
  )));
};

export { ScorecardsServiceStatistics };
//# sourceMappingURL=ScorecardsServiceStatistics.esm.js.map
