import React__default, { useMemo } from 'react';
import { Progress, WarningPanel, Table } from '@backstage/core-components';
import { useCortexApi } from '../../utils/hooks.esm.js';
import { JobStatus } from '../../api/types.esm.js';
import { TimelapseOutlined, SmsFailedOutlined, AccessTimeOutlined, CancelOutlined, CheckCircleOutline } from '@material-ui/icons';
import moment from 'moment';
import Grid from '@material-ui/core/Grid';
import { Tooltip } from '@material-ui/core';
import { isNil } from 'lodash';

const statusLogo = (status) => {
  switch (status) {
    case JobStatus.Done:
      return /* @__PURE__ */ React__default.createElement(CheckCircleOutline, { color: "primary" });
    case JobStatus.Cancelled:
      return /* @__PURE__ */ React__default.createElement(CancelOutlined, { color: "error" });
    case JobStatus.TimedOut:
      return /* @__PURE__ */ React__default.createElement(AccessTimeOutlined, { color: "error" });
    case JobStatus.Failure:
      return /* @__PURE__ */ React__default.createElement(SmsFailedOutlined, { color: "error" });
    case JobStatus.InProgress:
      return /* @__PURE__ */ React__default.createElement(TimelapseOutlined, { color: "action" });
  }
};
const formatStatus = (status) => {
  switch (status) {
    case JobStatus.Done:
      return "Done";
    case JobStatus.Cancelled:
      return "Canceled";
    case JobStatus.TimedOut:
      return "Timed out";
    case JobStatus.Failure:
      return "Failure";
    case JobStatus.InProgress:
      return "In progress";
  }
};
const columns = [
  {
    title: "Status",
    field: "status",
    render: ({ status }) => /* @__PURE__ */ React__default.createElement(Grid, { container: true, alignItems: "center", direction: "row" }, /* @__PURE__ */ React__default.createElement(Grid, { item: true, xs: 1 }, statusLogo(status)), /* @__PURE__ */ React__default.createElement(Grid, { item: true, xs: 11 }, formatStatus(status)))
  },
  {
    title: "Timestamp",
    field: "timestamp",
    render: ({ timestamp }) => /* @__PURE__ */ React__default.createElement(
      Tooltip,
      {
        title: moment.utc(timestamp).local().format("dddd, MM/DD/YYYY, HH:mm:ss")
      },
      /* @__PURE__ */ React__default.createElement("span", null, moment.utc(timestamp).local().format("MMM Do YYYY, h:mm:ss a"))
    ),
    defaultSort: "desc"
  }
];
const SyncJobsTable = () => {
  const {
    value: jobsResponse,
    loading,
    error
  } = useCortexApi((api) => api.getSyncJobs());
  const rows = useMemo(() => {
    var _a;
    return (_a = jobsResponse == null ? void 0 : jobsResponse.jobs) == null ? void 0 : _a.map((job) => {
      return {
        status: job.status,
        timestamp: job.dateCreated
      };
    });
  }, [jobsResponse]);
  if (loading || isNil(rows)) {
    return /* @__PURE__ */ React__default.createElement(Progress, null);
  }
  if (error) {
    return /* @__PURE__ */ React__default.createElement(WarningPanel, { severity: "error", title: "Could not load sync jobs." }, error.message);
  }
  return /* @__PURE__ */ React__default.createElement(
    Table,
    {
      title: "Sync job statuses",
      columns,
      options: { search: false },
      data: rows
    }
  );
};

export { SyncJobsTable };
//# sourceMappingURL=SyncJobsTable.esm.js.map
