import React__default, { useCallback } from 'react';
import { makeStyles, Card, Grid, Typography, Divider } from '@material-ui/core';
import Box from '@material-ui/core/Box';
import { fallbackPalette, useDetailCardStyles, Status } from '../../styles/styles.esm.js';
import { ordinal } from '../../utils/strings.esm.js';
import { percentify } from '../../utils/NumberUtils.esm.js';

const useStyles = makeStyles((theme) => {
  var _a, _b, _c, _d, _e, _f;
  return {
    okay: {
      color: (_b = (_a = theme.palette.status) == null ? void 0 : _a.ok) != null ? _b : fallbackPalette.status.ok,
      marginBottom: "1px"
    },
    warning: {
      color: (_d = (_c = theme.palette.status) == null ? void 0 : _c.warning) != null ? _d : fallbackPalette.status.warning,
      marginBottom: "1px"
    },
    error: {
      color: (_f = (_e = theme.palette.status) == null ? void 0 : _e.error) != null ? _f : fallbackPalette.status.error,
      marginBottom: "1px"
    },
    suffix: {
      "font-size": theme.typography.h3.fontSize
    }
  };
});
const suffixify = ({ type, value, percentage }) => {
  const formattedValue = percentage ? percentify(value) : value;
  let suffix;
  switch (type) {
    case "NTH":
      suffix = ordinal(formattedValue);
      break;
    case "PERCENTAGE":
      suffix = "%";
      break;
  }
  return { formattedValue, suffix };
};
const StatsCard = ({ stats }) => {
  const cardClasses = useDetailCardStyles();
  const colorClasses = useStyles();
  const selectClassname = useCallback(
    (status) => {
      switch (status) {
        case Status.OKAY:
          return colorClasses.okay;
        case Status.WARNING:
          return colorClasses.warning;
        case Status.ERROR:
          return colorClasses.error;
        default:
          return colorClasses.okay;
      }
    },
    [colorClasses]
  );
  return /* @__PURE__ */ React__default.createElement(Card, { className: cardClasses.root }, /* @__PURE__ */ React__default.createElement(Grid, { container: true, direction: "row", justify: "space-evenly" }, stats.map((stat, idx) => {
    const { formattedValue, suffix } = suffixify(stat);
    return /* @__PURE__ */ React__default.createElement(React__default.Fragment, { key: `Stat-${stat.label}` }, /* @__PURE__ */ React__default.createElement(Grid, { item: true }, /* @__PURE__ */ React__default.createElement(
      Box,
      {
        flexDirection: "column",
        display: "flex",
        justifyContent: "center",
        alignItems: "center"
      },
      /* @__PURE__ */ React__default.createElement(
        Typography,
        {
          variant: "h1",
          className: selectClassname(stat.status),
          "data-testid": `Stat-${stat.label}`
        },
        formattedValue,
        /* @__PURE__ */ React__default.createElement("span", { className: colorClasses.suffix }, suffix && suffix)
      ),
      /* @__PURE__ */ React__default.createElement(Typography, { variant: "body2" }, stat.label)
    )), idx < stats.length - 1 && /* @__PURE__ */ React__default.createElement(Divider, { orientation: "vertical", variant: "middle", flexItem: true }));
  })));
};

export { StatsCard };
//# sourceMappingURL=StatsCard.esm.js.map
