import React__default, { useMemo } from 'react';
import { Table, TableBody } from '@material-ui/core';
import { Progress, WarningPanel, Content, InfoCard, EmptyState } from '@backstage/core-components';
import { useEntity } from '@backstage/plugin-catalog-react';
import { parseEntityRef } from '@backstage/catalog-model';
import { useCortexApi, usePartialScorecardCompareFn } from '../../utils/hooks.esm.js';
import { defaultSystemRefContext } from '../../utils/ComponentUtils.esm.js';
import { useDetailCardStyles } from '../../styles/styles.esm.js';
import { SystemPageRow } from './SystemPageRow.esm.js';
import { GroupByOption } from '../../api/types.esm.js';
import { isUndefined } from 'lodash';

const SystemPage = () => {
  const classes = useDetailCardStyles();
  const { entity } = useEntity();
  const { value: serviceGroupScores } = useCortexApi(
    (api) => api.getServiceScorecardScores(GroupByOption.SERVICE_GROUP),
    [GroupByOption.SERVICE_GROUP]
  );
  const mySystemScores = useMemo(
    () => {
      var _a;
      return (_a = serviceGroupScores == null ? void 0 : serviceGroupScores.filter((serviceGroupScore) => {
        var _a2;
        const { name } = parseEntityRef(
          (_a2 = serviceGroupScore == null ? void 0 : serviceGroupScore.identifier) != null ? _a2 : "",
          defaultSystemRefContext
        );
        return name === (entity == null ? void 0 : entity.metadata.name);
      })) == null ? void 0 : _a[0];
    },
    [serviceGroupScores, entity]
  );
  const myComponents = useMemo(
    () => {
      var _a;
      return (_a = entity == null ? void 0 : entity.relations) == null ? void 0 : _a.filter(({ type }) => type === "hasPart").map(({ targetRef }) => parseEntityRef(targetRef).name);
    },
    [entity]
  );
  const { value: scorecardScores } = useCortexApi(
    (api) => (mySystemScores == null ? void 0 : mySystemScores.scores) ? Promise.all(
      mySystemScores == null ? void 0 : mySystemScores.scores.map(
        (score) => api.getScorecardScores(score.scorecardId)
      )
    ) : Promise.resolve([]),
    [mySystemScores]
  );
  const scorecardData = useMemo(
    () => mySystemScores == null ? void 0 : mySystemScores.scores.map((score, index) => {
      var _a, _b;
      return {
        score,
        scoresForScorecard: (_b = (_a = scorecardScores == null ? void 0 : scorecardScores[index]) == null ? void 0 : _a.filter(
          ({ componentRef }) => myComponents == null ? void 0 : myComponents.includes(componentRef)
        )) != null ? _b : []
      };
    }),
    [mySystemScores, myComponents, scorecardScores]
  );
  const {
    compareFn: scorecardCompareFn,
    loading: loadingScorecardCompareFn,
    error: scorecardCompareFnError
  } = usePartialScorecardCompareFn();
  const sortedScorecardData = useMemo(() => {
    return scorecardData == null ? void 0 : scorecardData.sort(
      isUndefined(scorecardCompareFn) ? void 0 : (a, b) => scorecardCompareFn(
        { id: a.score.scorecardId },
        { id: b.score.scorecardId }
      )
    );
  }, [scorecardData, scorecardCompareFn]);
  if (loadingScorecardCompareFn) {
    return /* @__PURE__ */ React__default.createElement(Progress, null);
  }
  if (scorecardCompareFnError) {
    return /* @__PURE__ */ React__default.createElement(WarningPanel, { severity: "error", title: "Could not load Scorecards." }, scorecardCompareFnError.message);
  }
  return /* @__PURE__ */ React__default.createElement(Content, null, /* @__PURE__ */ React__default.createElement(InfoCard, { title: "System Scorecards", className: classes.root }, (sortedScorecardData == null ? void 0 : sortedScorecardData.length) === 0 ? /* @__PURE__ */ React__default.createElement(EmptyState, { missing: "data", title: "No scorecards found." }) : /* @__PURE__ */ React__default.createElement(Table, null, /* @__PURE__ */ React__default.createElement(TableBody, null, sortedScorecardData == null ? void 0 : sortedScorecardData.map((_) => /* @__PURE__ */ React__default.createElement(
    SystemPageRow,
    {
      key: `SystemPageRow-${_.score.scorecardId}`,
      score: _.score,
      scoresForScorecard: _.scoresForScorecard
    }
  ))))));
};

export { SystemPage };
//# sourceMappingURL=SystemPage.esm.js.map
