import React__default from 'react';
import { makeStyles, useTheme } from '@material-ui/core';
import { ResponsiveLineCanvas } from '@nivo/line';

const useStyles = makeStyles((theme) => ({
  chartRoot: {
    height: "500px",
    marginTop: "20px"
  },
  toolTip: {
    backgroundColor: "white",
    border: `2px solid ${theme.palette.primary.main}`,
    borderRadius: theme.spacing(2),
    padding: theme.spacing(2),
    fontFamily: "Helvetica",
    fontSize: 12,
    color: theme.palette.primary.main,
    fontWeight: "bold",
    boxShadow: "0px 5px 15px rgba(0,0,0,0.1)",
    marginBottom: theme.spacing(2)
  }
}));
function nivoTheme(theme) {
  return {
    crosshair: {
      line: {
        stroke: theme.palette.divider
      }
    },
    background: theme.palette.background.default,
    axis: {
      ticks: {
        line: { stroke: theme.palette.divider },
        text: { fill: theme.palette.text.primary }
      },
      legend: {
        text: { fill: theme.palette.text.primary }
      }
    },
    grid: {
      line: { stroke: theme.palette.divider }
    },
    labels: {
      text: { fill: theme.palette.text.primary }
    }
  };
}
const percentageYScale = {
  type: "linear",
  min: 0,
  max: 100
};
const Timeseries = ({ data, tooltip, onClick }) => {
  const classes = useStyles();
  const theme = useTheme();
  return /* @__PURE__ */ React__default.createElement("div", { className: classes.chartRoot }, /* @__PURE__ */ React__default.createElement(
    ResponsiveLineCanvas,
    {
      theme: nivoTheme(theme),
      data,
      curve: "linear",
      enablePoints: false,
      colors: { scheme: "nivo" },
      margin: { bottom: 30, top: 30, left: 10, right: 40 },
      tooltip,
      isInteractive: tooltip !== void 0,
      xScale: {
        type: "time",
        useUTC: true,
        precision: "hour"
      },
      xFormat: "time:%m/%d/%Y",
      yScale: percentageYScale,
      yFormat: (p) => `${p}%`,
      axisBottom: {
        format: "%d %b"
      },
      axisRight: {
        format: (p) => `${p}%`
      },
      onClick
    }
  ));
};

export { Timeseries, nivoTheme };
//# sourceMappingURL=Timeseries.esm.js.map
