import { useState, useCallback, useEffect } from 'react';

const useMountEffect = (fun) => useEffect(() => fun == null ? void 0 : fun(), []);
const getSize = (el) => {
  if (!el) {
    return {
      height: 0,
      width: 0
    };
  }
  return {
    height: el.offsetHeight,
    width: el.offsetWidth
  };
};
const useDimensions = (ref) => {
  const [componentSize, setComponentSize] = useState(
    getSize(ref ? ref.current : null)
  );
  const handleResize = useCallback(() => {
    setComponentSize({
      height: ref.current ? ref.current.offsetHeight : 0,
      width: ref.current ? ref.current.offsetWidth : 0
    });
  }, [ref, setComponentSize]);
  const [observer] = useState(() => {
    if (typeof ResizeObserver === "function") {
      return new ResizeObserver(() => {
        handleResize();
      });
    }
    return void 0;
  });
  useMountEffect(() => {
    if (typeof ResizeObserver !== "function") {
      window.addEventListener("resize", handleResize);
    }
    handleResize();
    return () => {
      observer == null ? void 0 : observer.disconnect();
      window.removeEventListener("resize", handleResize);
    };
  });
  return componentSize;
};

export { useDimensions, useMountEffect };
//# sourceMappingURL=pureHooks.esm.js.map
